#!/usr/bin/env python
"""Top-level application programs.

-   :mod:`tools.convertPyX12`.
    Converts Python :file:`.xml` files to :mod:`X12.parse` structures.
    From these structures visitors in :mod:`X12.map` can emit Python source
    as well as Django ORM structures.

-   :mod:`tools.surveyPyX12`.
    Examines the Python :file:`.xml` files to write some overview
    reports.

tools.convertPyX12
=====================

..  automodule:: tools.convertPyX12
    :members:

tools.surveyPyX12
===================

..  automodule:: tools.surveyPyX12
    :members:


"""
