#
# Generated by TigerShark.tools.convertPyX12 on 2012-07-10 16:30:01.728840
#
from tigershark.X12.parse import Message, Loop, Segment, Composite, Element, Properties
parsed_837_1000A = Loop( u'1000A', Properties(looptype='',repeat=u'1',pos=u'020',req_sit=u'R',desc=u'Submitter Name'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'020',desc=u'Submitter Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'41'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'46'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'PER', Properties(syntax='',req_sit=u'R',repeat=u'2',pos=u'045',desc=u'Submitter EDI Contact Information'),
  Element( u'PER01', Properties(desc=u'Contact Function Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'IC'] ) ),
  Element( u'PER02', Properties(desc=u'Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=2,
    codes=[] ) ),
  Element( u'PER03', Properties(desc=u'Communication Number Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=3,
    codes=[u'ED', u'EM', u'FX', u'TE'] ) ),
  Element( u'PER04', Properties(desc=u'Communication Number', req_sit=u'R', data_type=(u'AN',u'1',u'256'), position=4,
    codes=[] ) ),
  Element( u'PER05', Properties(desc=u'Communication Number Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=5,
    codes=[u'ED', u'EM', u'EX', u'FX', u'TE'] ) ),
  Element( u'PER06', Properties(desc=u'Communication Number', req_sit=u'S', data_type=(u'AN',u'1',u'256'), position=6,
    codes=[] ) ),
  Element( u'PER07', Properties(desc=u'Communication Number Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=7,
    codes=[u'ED', u'EM', u'EX', u'FX', u'TE'] ) ),
  Element( u'PER08', Properties(desc=u'Communication Number', req_sit=u'S', data_type=(u'AN',u'1',u'256'), position=8,
    codes=[] ) ),
  Element( u'PER09', Properties(desc=u'Contact Inquiry Reference', req_sit=u'N', data_type=(u'AN',u'1',u'20'), position=9,
    codes=[] ) ),
),
)
parsed_837_1000B = Loop( u'1000B', Properties(looptype='',repeat=u'1',pos=u'020',req_sit=u'R',desc=u'Receiver Name'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'020',desc=u'Receiver Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'40'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'46'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
)
parsed_837_HEADER = Loop( u'HEADER', Properties(looptype=u'wrapper',repeat=u'1',pos=u'010',req_sit=u'R',desc=u'Table 1 - Header'),
Segment( u'BHT', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'010',desc=u'Beginning of Hierarchical Transaction'),
  Element( u'BHT01', Properties(desc=u'Hierarchical Structure Code', req_sit=u'R', data_type=(u'ID',u'4',u'4'), position=1,
    codes=[u'0019'] ) ),
  Element( u'BHT02', Properties(desc=u'Transaction Set Purpose Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[u'00', u'18'] ) ),
  Element( u'BHT03', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'BHT04', Properties(desc=u'Date', req_sit=u'R', data_type=(u'DT',u'8',u'8'), position=4,
    codes=[] ) ),
  Element( u'BHT05', Properties(desc=u'Time', req_sit=u'R', data_type=(u'TM',u'4',u'8'), position=5,
    codes=[] ) ),
  Element( u'BHT06', Properties(desc=u'Transaction Type Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=6,
    codes=[u'CH', u'RP'] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'015',desc=u'Transaction Type Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'87'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[u'004010X096DA1', u'004010X096A1'] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
parsed_837_1000A,
parsed_837_1000B,
)
parsed_837_2010AA = Loop( u'2010AA', Properties(looptype='',repeat=u'1',pos=u'015',req_sit=u'R',desc=u'Billing Provider Name'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'015',desc=u'Billing Provider Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'85'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'N3', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'025',desc=u'Billing Provider Address'),
  Element( u'N301', Properties(desc=u'Address Information', req_sit=u'R', data_type=(u'AN',u'1',u'55'), position=1,
    codes=[] ) ),
  Element( u'N302', Properties(desc=u'Address Information', req_sit=u'S', data_type=(u'AN',u'1',u'55'), position=2,
    codes=[] ) ),
),
Segment( u'N4', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'030',desc=u'Billing Provider City/State/ZIP Code'),
  Element( u'N401', Properties(desc=u'City Name', req_sit=u'R', data_type=(u'AN',u'2',u'30'), position=1,
    codes=[] ) ),
  Element( u'N402', Properties(desc=u'State or Province Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[] ) ),
  Element( u'N403', Properties(desc=u'Postal Code', req_sit=u'R', data_type=(u'ID',u'3',u'15'), position=3,
    codes=[] ) ),
  Element( u'N404', Properties(desc=u'Country Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'N405', Properties(desc=u'Location Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[] ) ),
  Element( u'N406', Properties(desc=u'Location Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'8',pos=u'035',desc=u'Billing Provider Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'1J', u'B3', u'BQ', u'EI', u'FH', u'G2', u'G5', u'LU', u'SY', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'8',pos=u'035',desc=u'Credit/Debit Card Billing Information'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'06', u'8U', u'EM', u'IJ', u'LU', u'RB', u'ST', u'TT'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'PER', Properties(syntax='',req_sit=u'S',repeat=u'2',pos=u'040',desc=u'Billing Provider Contact Information'),
  Element( u'PER01', Properties(desc=u'Contact Function Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'IC'] ) ),
  Element( u'PER02', Properties(desc=u'Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=2,
    codes=[] ) ),
  Element( u'PER03', Properties(desc=u'Communication Number Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=3,
    codes=[u'EM', u'FX', u'TE'] ) ),
  Element( u'PER04', Properties(desc=u'Communication Number', req_sit=u'R', data_type=(u'AN',u'1',u'256'), position=4,
    codes=[] ) ),
  Element( u'PER05', Properties(desc=u'Communication Number Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=5,
    codes=[u'EM', u'EX', u'FX', u'TE'] ) ),
  Element( u'PER06', Properties(desc=u'Communication Number', req_sit=u'S', data_type=(u'AN',u'1',u'256'), position=6,
    codes=[] ) ),
  Element( u'PER07', Properties(desc=u'Communication Number Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=7,
    codes=[u'EM', u'EX', u'FX', u'TE'] ) ),
  Element( u'PER08', Properties(desc=u'Communication Number', req_sit=u'S', data_type=(u'AN',u'1',u'256'), position=8,
    codes=[] ) ),
  Element( u'PER09', Properties(desc=u'Contact Inquiry Reference', req_sit=u'N', data_type=(u'AN',u'1',u'20'), position=9,
    codes=[] ) ),
),
)
parsed_837_2010AB = Loop( u'2010AB', Properties(looptype='',repeat=u'1',pos=u'015',req_sit=u'S',desc=u'Pay-To Provider Name'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'015',desc=u'Pay-To Provider Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'87'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'N3', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'025',desc=u'Pay-To Provider Address'),
  Element( u'N301', Properties(desc=u'Address Information', req_sit=u'R', data_type=(u'AN',u'1',u'55'), position=1,
    codes=[] ) ),
  Element( u'N302', Properties(desc=u'Address Information', req_sit=u'S', data_type=(u'AN',u'1',u'55'), position=2,
    codes=[] ) ),
),
Segment( u'N4', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'030',desc=u'Pay-To Provider City/State/ZIP Code'),
  Element( u'N401', Properties(desc=u'City Name', req_sit=u'R', data_type=(u'AN',u'2',u'30'), position=1,
    codes=[] ) ),
  Element( u'N402', Properties(desc=u'State or Province Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[] ) ),
  Element( u'N403', Properties(desc=u'Postal Code', req_sit=u'R', data_type=(u'ID',u'3',u'15'), position=3,
    codes=[] ) ),
  Element( u'N404', Properties(desc=u'Country Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'N405', Properties(desc=u'Location Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[] ) ),
  Element( u'N406', Properties(desc=u'Location Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'5',pos=u'035',desc=u'Pay-To Provider Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'1J', u'B3', u'BQ', u'EI', u'FH', u'G2', u'G5', u'LU', u'SY', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2010BA = Loop( u'2010BA', Properties(looptype='',repeat=u'1',pos=u'015',req_sit=u'R',desc=u'Subscriber Name'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'015',desc=u'Subscriber Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'IL'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'MI', u'ZZ'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'S', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'N3', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'025',desc=u'Subscriber Address'),
  Element( u'N301', Properties(desc=u'Address Information', req_sit=u'R', data_type=(u'AN',u'1',u'55'), position=1,
    codes=[] ) ),
  Element( u'N302', Properties(desc=u'Address Information', req_sit=u'S', data_type=(u'AN',u'1',u'55'), position=2,
    codes=[] ) ),
),
Segment( u'N4', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'030',desc=u'Subscriber City/State/ZIP Code'),
  Element( u'N401', Properties(desc=u'City Name', req_sit=u'R', data_type=(u'AN',u'2',u'30'), position=1,
    codes=[] ) ),
  Element( u'N402', Properties(desc=u'State or Province Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[] ) ),
  Element( u'N403', Properties(desc=u'Postal Code', req_sit=u'R', data_type=(u'ID',u'3',u'15'), position=3,
    codes=[] ) ),
  Element( u'N404', Properties(desc=u'Country Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'N405', Properties(desc=u'Location Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[] ) ),
  Element( u'N406', Properties(desc=u'Location Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
Segment( u'DMG', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'032',desc=u'Subscriber Demographic Information'),
  Element( u'DMG01', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'D8'] ) ),
  Element( u'DMG02', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=2,
    codes=[] ) ),
  Element( u'DMG03', Properties(desc=u'Gender Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[u'F', u'M', u'U'] ) ),
  Element( u'DMG04', Properties(desc=u'Marital Status Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[] ) ),
  Element( u'DMG05', Properties(desc=u'Race or Ethnicity Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=5,
    codes=[] ) ),
  Element( u'DMG06', Properties(desc=u'Citizenship Status Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=6,
    codes=[] ) ),
  Element( u'DMG07', Properties(desc=u'Country Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=7,
    codes=[] ) ),
  Element( u'DMG08', Properties(desc=u'Basis of Verification Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[] ) ),
  Element( u'DMG09', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=9,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'4',pos=u'035',desc=u'Subscriber Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1W', u'23', u'IG', u'SY'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'035',desc=u'Property and Casualty Claim Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'Y4'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2010BB = Loop( u'2010BB', Properties(looptype='',repeat=u'1',pos=u'015',req_sit=u'S',desc=u'Credit/Debit Card Account Holder Name'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'015',desc=u'Credit/Debit Card Account Holder Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'AO'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'MI'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'2',pos=u'035',desc=u'Credit/Debit Card Information'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'AB', u'BB'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2010BC = Loop( u'2010BC', Properties(looptype='',repeat=u'1',pos=u'015',req_sit=u'R',desc=u'Payer Name'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'015',desc=u'Payer Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'PR'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'PI', u'XV'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'N3', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'025',desc=u'Payer Address'),
  Element( u'N301', Properties(desc=u'Address Information', req_sit=u'R', data_type=(u'AN',u'1',u'55'), position=1,
    codes=[] ) ),
  Element( u'N302', Properties(desc=u'Address Information', req_sit=u'S', data_type=(u'AN',u'1',u'55'), position=2,
    codes=[] ) ),
),
Segment( u'N4', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'030',desc=u'Payer City/State/ZIP Code'),
  Element( u'N401', Properties(desc=u'City Name', req_sit=u'R', data_type=(u'AN',u'2',u'30'), position=1,
    codes=[] ) ),
  Element( u'N402', Properties(desc=u'State or Province Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[] ) ),
  Element( u'N403', Properties(desc=u'Postal Code', req_sit=u'R', data_type=(u'ID',u'3',u'15'), position=3,
    codes=[] ) ),
  Element( u'N404', Properties(desc=u'Country Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'N405', Properties(desc=u'Location Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[] ) ),
  Element( u'N406', Properties(desc=u'Location Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'3',pos=u'035',desc=u'Payer Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'2U', u'FY', u'NF', u'TJ'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2010BD = Loop( u'2010BD', Properties(looptype='',repeat=u'1',pos=u'015',req_sit=u'S',desc=u'Responsible Party Name'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'015',desc=u'Responsible Party Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'QD'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'N', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'N3', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'025',desc=u'Responsible Party Address'),
  Element( u'N301', Properties(desc=u'Address Information', req_sit=u'R', data_type=(u'AN',u'1',u'55'), position=1,
    codes=[] ) ),
  Element( u'N302', Properties(desc=u'Address Information', req_sit=u'S', data_type=(u'AN',u'1',u'55'), position=2,
    codes=[] ) ),
),
Segment( u'N4', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'030',desc=u'Responsible Party City/State/ZIP Code'),
  Element( u'N401', Properties(desc=u'City Name', req_sit=u'R', data_type=(u'AN',u'2',u'30'), position=1,
    codes=[] ) ),
  Element( u'N402', Properties(desc=u'State or Province Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[] ) ),
  Element( u'N403', Properties(desc=u'Postal Code', req_sit=u'R', data_type=(u'ID',u'3',u'15'), position=3,
    codes=[] ) ),
  Element( u'N404', Properties(desc=u'Country Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'N405', Properties(desc=u'Location Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[] ) ),
  Element( u'N406', Properties(desc=u'Location Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
)
parsed_837_2305 = Loop( u'2305', Properties(looptype='',repeat=u'6',pos=u'242',req_sit=u'S',desc=u'Home Health Care Plan Information'),
Segment( u'CR7', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'242',desc=u'Home Health Care Plan Information'),
  Element( u'CR701', Properties(desc=u'Discipline Type Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'AI', u'MS', u'OT', u'PT', u'SN', u'ST'] ) ),
  Element( u'CR702', Properties(desc=u'Number', req_sit=u'R', data_type=(u'N0',u'1',u'9'), position=2,
    codes=[] ) ),
  Element( u'CR703', Properties(desc=u'Number', req_sit=u'R', data_type=(u'N0',u'1',u'9'), position=3,
    codes=[] ) ),
),
Segment( u'HSD', Properties(syntax='',req_sit=u'S',repeat=u'12',pos=u'243',desc=u'Health Care Services Delivery'),
  Element( u'HSD01', Properties(desc=u'Quantity Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'VS'] ) ),
  Element( u'HSD02', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=2,
    codes=[] ) ),
  Element( u'HSD03', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=3,
    codes=[u'DA', u'MO', u'Q1', u'WK'] ) ),
  Element( u'HSD04', Properties(desc=u'Sample Selection Modulus', req_sit=u'S', data_type=(u'R',u'1',u'6'), position=4,
    codes=[] ) ),
  Element( u'HSD05', Properties(desc=u'Time Period Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[u'7', u'35'] ) ),
  Element( u'HSD06', Properties(desc=u'Number of Periods', req_sit=u'S', data_type=(u'N0',u'1',u'3'), position=6,
    codes=[] ) ),
  Element( u'HSD07', Properties(desc=u'Ship/Delivery or Calendar Pattern Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=7,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'A', u'B', u'C', u'D', u'E', u'F', u'G', u'H', u'J', u'K', u'L', u'N', u'O', u'S', u'SA', u'SB', u'SC', u'SD', u'SG', u'SL', u'SP', u'SX', u'SY', u'SZ', u'W'] ) ),
  Element( u'HSD08', Properties(desc=u'Ship/Delivery Pattern Time Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=8,
    codes=[u'D', u'E', u'F'] ) ),
),
)
parsed_837_2310A = Loop( u'2310A', Properties(looptype='',repeat=u'1',pos=u'250',req_sit=u'S',desc=u'Attending Physician Name'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'250',desc=u'Attending Physician Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'71'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'PRV', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'255',desc=u'Attending Physician Specialty Information'),
  Element( u'PRV01', Properties(desc=u'Provider Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'AT', u'SU'] ) ),
  Element( u'PRV02', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'ZZ'] ) ),
  Element( u'PRV03', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'PRV04', Properties(desc=u'State or Province Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=4,
    codes=[] ) ),
  Composite( u'C035', Properties(req_sit=u'N',refdes='',seq=u'05',desc=u'Provider Specialty Information'),
  ),
  Element( u'PRV06', Properties(desc=u'Provider Organization Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'5',pos=u'271',desc=u'Attending Physician Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2310B = Loop( u'2310B', Properties(looptype='',repeat=u'1',pos=u'250',req_sit=u'S',desc=u'Operating Physician Name'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'250',desc=u'Operating Physician Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'72'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'PRV', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'255',desc=u'Operating Physician Specialty Information'),
  Element( u'PRV01', Properties(desc=u'Provider Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'OP'] ) ),
  Element( u'PRV02', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'ZZ'] ) ),
  Element( u'PRV03', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'PRV04', Properties(desc=u'State or Province Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=4,
    codes=[] ) ),
  Composite( u'C035', Properties(req_sit=u'N',refdes='',seq=u'05',desc=u'Provider Specialty Information'),
  ),
  Element( u'PRV06', Properties(desc=u'Provider Organization Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'5',pos=u'271',desc=u'Operating Physician Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2310C = Loop( u'2310C', Properties(looptype='',repeat=u'1',pos=u'250',req_sit=u'S',desc=u'Other Provider Name'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'250',desc=u'Other Provider Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'73'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'PRV', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'255',desc=u'Other Provider Specialty Information'),
  Element( u'PRV01', Properties(desc=u'Provider Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'OT', u'PE'] ) ),
  Element( u'PRV02', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'ZZ'] ) ),
  Element( u'PRV03', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'PRV04', Properties(desc=u'State or Province Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=4,
    codes=[] ) ),
  Composite( u'C035', Properties(req_sit=u'N',refdes='',seq=u'05',desc=u'Provider Specialty Information'),
  ),
  Element( u'PRV06', Properties(desc=u'Provider Organization Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'5',pos=u'271',desc=u'Other Provider Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2310E = Loop( u'2310E', Properties(looptype='',repeat=u'1',pos=u'250',req_sit=u'S',desc=u'Service Facility Name'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'250',desc=u'Service Facility Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'FA'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'S', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'PRV', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'255',desc=u'Service Facility Specialty Information'),
  Element( u'PRV01', Properties(desc=u'Provider Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'RP'] ) ),
  Element( u'PRV02', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'ZZ'] ) ),
  Element( u'PRV03', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'PRV04', Properties(desc=u'State or Province Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=4,
    codes=[] ) ),
  Composite( u'C035', Properties(req_sit=u'N',refdes='',seq=u'05',desc=u'Provider Specialty Information'),
  ),
  Element( u'PRV06', Properties(desc=u'Provider Organization Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=6,
    codes=[] ) ),
),
Segment( u'N3', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'265',desc=u'Service Facility Address'),
  Element( u'N301', Properties(desc=u'Address Information', req_sit=u'R', data_type=(u'AN',u'1',u'55'), position=1,
    codes=[] ) ),
  Element( u'N302', Properties(desc=u'Address Information', req_sit=u'S', data_type=(u'AN',u'1',u'55'), position=2,
    codes=[] ) ),
),
Segment( u'N4', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'270',desc=u'Service Facility City/State/Zip Code'),
  Element( u'N401', Properties(desc=u'City Name', req_sit=u'R', data_type=(u'AN',u'2',u'30'), position=1,
    codes=[] ) ),
  Element( u'N402', Properties(desc=u'State or Province Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[] ) ),
  Element( u'N403', Properties(desc=u'Postal Code', req_sit=u'R', data_type=(u'ID',u'3',u'15'), position=3,
    codes=[] ) ),
  Element( u'N404', Properties(desc=u'Country Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'N405', Properties(desc=u'Location Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[] ) ),
  Element( u'N406', Properties(desc=u'Location Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'5',pos=u'271',desc=u'Service Facility Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'1J', u'EI', u'FH', u'G2', u'G5', u'LU', u'N5', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2330A = Loop( u'2330A', Properties(looptype='',repeat=u'1',pos=u'325',req_sit=u'R',desc=u'Other Subscriber Name'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'325',desc=u'Other Subscriber Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'IL'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'MI', u'ZZ'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'N3', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'332',desc=u'Other Subscriber Address'),
  Element( u'N301', Properties(desc=u'Address Information', req_sit=u'R', data_type=(u'AN',u'1',u'55'), position=1,
    codes=[] ) ),
  Element( u'N302', Properties(desc=u'Address Information', req_sit=u'S', data_type=(u'AN',u'1',u'55'), position=2,
    codes=[] ) ),
),
Segment( u'N4', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'340',desc=u'Other Subscriber City/State/ZIP Code'),
  Element( u'N401', Properties(desc=u'City Name', req_sit=u'R', data_type=(u'AN',u'2',u'30'), position=1,
    codes=[] ) ),
  Element( u'N402', Properties(desc=u'State or Province Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[] ) ),
  Element( u'N403', Properties(desc=u'Postal Code', req_sit=u'R', data_type=(u'ID',u'3',u'15'), position=3,
    codes=[] ) ),
  Element( u'N404', Properties(desc=u'Country Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'N405', Properties(desc=u'Location Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[] ) ),
  Element( u'N406', Properties(desc=u'Location Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'3',pos=u'355',desc=u'Other Subscriber Secondary Information'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1W', u'23', u'IG', u'SY'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2330B = Loop( u'2330B', Properties(looptype='',repeat=u'1',pos=u'325',req_sit=u'R',desc=u'Other Payer Name'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'325',desc=u'Other Payer Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'PR'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'PI', u'XV'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'N3', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'332',desc=u'Other Payer Address'),
  Element( u'N301', Properties(desc=u'Address Information', req_sit=u'R', data_type=(u'AN',u'1',u'55'), position=1,
    codes=[] ) ),
  Element( u'N302', Properties(desc=u'Address Information', req_sit=u'S', data_type=(u'AN',u'1',u'55'), position=2,
    codes=[] ) ),
),
Segment( u'N4', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'340',desc=u'Other Payer City/State/ZIP Code'),
  Element( u'N401', Properties(desc=u'City Name', req_sit=u'R', data_type=(u'AN',u'2',u'30'), position=1,
    codes=[] ) ),
  Element( u'N402', Properties(desc=u'State or Province Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[] ) ),
  Element( u'N403', Properties(desc=u'Postal Code', req_sit=u'R', data_type=(u'ID',u'3',u'15'), position=3,
    codes=[] ) ),
  Element( u'N404', Properties(desc=u'Country Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'N405', Properties(desc=u'Location Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[] ) ),
  Element( u'N406', Properties(desc=u'Location Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'350',desc=u'Claim Adjudication Date'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'573'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'2',pos=u'355',desc=u'Other Payer Secondary Identification and Reference Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'2U', u'F8', u'FY', u'NF', u'TJ'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'355',desc=u'Other Payer Prior Authorization or Referral Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'9F', u'G1'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2330C = Loop( u'2330C', Properties(looptype='',repeat=u'1',pos=u'325',req_sit=u'S',desc=u'Other Payer Patient Information'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'325',desc=u'Other Payer Patient Information'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'QC'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'N', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'EI', u'MI'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'3',pos=u'355',desc=u'Other Payer identification Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1W', u'IG', u'SY'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2330D = Loop( u'2330D', Properties(looptype='',repeat=u'1',pos=u'325',req_sit=u'S',desc=u'Other Payer Attending Provider'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'325',desc=u'Other Payer Attending Provider'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'71'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'N', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'N', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'R',repeat=u'3',pos=u'355',desc=u'Other Payer Attending Provider Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2330E = Loop( u'2330E', Properties(looptype='',repeat=u'1',pos=u'325',req_sit=u'S',desc=u'Other Payer Operating Provider'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'325',desc=u'Other Payer Operating Provider'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'72'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'N', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'N', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'R',repeat=u'3',pos=u'355',desc=u'Other Payer Operating Provider Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2330F = Loop( u'2330F', Properties(looptype='',repeat=u'1',pos=u'325',req_sit=u'S',desc=u'Other Payer Other Provider'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'325',desc=u'Other Payer Other Provider'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'73'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'N', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'N', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'R',repeat=u'3',pos=u'355',desc=u'Other Payer Other Provider Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2330H = Loop( u'2330H', Properties(looptype='',repeat=u'1',pos=u'325',req_sit=u'S',desc=u'Other Payer Service Facility Provider'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'325',desc=u'Other Payer Service Facility Provider'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'FA'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'N', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'N', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'R',repeat=u'3',pos=u'355',desc=u'Other Payer Service Facility Provider Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1B', u'1C', u'1D', u'EI', u'G2', u'LU', u'N5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2320 = Loop( u'2320', Properties(looptype='',repeat=u'10',pos=u'290',req_sit=u'S',desc=u'Other Subscriber Information'),
Segment( u'SBR', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'290',desc=u'Other Subscriber Information'),
  Element( u'SBR01', Properties(desc=u'Payer Responsibility Sequence Number Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=1,
    codes=[u'P', u'S', u'T'] ) ),
  Element( u'SBR02', Properties(desc=u'Individual Relationship Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[u'01', u'04', u'05', u'07', u'10', u'15', u'17', u'18', u'19', u'20', u'21', u'22', u'23', u'24', u'29', u'32', u'33', u'36', u'39', u'40', u'41', u'43', u'53', u'G8'] ) ),
  Element( u'SBR03', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'SBR04', Properties(desc=u'Name', req_sit=u'S', data_type=(u'AN',u'1',u'60'), position=4,
    codes=[] ) ),
  Element( u'SBR05', Properties(desc=u'Insurance Type Code', req_sit=u'N', data_type=(u'ID',u'1',u'3'), position=5,
    codes=[] ) ),
  Element( u'SBR06', Properties(desc=u'Coordination of Benefits Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=6,
    codes=[] ) ),
  Element( u'SBR07', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=7,
    codes=[] ) ),
  Element( u'SBR08', Properties(desc=u'Employment Status Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=8,
    codes=[] ) ),
  Element( u'SBR09', Properties(desc=u'Claim Filing Indicator Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=9,
    codes=[u'09', u'10', u'11', u'12', u'13', u'14', u'15', u'16', u'AM', u'BL', u'CH', u'CI', u'DS', u'HM', u'LI', u'LM', u'MA', u'MB', u'MC', u'OF', u'TV', u'VA', u'WC', u'ZZ'] ) ),
),
Segment( u'CAS', Properties(syntax='',req_sit=u'S',repeat=u'5',pos=u'295',desc=u'Claim Level Adjustment'),
  Element( u'CAS01', Properties(desc=u'Claim Adjustment Group Code', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=1,
    codes=[u'CO', u'CR', u'OA', u'PI', u'PR'] ) ),
  Element( u'CAS02', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'R', data_type=(u'ID',u'1',u'5'), position=2,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'10', u'11', u'12', u'13', u'14', u'15', u'16', u'17', u'18', u'19', u'20', u'21', u'22', u'23', u'24', u'25', u'26', u'27', u'28', u'29', u'30', u'31', u'32', u'33', u'34', u'35', u'36', u'37', u'38', u'39', u'40', u'41', u'42', u'43', u'44', u'45', u'46', u'47', u'48', u'49', u'50', u'51', u'52', u'53', u'54', u'55', u'56', u'57', u'58', u'59', u'60', u'61', u'62', u'63', u'64', u'65', u'66', u'67', u'68', u'69', u'70', u'71', u'72', u'73', u'74', u'75', u'76', u'77', u'78', u'79', u'80', u'81', u'82', u'83', u'84', u'85', u'86', u'87', u'88', u'89', u'90', u'91', u'92', u'93', u'94', u'95', u'96', u'97', u'98', u'99', u'100', u'101', u'102', u'103', u'104', u'105', u'106', u'107', u'108', u'109', u'110', u'111', u'112', u'113', u'114', u'115', u'116', u'117', u'118', u'119', u'120', u'121', u'122', u'123', u'124', u'125', u'126', u'127', u'128', u'129', u'130', u'131', u'132', u'133', u'134', u'135', u'136', u'137', u'138', u'139', u'140', u'141', u'142', u'143', u'144', u'145', u'146', u'147', u'148', u'149', u'150', u'151', u'152', u'153', u'154', u'A0', u'A1', u'A2', u'A3', u'A4', u'A5', u'A6', u'A7', u'A8', u'B1', u'B2', u'B3', u'B4', u'B5', u'B6', u'B7', u'B8', u'B9', u'B10', u'B11', u'B12', u'B13', u'B14', u'B15', u'B16', u'B17', u'B18', u'B19', u'B20', u'B21', u'B22', u'B23', u'D1', u'D2', u'D3', u'D4', u'D5', u'D6', u'D7', u'D8', u'D9', u'D10', u'D11', u'D12', u'D13', u'D14', u'D15', u'W1'] ) ),
  Element( u'CAS03', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=3,
    codes=[] ) ),
  Element( u'CAS04', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=4,
    codes=[] ) ),
  Element( u'CAS05', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=5,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'10', u'11', u'12', u'13', u'14', u'15', u'16', u'17', u'18', u'19', u'20', u'21', u'22', u'23', u'24', u'25', u'26', u'27', u'28', u'29', u'30', u'31', u'32', u'33', u'34', u'35', u'36', u'37', u'38', u'39', u'40', u'41', u'42', u'43', u'44', u'45', u'46', u'47', u'48', u'49', u'50', u'51', u'52', u'53', u'54', u'55', u'56', u'57', u'58', u'59', u'60', u'61', u'62', u'63', u'64', u'65', u'66', u'67', u'68', u'69', u'70', u'71', u'72', u'73', u'74', u'75', u'76', u'77', u'78', u'79', u'80', u'81', u'82', u'83', u'84', u'85', u'86', u'87', u'88', u'89', u'90', u'91', u'92', u'93', u'94', u'95', u'96', u'97', u'98', u'99', u'100', u'101', u'102', u'103', u'104', u'105', u'106', u'107', u'108', u'109', u'110', u'111', u'112', u'113', u'114', u'115', u'116', u'117', u'118', u'119', u'120', u'121', u'122', u'123', u'124', u'125', u'126', u'127', u'128', u'129', u'130', u'131', u'132', u'133', u'134', u'135', u'136', u'137', u'138', u'139', u'140', u'141', u'142', u'143', u'144', u'145', u'146', u'147', u'148', u'149', u'150', u'151', u'152', u'153', u'154', u'A0', u'A1', u'A2', u'A3', u'A4', u'A5', u'A6', u'A7', u'A8', u'B1', u'B2', u'B3', u'B4', u'B5', u'B6', u'B7', u'B8', u'B9', u'B10', u'B11', u'B12', u'B13', u'B14', u'B15', u'B16', u'B17', u'B18', u'B19', u'B20', u'B21', u'B22', u'B23', u'D1', u'D2', u'D3', u'D4', u'D5', u'D6', u'D7', u'D8', u'D9', u'D10', u'D11', u'D12', u'D13', u'D14', u'D15', u'W1'] ) ),
  Element( u'CAS06', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=6,
    codes=[] ) ),
  Element( u'CAS07', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=7,
    codes=[] ) ),
  Element( u'CAS08', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=8,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'10', u'11', u'12', u'13', u'14', u'15', u'16', u'17', u'18', u'19', u'20', u'21', u'22', u'23', u'24', u'25', u'26', u'27', u'28', u'29', u'30', u'31', u'32', u'33', u'34', u'35', u'36', u'37', u'38', u'39', u'40', u'41', u'42', u'43', u'44', u'45', u'46', u'47', u'48', u'49', u'50', u'51', u'52', u'53', u'54', u'55', u'56', u'57', u'58', u'59', u'60', u'61', u'62', u'63', u'64', u'65', u'66', u'67', u'68', u'69', u'70', u'71', u'72', u'73', u'74', u'75', u'76', u'77', u'78', u'79', u'80', u'81', u'82', u'83', u'84', u'85', u'86', u'87', u'88', u'89', u'90', u'91', u'92', u'93', u'94', u'95', u'96', u'97', u'98', u'99', u'100', u'101', u'102', u'103', u'104', u'105', u'106', u'107', u'108', u'109', u'110', u'111', u'112', u'113', u'114', u'115', u'116', u'117', u'118', u'119', u'120', u'121', u'122', u'123', u'124', u'125', u'126', u'127', u'128', u'129', u'130', u'131', u'132', u'133', u'134', u'135', u'136', u'137', u'138', u'139', u'140', u'141', u'142', u'143', u'144', u'145', u'146', u'147', u'148', u'149', u'150', u'151', u'152', u'153', u'154', u'A0', u'A1', u'A2', u'A3', u'A4', u'A5', u'A6', u'A7', u'A8', u'B1', u'B2', u'B3', u'B4', u'B5', u'B6', u'B7', u'B8', u'B9', u'B10', u'B11', u'B12', u'B13', u'B14', u'B15', u'B16', u'B17', u'B18', u'B19', u'B20', u'B21', u'B22', u'B23', u'D1', u'D2', u'D3', u'D4', u'D5', u'D6', u'D7', u'D8', u'D9', u'D10', u'D11', u'D12', u'D13', u'D14', u'D15', u'W1'] ) ),
  Element( u'CAS09', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=9,
    codes=[] ) ),
  Element( u'CAS10', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=10,
    codes=[] ) ),
  Element( u'CAS11', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=11,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'10', u'11', u'12', u'13', u'14', u'15', u'16', u'17', u'18', u'19', u'20', u'21', u'22', u'23', u'24', u'25', u'26', u'27', u'28', u'29', u'30', u'31', u'32', u'33', u'34', u'35', u'36', u'37', u'38', u'39', u'40', u'41', u'42', u'43', u'44', u'45', u'46', u'47', u'48', u'49', u'50', u'51', u'52', u'53', u'54', u'55', u'56', u'57', u'58', u'59', u'60', u'61', u'62', u'63', u'64', u'65', u'66', u'67', u'68', u'69', u'70', u'71', u'72', u'73', u'74', u'75', u'76', u'77', u'78', u'79', u'80', u'81', u'82', u'83', u'84', u'85', u'86', u'87', u'88', u'89', u'90', u'91', u'92', u'93', u'94', u'95', u'96', u'97', u'98', u'99', u'100', u'101', u'102', u'103', u'104', u'105', u'106', u'107', u'108', u'109', u'110', u'111', u'112', u'113', u'114', u'115', u'116', u'117', u'118', u'119', u'120', u'121', u'122', u'123', u'124', u'125', u'126', u'127', u'128', u'129', u'130', u'131', u'132', u'133', u'134', u'135', u'136', u'137', u'138', u'139', u'140', u'141', u'142', u'143', u'144', u'145', u'146', u'147', u'148', u'149', u'150', u'151', u'152', u'153', u'154', u'A0', u'A1', u'A2', u'A3', u'A4', u'A5', u'A6', u'A7', u'A8', u'B1', u'B2', u'B3', u'B4', u'B5', u'B6', u'B7', u'B8', u'B9', u'B10', u'B11', u'B12', u'B13', u'B14', u'B15', u'B16', u'B17', u'B18', u'B19', u'B20', u'B21', u'B22', u'B23', u'D1', u'D2', u'D3', u'D4', u'D5', u'D6', u'D7', u'D8', u'D9', u'D10', u'D11', u'D12', u'D13', u'D14', u'D15', u'W1'] ) ),
  Element( u'CAS12', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=12,
    codes=[] ) ),
  Element( u'CAS13', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=13,
    codes=[] ) ),
  Element( u'CAS14', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=14,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'10', u'11', u'12', u'13', u'14', u'15', u'16', u'17', u'18', u'19', u'20', u'21', u'22', u'23', u'24', u'25', u'26', u'27', u'28', u'29', u'30', u'31', u'32', u'33', u'34', u'35', u'36', u'37', u'38', u'39', u'40', u'41', u'42', u'43', u'44', u'45', u'46', u'47', u'48', u'49', u'50', u'51', u'52', u'53', u'54', u'55', u'56', u'57', u'58', u'59', u'60', u'61', u'62', u'63', u'64', u'65', u'66', u'67', u'68', u'69', u'70', u'71', u'72', u'73', u'74', u'75', u'76', u'77', u'78', u'79', u'80', u'81', u'82', u'83', u'84', u'85', u'86', u'87', u'88', u'89', u'90', u'91', u'92', u'93', u'94', u'95', u'96', u'97', u'98', u'99', u'100', u'101', u'102', u'103', u'104', u'105', u'106', u'107', u'108', u'109', u'110', u'111', u'112', u'113', u'114', u'115', u'116', u'117', u'118', u'119', u'120', u'121', u'122', u'123', u'124', u'125', u'126', u'127', u'128', u'129', u'130', u'131', u'132', u'133', u'134', u'135', u'136', u'137', u'138', u'139', u'140', u'141', u'142', u'143', u'144', u'145', u'146', u'147', u'148', u'149', u'150', u'151', u'152', u'153', u'154', u'A0', u'A1', u'A2', u'A3', u'A4', u'A5', u'A6', u'A7', u'A8', u'B1', u'B2', u'B3', u'B4', u'B5', u'B6', u'B7', u'B8', u'B9', u'B10', u'B11', u'B12', u'B13', u'B14', u'B15', u'B16', u'B17', u'B18', u'B19', u'B20', u'B21', u'B22', u'B23', u'D1', u'D2', u'D3', u'D4', u'D5', u'D6', u'D7', u'D8', u'D9', u'D10', u'D11', u'D12', u'D13', u'D14', u'D15', u'W1'] ) ),
  Element( u'CAS15', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=15,
    codes=[] ) ),
  Element( u'CAS16', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=16,
    codes=[] ) ),
  Element( u'CAS17', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=17,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'10', u'11', u'12', u'13', u'14', u'15', u'16', u'17', u'18', u'19', u'20', u'21', u'22', u'23', u'24', u'25', u'26', u'27', u'28', u'29', u'30', u'31', u'32', u'33', u'34', u'35', u'36', u'37', u'38', u'39', u'40', u'41', u'42', u'43', u'44', u'45', u'46', u'47', u'48', u'49', u'50', u'51', u'52', u'53', u'54', u'55', u'56', u'57', u'58', u'59', u'60', u'61', u'62', u'63', u'64', u'65', u'66', u'67', u'68', u'69', u'70', u'71', u'72', u'73', u'74', u'75', u'76', u'77', u'78', u'79', u'80', u'81', u'82', u'83', u'84', u'85', u'86', u'87', u'88', u'89', u'90', u'91', u'92', u'93', u'94', u'95', u'96', u'97', u'98', u'99', u'100', u'101', u'102', u'103', u'104', u'105', u'106', u'107', u'108', u'109', u'110', u'111', u'112', u'113', u'114', u'115', u'116', u'117', u'118', u'119', u'120', u'121', u'122', u'123', u'124', u'125', u'126', u'127', u'128', u'129', u'130', u'131', u'132', u'133', u'134', u'135', u'136', u'137', u'138', u'139', u'140', u'141', u'142', u'143', u'144', u'145', u'146', u'147', u'148', u'149', u'150', u'151', u'152', u'153', u'154', u'A0', u'A1', u'A2', u'A3', u'A4', u'A5', u'A6', u'A7', u'A8', u'B1', u'B2', u'B3', u'B4', u'B5', u'B6', u'B7', u'B8', u'B9', u'B10', u'B11', u'B12', u'B13', u'B14', u'B15', u'B16', u'B17', u'B18', u'B19', u'B20', u'B21', u'B22', u'B23', u'D1', u'D2', u'D3', u'D4', u'D5', u'D6', u'D7', u'D8', u'D9', u'D10', u'D11', u'D12', u'D13', u'D14', u'D15', u'W1'] ) ),
  Element( u'CAS18', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=18,
    codes=[] ) ),
  Element( u'CAS19', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=19,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Payer Prior Payment'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'C4'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Total Allowed Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'B6'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Total Submitted Charges'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'T3'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Diagnostic Related Group (DRG) Outlier Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'ZZ'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Total Medicare Paid Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'N1'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Medicare Paid Amount - 100%'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'KF'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Medicare Paid Amount - 80%'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'PG'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Medicare A Trust Fund Paid Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'AA'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Medicare B Trust Fund Paid Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'B1'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Total Non-Covered Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'A8'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Total Denied Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'YT'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'DMG', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'305',desc=u'Other Subscriber Demographic Information'),
  Element( u'DMG01', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'D8'] ) ),
  Element( u'DMG02', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=2,
    codes=[] ) ),
  Element( u'DMG03', Properties(desc=u'Gender Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[u'F', u'M', u'U'] ) ),
  Element( u'DMG04', Properties(desc=u'Marital Status Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[] ) ),
  Element( u'DMG05', Properties(desc=u'Race or Ethnicity Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=5,
    codes=[] ) ),
  Element( u'DMG06', Properties(desc=u'Citizenship Status Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=6,
    codes=[] ) ),
  Element( u'DMG07', Properties(desc=u'Country Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=7,
    codes=[] ) ),
  Element( u'DMG08', Properties(desc=u'Basis of Verification Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[] ) ),
  Element( u'DMG09', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=9,
    codes=[] ) ),
),
Segment( u'OI', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'310',desc=u'Other Insurance Coverage Information'),
  Element( u'OI01', Properties(desc=u'Claim Filing Indicator Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=1,
    codes=[] ) ),
  Element( u'OI02', Properties(desc=u'Claim Submission Reason Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[] ) ),
  Element( u'OI03', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[u'N', u'Y'] ) ),
  Element( u'OI04', Properties(desc=u'Patient Signature Source Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[] ) ),
  Element( u'OI05', Properties(desc=u'Provider Agreement Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=5,
    codes=[] ) ),
  Element( u'OI06', Properties(desc=u'Release of Information Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=6,
    codes=[u'A', u'I', u'M', u'N', u'O', u'Y'] ) ),
),
Segment( u'MIA', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'315',desc=u'Medicare Inpatient Adjudication Information'),
  Element( u'MIA01', Properties(desc=u'Quantity', req_sit=u'R', data_type=(u'R',u'1',u'15'), position=1,
    codes=[] ) ),
  Element( u'MIA02', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=2,
    codes=[] ) ),
  Element( u'MIA03', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=3,
    codes=[] ) ),
  Element( u'MIA04', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=4,
    codes=[] ) ),
  Element( u'MIA05', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=5,
    codes=[u'M1', u'M2', u'M3', u'M4', u'M5', u'M6', u'M7', u'M8', u'M9', u'M10', u'M11', u'M12', u'M13', u'M14', u'M15', u'M16', u'M17', u'M18', u'M19', u'M20', u'M21', u'M22', u'M23', u'M24', u'M25', u'M26', u'M27', u'M28', u'M29', u'M30', u'M31', u'M32', u'M33', u'M34', u'M35', u'M36', u'M37', u'M38', u'M39', u'M40', u'M41', u'M42', u'M43', u'M44', u'M45', u'M46', u'M47', u'M48', u'M49', u'M50', u'M51', u'M52', u'M53', u'M54', u'M55', u'M56', u'M57', u'M58', u'M59', u'M60', u'M61', u'M62', u'M63', u'M64', u'M65', u'M66', u'M67', u'M68', u'M69', u'M70', u'M71', u'M72', u'M73', u'M74', u'M75', u'M76', u'M77', u'M78', u'M79', u'M80', u'M81', u'M82', u'M83', u'M84', u'M85', u'M86', u'M87', u'M88', u'M89', u'M90', u'M91', u'M92', u'M93', u'M94', u'M95', u'M96', u'M97', u'M98', u'M99', u'M100', u'M101', u'M102', u'M103', u'M104', u'M105', u'M106', u'M107', u'M108', u'M109', u'M110', u'M111', u'M112', u'M113', u'M114', u'M115', u'M116', u'M117', u'M118', u'M119', u'M120', u'M121', u'M122', u'M123', u'M124', u'M125', u'M126', u'M127', u'M128', u'M129', u'M130', u'M131', u'M132', u'M133', u'M134', u'M135', u'M136', u'M137', u'M138', u'M139', u'M140', u'M141', u'M142', u'M143', u'M144', u'MA01', u'MA02', u'MA03', u'MA04', u'MA05', u'MA06', u'MA07', u'MA08', u'MA09', u'MA10', u'MA11', u'MA12', u'MA13', u'MA14', u'MA15', u'MA16', u'MA17', u'MA18', u'MA19', u'MA20', u'MA21', u'MA22', u'MA23', u'MA24', u'MA25', u'MA26', u'MA27', u'MA28', u'MA29', u'MA30', u'MA31', u'MA32', u'MA33', u'MA34', u'MA35', u'MA36', u'MA37', u'MA38', u'MA39', u'MA40', u'MA41', u'MA42', u'MA43', u'MA44', u'MA45', u'MA46', u'MA47', u'MA48', u'MA49', u'MA50', u'MA51', u'MA52', u'MA53', u'MA54', u'MA55', u'MA56', u'MA57', u'MA58', u'MA59', u'MA60', u'MA61', u'MA62', u'MA63', u'MA64', u'MA65', u'MA66', u'MA67', u'MA68', u'MA69', u'MA70', u'MA71', u'MA72', u'MA73', u'MA74', u'MA75', u'MA76', u'MA77', u'MA78', u'MA79', u'MA80', u'MA81', u'MA82', u'MA83', u'MA84', u'MA85', u'MA86', u'MA87', u'MA88', u'MA89', u'MA90', u'MA91', u'MA92', u'MA93', u'MA94', u'MA95', u'MA96', u'MA97', u'MA98', u'MA99', u'MA100', u'MA101', u'MA102', u'MA103', u'MA104', u'MA105', u'MA106', u'MA107', u'MA108', u'MA109', u'MA110', u'MA111', u'MA112', u'MA113', u'MA114', u'MA115', u'MA116', u'MA117', u'MA118', u'MA119', u'MA120', u'MA121', u'MA122', u'MA123', u'MA124', u'MA125', u'MA126', u'MA127', u'MA128', u'MA129', u'MA130', u'MA131', u'MA132', u'MA133', u'MA134', u'N1', u'N2', u'N3', u'N4', u'N5', u'N6', u'N7', u'N8', u'N9', u'N10', u'N11', u'N12', u'N13', u'N14', u'N15', u'N16', u'N17', u'N18', u'N19', u'N20', u'N21', u'N22', u'N23', u'N24', u'N25', u'N26', u'N27', u'N28', u'N29', u'N30', u'N31', u'N32', u'N33', u'N34', u'N35', u'N36', u'N37', u'N38', u'N39', u'N40', u'N41', u'N42', u'N43', u'N44', u'N45', u'N46', u'N47', u'N48', u'N49', u'N50', u'N51', u'N52', u'N53', u'N54', u'N55', u'N56', u'N57', u'N58', u'N59', u'N60', u'N61', u'N62', u'N63', u'N64', u'N65', u'N66', u'N67', u'N68', u'N69', u'N70', u'N71', u'N72', u'N73', u'N74', u'N75', u'N76', u'N77', u'N78', u'N79', u'N80', u'N81', u'N82', u'N83', u'N84', u'N85', u'N86', u'N87', u'N88', u'N89', u'N90', u'N91', u'N92', u'N93', u'N94', u'N95', u'N96', u'N97', u'N98', u'N99', u'N100', u'N101', u'N102', u'N103', u'N104', u'N105', u'N106', u'N107', u'N108', u'N109', u'N110', u'N111', u'N112', u'N113', u'N114', u'N115', u'N116', u'N117', u'N118', u'N119', u'N120', u'N121', u'N122', u'N123', u'N124', u'N125', u'N126', u'N127', u'N128', u'N129', u'N130', u'N131', u'N132', u'N133', u'N134', u'N135', u'N136', u'N137', u'N138', u'N139', u'N140', u'N141', u'N142', u'N143', u'N144', u'N145', u'N146', u'N147', u'N148', u'N149', u'N150', u'N151', u'N152', u'N153', u'N154', u'N155', u'N156 '] ) ),
  Element( u'MIA06', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=6,
    codes=[] ) ),
  Element( u'MIA07', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=7,
    codes=[] ) ),
  Element( u'MIA08', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=8,
    codes=[] ) ),
  Element( u'MIA09', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=9,
    codes=[] ) ),
  Element( u'MIA10', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=10,
    codes=[] ) ),
  Element( u'MIA11', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=11,
    codes=[] ) ),
  Element( u'MIA12', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=12,
    codes=[] ) ),
  Element( u'MIA13', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=13,
    codes=[] ) ),
  Element( u'MIA14', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=14,
    codes=[] ) ),
  Element( u'MIA15', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=15,
    codes=[] ) ),
  Element( u'MIA16', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=16,
    codes=[] ) ),
  Element( u'MIA17', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=17,
    codes=[] ) ),
  Element( u'MIA18', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=18,
    codes=[] ) ),
  Element( u'MIA19', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=19,
    codes=[] ) ),
  Element( u'MIA20', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=20,
    codes=[u'M1', u'M2', u'M3', u'M4', u'M5', u'M6', u'M7', u'M8', u'M9', u'M10', u'M11', u'M12', u'M13', u'M14', u'M15', u'M16', u'M17', u'M18', u'M19', u'M20', u'M21', u'M22', u'M23', u'M24', u'M25', u'M26', u'M27', u'M28', u'M29', u'M30', u'M31', u'M32', u'M33', u'M34', u'M35', u'M36', u'M37', u'M38', u'M39', u'M40', u'M41', u'M42', u'M43', u'M44', u'M45', u'M46', u'M47', u'M48', u'M49', u'M50', u'M51', u'M52', u'M53', u'M54', u'M55', u'M56', u'M57', u'M58', u'M59', u'M60', u'M61', u'M62', u'M63', u'M64', u'M65', u'M66', u'M67', u'M68', u'M69', u'M70', u'M71', u'M72', u'M73', u'M74', u'M75', u'M76', u'M77', u'M78', u'M79', u'M80', u'M81', u'M82', u'M83', u'M84', u'M85', u'M86', u'M87', u'M88', u'M89', u'M90', u'M91', u'M92', u'M93', u'M94', u'M95', u'M96', u'M97', u'M98', u'M99', u'M100', u'M101', u'M102', u'M103', u'M104', u'M105', u'M106', u'M107', u'M108', u'M109', u'M110', u'M111', u'M112', u'M113', u'M114', u'M115', u'M116', u'M117', u'M118', u'M119', u'M120', u'M121', u'M122', u'M123', u'M124', u'M125', u'M126', u'M127', u'M128', u'M129', u'M130', u'M131', u'M132', u'M133', u'M134', u'M135', u'M136', u'M137', u'M138', u'M139', u'M140', u'M141', u'M142', u'M143', u'M144', u'MA01', u'MA02', u'MA03', u'MA04', u'MA05', u'MA06', u'MA07', u'MA08', u'MA09', u'MA10', u'MA11', u'MA12', u'MA13', u'MA14', u'MA15', u'MA16', u'MA17', u'MA18', u'MA19', u'MA20', u'MA21', u'MA22', u'MA23', u'MA24', u'MA25', u'MA26', u'MA27', u'MA28', u'MA29', u'MA30', u'MA31', u'MA32', u'MA33', u'MA34', u'MA35', u'MA36', u'MA37', u'MA38', u'MA39', u'MA40', u'MA41', u'MA42', u'MA43', u'MA44', u'MA45', u'MA46', u'MA47', u'MA48', u'MA49', u'MA50', u'MA51', u'MA52', u'MA53', u'MA54', u'MA55', u'MA56', u'MA57', u'MA58', u'MA59', u'MA60', u'MA61', u'MA62', u'MA63', u'MA64', u'MA65', u'MA66', u'MA67', u'MA68', u'MA69', u'MA70', u'MA71', u'MA72', u'MA73', u'MA74', u'MA75', u'MA76', u'MA77', u'MA78', u'MA79', u'MA80', u'MA81', u'MA82', u'MA83', u'MA84', u'MA85', u'MA86', u'MA87', u'MA88', u'MA89', u'MA90', u'MA91', u'MA92', u'MA93', u'MA94', u'MA95', u'MA96', u'MA97', u'MA98', u'MA99', u'MA100', u'MA101', u'MA102', u'MA103', u'MA104', u'MA105', u'MA106', u'MA107', u'MA108', u'MA109', u'MA110', u'MA111', u'MA112', u'MA113', u'MA114', u'MA115', u'MA116', u'MA117', u'MA118', u'MA119', u'MA120', u'MA121', u'MA122', u'MA123', u'MA124', u'MA125', u'MA126', u'MA127', u'MA128', u'MA129', u'MA130', u'MA131', u'MA132', u'MA133', u'MA134', u'N1', u'N2', u'N3', u'N4', u'N5', u'N6', u'N7', u'N8', u'N9', u'N10', u'N11', u'N12', u'N13', u'N14', u'N15', u'N16', u'N17', u'N18', u'N19', u'N20', u'N21', u'N22', u'N23', u'N24', u'N25', u'N26', u'N27', u'N28', u'N29', u'N30', u'N31', u'N32', u'N33', u'N34', u'N35', u'N36', u'N37', u'N38', u'N39', u'N40', u'N41', u'N42', u'N43', u'N44', u'N45', u'N46', u'N47', u'N48', u'N49', u'N50', u'N51', u'N52', u'N53', u'N54', u'N55', u'N56', u'N57', u'N58', u'N59', u'N60', u'N61', u'N62', u'N63', u'N64', u'N65', u'N66', u'N67', u'N68', u'N69', u'N70', u'N71', u'N72', u'N73', u'N74', u'N75', u'N76', u'N77', u'N78', u'N79', u'N80', u'N81', u'N82', u'N83', u'N84', u'N85', u'N86', u'N87', u'N88', u'N89', u'N90', u'N91', u'N92', u'N93', u'N94', u'N95', u'N96', u'N97', u'N98', u'N99', u'N100', u'N101', u'N102', u'N103', u'N104', u'N105', u'N106', u'N107', u'N108', u'N109', u'N110', u'N111', u'N112', u'N113', u'N114', u'N115', u'N116', u'N117', u'N118', u'N119', u'N120', u'N121', u'N122', u'N123', u'N124', u'N125', u'N126', u'N127', u'N128', u'N129', u'N130', u'N131', u'N132', u'N133', u'N134', u'N135', u'N136', u'N137', u'N138', u'N139', u'N140', u'N141', u'N142', u'N143', u'N144', u'N145', u'N146', u'N147', u'N148', u'N149', u'N150', u'N151', u'N152', u'N153', u'N154', u'N155', u'N156 '] ) ),
  Element( u'MIA21', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=21,
    codes=[u'M1', u'M2', u'M3', u'M4', u'M5', u'M6', u'M7', u'M8', u'M9', u'M10', u'M11', u'M12', u'M13', u'M14', u'M15', u'M16', u'M17', u'M18', u'M19', u'M20', u'M21', u'M22', u'M23', u'M24', u'M25', u'M26', u'M27', u'M28', u'M29', u'M30', u'M31', u'M32', u'M33', u'M34', u'M35', u'M36', u'M37', u'M38', u'M39', u'M40', u'M41', u'M42', u'M43', u'M44', u'M45', u'M46', u'M47', u'M48', u'M49', u'M50', u'M51', u'M52', u'M53', u'M54', u'M55', u'M56', u'M57', u'M58', u'M59', u'M60', u'M61', u'M62', u'M63', u'M64', u'M65', u'M66', u'M67', u'M68', u'M69', u'M70', u'M71', u'M72', u'M73', u'M74', u'M75', u'M76', u'M77', u'M78', u'M79', u'M80', u'M81', u'M82', u'M83', u'M84', u'M85', u'M86', u'M87', u'M88', u'M89', u'M90', u'M91', u'M92', u'M93', u'M94', u'M95', u'M96', u'M97', u'M98', u'M99', u'M100', u'M101', u'M102', u'M103', u'M104', u'M105', u'M106', u'M107', u'M108', u'M109', u'M110', u'M111', u'M112', u'M113', u'M114', u'M115', u'M116', u'M117', u'M118', u'M119', u'M120', u'M121', u'M122', u'M123', u'M124', u'M125', u'M126', u'M127', u'M128', u'M129', u'M130', u'M131', u'M132', u'M133', u'M134', u'M135', u'M136', u'M137', u'M138', u'M139', u'M140', u'M141', u'M142', u'M143', u'M144', u'MA01', u'MA02', u'MA03', u'MA04', u'MA05', u'MA06', u'MA07', u'MA08', u'MA09', u'MA10', u'MA11', u'MA12', u'MA13', u'MA14', u'MA15', u'MA16', u'MA17', u'MA18', u'MA19', u'MA20', u'MA21', u'MA22', u'MA23', u'MA24', u'MA25', u'MA26', u'MA27', u'MA28', u'MA29', u'MA30', u'MA31', u'MA32', u'MA33', u'MA34', u'MA35', u'MA36', u'MA37', u'MA38', u'MA39', u'MA40', u'MA41', u'MA42', u'MA43', u'MA44', u'MA45', u'MA46', u'MA47', u'MA48', u'MA49', u'MA50', u'MA51', u'MA52', u'MA53', u'MA54', u'MA55', u'MA56', u'MA57', u'MA58', u'MA59', u'MA60', u'MA61', u'MA62', u'MA63', u'MA64', u'MA65', u'MA66', u'MA67', u'MA68', u'MA69', u'MA70', u'MA71', u'MA72', u'MA73', u'MA74', u'MA75', u'MA76', u'MA77', u'MA78', u'MA79', u'MA80', u'MA81', u'MA82', u'MA83', u'MA84', u'MA85', u'MA86', u'MA87', u'MA88', u'MA89', u'MA90', u'MA91', u'MA92', u'MA93', u'MA94', u'MA95', u'MA96', u'MA97', u'MA98', u'MA99', u'MA100', u'MA101', u'MA102', u'MA103', u'MA104', u'MA105', u'MA106', u'MA107', u'MA108', u'MA109', u'MA110', u'MA111', u'MA112', u'MA113', u'MA114', u'MA115', u'MA116', u'MA117', u'MA118', u'MA119', u'MA120', u'MA121', u'MA122', u'MA123', u'MA124', u'MA125', u'MA126', u'MA127', u'MA128', u'MA129', u'MA130', u'MA131', u'MA132', u'MA133', u'MA134', u'N1', u'N2', u'N3', u'N4', u'N5', u'N6', u'N7', u'N8', u'N9', u'N10', u'N11', u'N12', u'N13', u'N14', u'N15', u'N16', u'N17', u'N18', u'N19', u'N20', u'N21', u'N22', u'N23', u'N24', u'N25', u'N26', u'N27', u'N28', u'N29', u'N30', u'N31', u'N32', u'N33', u'N34', u'N35', u'N36', u'N37', u'N38', u'N39', u'N40', u'N41', u'N42', u'N43', u'N44', u'N45', u'N46', u'N47', u'N48', u'N49', u'N50', u'N51', u'N52', u'N53', u'N54', u'N55', u'N56', u'N57', u'N58', u'N59', u'N60', u'N61', u'N62', u'N63', u'N64', u'N65', u'N66', u'N67', u'N68', u'N69', u'N70', u'N71', u'N72', u'N73', u'N74', u'N75', u'N76', u'N77', u'N78', u'N79', u'N80', u'N81', u'N82', u'N83', u'N84', u'N85', u'N86', u'N87', u'N88', u'N89', u'N90', u'N91', u'N92', u'N93', u'N94', u'N95', u'N96', u'N97', u'N98', u'N99', u'N100', u'N101', u'N102', u'N103', u'N104', u'N105', u'N106', u'N107', u'N108', u'N109', u'N110', u'N111', u'N112', u'N113', u'N114', u'N115', u'N116', u'N117', u'N118', u'N119', u'N120', u'N121', u'N122', u'N123', u'N124', u'N125', u'N126', u'N127', u'N128', u'N129', u'N130', u'N131', u'N132', u'N133', u'N134', u'N135', u'N136', u'N137', u'N138', u'N139', u'N140', u'N141', u'N142', u'N143', u'N144', u'N145', u'N146', u'N147', u'N148', u'N149', u'N150', u'N151', u'N152', u'N153', u'N154', u'N155', u'N156 '] ) ),
  Element( u'MIA22', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=22,
    codes=[u'M1', u'M2', u'M3', u'M4', u'M5', u'M6', u'M7', u'M8', u'M9', u'M10', u'M11', u'M12', u'M13', u'M14', u'M15', u'M16', u'M17', u'M18', u'M19', u'M20', u'M21', u'M22', u'M23', u'M24', u'M25', u'M26', u'M27', u'M28', u'M29', u'M30', u'M31', u'M32', u'M33', u'M34', u'M35', u'M36', u'M37', u'M38', u'M39', u'M40', u'M41', u'M42', u'M43', u'M44', u'M45', u'M46', u'M47', u'M48', u'M49', u'M50', u'M51', u'M52', u'M53', u'M54', u'M55', u'M56', u'M57', u'M58', u'M59', u'M60', u'M61', u'M62', u'M63', u'M64', u'M65', u'M66', u'M67', u'M68', u'M69', u'M70', u'M71', u'M72', u'M73', u'M74', u'M75', u'M76', u'M77', u'M78', u'M79', u'M80', u'M81', u'M82', u'M83', u'M84', u'M85', u'M86', u'M87', u'M88', u'M89', u'M90', u'M91', u'M92', u'M93', u'M94', u'M95', u'M96', u'M97', u'M98', u'M99', u'M100', u'M101', u'M102', u'M103', u'M104', u'M105', u'M106', u'M107', u'M108', u'M109', u'M110', u'M111', u'M112', u'M113', u'M114', u'M115', u'M116', u'M117', u'M118', u'M119', u'M120', u'M121', u'M122', u'M123', u'M124', u'M125', u'M126', u'M127', u'M128', u'M129', u'M130', u'M131', u'M132', u'M133', u'M134', u'M135', u'M136', u'M137', u'M138', u'M139', u'M140', u'M141', u'M142', u'M143', u'M144', u'MA01', u'MA02', u'MA03', u'MA04', u'MA05', u'MA06', u'MA07', u'MA08', u'MA09', u'MA10', u'MA11', u'MA12', u'MA13', u'MA14', u'MA15', u'MA16', u'MA17', u'MA18', u'MA19', u'MA20', u'MA21', u'MA22', u'MA23', u'MA24', u'MA25', u'MA26', u'MA27', u'MA28', u'MA29', u'MA30', u'MA31', u'MA32', u'MA33', u'MA34', u'MA35', u'MA36', u'MA37', u'MA38', u'MA39', u'MA40', u'MA41', u'MA42', u'MA43', u'MA44', u'MA45', u'MA46', u'MA47', u'MA48', u'MA49', u'MA50', u'MA51', u'MA52', u'MA53', u'MA54', u'MA55', u'MA56', u'MA57', u'MA58', u'MA59', u'MA60', u'MA61', u'MA62', u'MA63', u'MA64', u'MA65', u'MA66', u'MA67', u'MA68', u'MA69', u'MA70', u'MA71', u'MA72', u'MA73', u'MA74', u'MA75', u'MA76', u'MA77', u'MA78', u'MA79', u'MA80', u'MA81', u'MA82', u'MA83', u'MA84', u'MA85', u'MA86', u'MA87', u'MA88', u'MA89', u'MA90', u'MA91', u'MA92', u'MA93', u'MA94', u'MA95', u'MA96', u'MA97', u'MA98', u'MA99', u'MA100', u'MA101', u'MA102', u'MA103', u'MA104', u'MA105', u'MA106', u'MA107', u'MA108', u'MA109', u'MA110', u'MA111', u'MA112', u'MA113', u'MA114', u'MA115', u'MA116', u'MA117', u'MA118', u'MA119', u'MA120', u'MA121', u'MA122', u'MA123', u'MA124', u'MA125', u'MA126', u'MA127', u'MA128', u'MA129', u'MA130', u'MA131', u'MA132', u'MA133', u'MA134', u'N1', u'N2', u'N3', u'N4', u'N5', u'N6', u'N7', u'N8', u'N9', u'N10', u'N11', u'N12', u'N13', u'N14', u'N15', u'N16', u'N17', u'N18', u'N19', u'N20', u'N21', u'N22', u'N23', u'N24', u'N25', u'N26', u'N27', u'N28', u'N29', u'N30', u'N31', u'N32', u'N33', u'N34', u'N35', u'N36', u'N37', u'N38', u'N39', u'N40', u'N41', u'N42', u'N43', u'N44', u'N45', u'N46', u'N47', u'N48', u'N49', u'N50', u'N51', u'N52', u'N53', u'N54', u'N55', u'N56', u'N57', u'N58', u'N59', u'N60', u'N61', u'N62', u'N63', u'N64', u'N65', u'N66', u'N67', u'N68', u'N69', u'N70', u'N71', u'N72', u'N73', u'N74', u'N75', u'N76', u'N77', u'N78', u'N79', u'N80', u'N81', u'N82', u'N83', u'N84', u'N85', u'N86', u'N87', u'N88', u'N89', u'N90', u'N91', u'N92', u'N93', u'N94', u'N95', u'N96', u'N97', u'N98', u'N99', u'N100', u'N101', u'N102', u'N103', u'N104', u'N105', u'N106', u'N107', u'N108', u'N109', u'N110', u'N111', u'N112', u'N113', u'N114', u'N115', u'N116', u'N117', u'N118', u'N119', u'N120', u'N121', u'N122', u'N123', u'N124', u'N125', u'N126', u'N127', u'N128', u'N129', u'N130', u'N131', u'N132', u'N133', u'N134', u'N135', u'N136', u'N137', u'N138', u'N139', u'N140', u'N141', u'N142', u'N143', u'N144', u'N145', u'N146', u'N147', u'N148', u'N149', u'N150', u'N151', u'N152', u'N153', u'N154', u'N155', u'N156 '] ) ),
  Element( u'MIA23', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=23,
    codes=[u'M1', u'M2', u'M3', u'M4', u'M5', u'M6', u'M7', u'M8', u'M9', u'M10', u'M11', u'M12', u'M13', u'M14', u'M15', u'M16', u'M17', u'M18', u'M19', u'M20', u'M21', u'M22', u'M23', u'M24', u'M25', u'M26', u'M27', u'M28', u'M29', u'M30', u'M31', u'M32', u'M33', u'M34', u'M35', u'M36', u'M37', u'M38', u'M39', u'M40', u'M41', u'M42', u'M43', u'M44', u'M45', u'M46', u'M47', u'M48', u'M49', u'M50', u'M51', u'M52', u'M53', u'M54', u'M55', u'M56', u'M57', u'M58', u'M59', u'M60', u'M61', u'M62', u'M63', u'M64', u'M65', u'M66', u'M67', u'M68', u'M69', u'M70', u'M71', u'M72', u'M73', u'M74', u'M75', u'M76', u'M77', u'M78', u'M79', u'M80', u'M81', u'M82', u'M83', u'M84', u'M85', u'M86', u'M87', u'M88', u'M89', u'M90', u'M91', u'M92', u'M93', u'M94', u'M95', u'M96', u'M97', u'M98', u'M99', u'M100', u'M101', u'M102', u'M103', u'M104', u'M105', u'M106', u'M107', u'M108', u'M109', u'M110', u'M111', u'M112', u'M113', u'M114', u'M115', u'M116', u'M117', u'M118', u'M119', u'M120', u'M121', u'M122', u'M123', u'M124', u'M125', u'M126', u'M127', u'M128', u'M129', u'M130', u'M131', u'M132', u'M133', u'M134', u'M135', u'M136', u'M137', u'M138', u'M139', u'M140', u'M141', u'M142', u'M143', u'M144', u'MA01', u'MA02', u'MA03', u'MA04', u'MA05', u'MA06', u'MA07', u'MA08', u'MA09', u'MA10', u'MA11', u'MA12', u'MA13', u'MA14', u'MA15', u'MA16', u'MA17', u'MA18', u'MA19', u'MA20', u'MA21', u'MA22', u'MA23', u'MA24', u'MA25', u'MA26', u'MA27', u'MA28', u'MA29', u'MA30', u'MA31', u'MA32', u'MA33', u'MA34', u'MA35', u'MA36', u'MA37', u'MA38', u'MA39', u'MA40', u'MA41', u'MA42', u'MA43', u'MA44', u'MA45', u'MA46', u'MA47', u'MA48', u'MA49', u'MA50', u'MA51', u'MA52', u'MA53', u'MA54', u'MA55', u'MA56', u'MA57', u'MA58', u'MA59', u'MA60', u'MA61', u'MA62', u'MA63', u'MA64', u'MA65', u'MA66', u'MA67', u'MA68', u'MA69', u'MA70', u'MA71', u'MA72', u'MA73', u'MA74', u'MA75', u'MA76', u'MA77', u'MA78', u'MA79', u'MA80', u'MA81', u'MA82', u'MA83', u'MA84', u'MA85', u'MA86', u'MA87', u'MA88', u'MA89', u'MA90', u'MA91', u'MA92', u'MA93', u'MA94', u'MA95', u'MA96', u'MA97', u'MA98', u'MA99', u'MA100', u'MA101', u'MA102', u'MA103', u'MA104', u'MA105', u'MA106', u'MA107', u'MA108', u'MA109', u'MA110', u'MA111', u'MA112', u'MA113', u'MA114', u'MA115', u'MA116', u'MA117', u'MA118', u'MA119', u'MA120', u'MA121', u'MA122', u'MA123', u'MA124', u'MA125', u'MA126', u'MA127', u'MA128', u'MA129', u'MA130', u'MA131', u'MA132', u'MA133', u'MA134', u'N1', u'N2', u'N3', u'N4', u'N5', u'N6', u'N7', u'N8', u'N9', u'N10', u'N11', u'N12', u'N13', u'N14', u'N15', u'N16', u'N17', u'N18', u'N19', u'N20', u'N21', u'N22', u'N23', u'N24', u'N25', u'N26', u'N27', u'N28', u'N29', u'N30', u'N31', u'N32', u'N33', u'N34', u'N35', u'N36', u'N37', u'N38', u'N39', u'N40', u'N41', u'N42', u'N43', u'N44', u'N45', u'N46', u'N47', u'N48', u'N49', u'N50', u'N51', u'N52', u'N53', u'N54', u'N55', u'N56', u'N57', u'N58', u'N59', u'N60', u'N61', u'N62', u'N63', u'N64', u'N65', u'N66', u'N67', u'N68', u'N69', u'N70', u'N71', u'N72', u'N73', u'N74', u'N75', u'N76', u'N77', u'N78', u'N79', u'N80', u'N81', u'N82', u'N83', u'N84', u'N85', u'N86', u'N87', u'N88', u'N89', u'N90', u'N91', u'N92', u'N93', u'N94', u'N95', u'N96', u'N97', u'N98', u'N99', u'N100', u'N101', u'N102', u'N103', u'N104', u'N105', u'N106', u'N107', u'N108', u'N109', u'N110', u'N111', u'N112', u'N113', u'N114', u'N115', u'N116', u'N117', u'N118', u'N119', u'N120', u'N121', u'N122', u'N123', u'N124', u'N125', u'N126', u'N127', u'N128', u'N129', u'N130', u'N131', u'N132', u'N133', u'N134', u'N135', u'N136', u'N137', u'N138', u'N139', u'N140', u'N141', u'N142', u'N143', u'N144', u'N145', u'N146', u'N147', u'N148', u'N149', u'N150', u'N151', u'N152', u'N153', u'N154', u'N155', u'N156 '] ) ),
  Element( u'MIA24', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=24,
    codes=[] ) ),
),
Segment( u'MOA', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'320',desc=u'Medicare Outpatient Adjudication Information'),
  Element( u'MOA01', Properties(desc=u'Percentage as Decimal', req_sit=u'S', data_type=(u'R',u'1',u'10'), position=1,
    codes=[] ) ),
  Element( u'MOA02', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'MOA03', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[u'M1', u'M2', u'M3', u'M4', u'M5', u'M6', u'M7', u'M8', u'M9', u'M10', u'M11', u'M12', u'M13', u'M14', u'M15', u'M16', u'M17', u'M18', u'M19', u'M20', u'M21', u'M22', u'M23', u'M24', u'M25', u'M26', u'M27', u'M28', u'M29', u'M30', u'M31', u'M32', u'M33', u'M34', u'M35', u'M36', u'M37', u'M38', u'M39', u'M40', u'M41', u'M42', u'M43', u'M44', u'M45', u'M46', u'M47', u'M48', u'M49', u'M50', u'M51', u'M52', u'M53', u'M54', u'M55', u'M56', u'M57', u'M58', u'M59', u'M60', u'M61', u'M62', u'M63', u'M64', u'M65', u'M66', u'M67', u'M68', u'M69', u'M70', u'M71', u'M72', u'M73', u'M74', u'M75', u'M76', u'M77', u'M78', u'M79', u'M80', u'M81', u'M82', u'M83', u'M84', u'M85', u'M86', u'M87', u'M88', u'M89', u'M90', u'M91', u'M92', u'M93', u'M94', u'M95', u'M96', u'M97', u'M98', u'M99', u'M100', u'M101', u'M102', u'M103', u'M104', u'M105', u'M106', u'M107', u'M108', u'M109', u'M110', u'M111', u'M112', u'M113', u'M114', u'M115', u'M116', u'M117', u'M118', u'M119', u'M120', u'M121', u'M122', u'M123', u'M124', u'M125', u'M126', u'M127', u'M128', u'M129', u'M130', u'M131', u'M132', u'M133', u'M134', u'M135', u'M136', u'M137', u'M138', u'M139', u'M140', u'M141', u'M142', u'M143', u'M144', u'MA01', u'MA02', u'MA03', u'MA04', u'MA05', u'MA06', u'MA07', u'MA08', u'MA09', u'MA10', u'MA11', u'MA12', u'MA13', u'MA14', u'MA15', u'MA16', u'MA17', u'MA18', u'MA19', u'MA20', u'MA21', u'MA22', u'MA23', u'MA24', u'MA25', u'MA26', u'MA27', u'MA28', u'MA29', u'MA30', u'MA31', u'MA32', u'MA33', u'MA34', u'MA35', u'MA36', u'MA37', u'MA38', u'MA39', u'MA40', u'MA41', u'MA42', u'MA43', u'MA44', u'MA45', u'MA46', u'MA47', u'MA48', u'MA49', u'MA50', u'MA51', u'MA52', u'MA53', u'MA54', u'MA55', u'MA56', u'MA57', u'MA58', u'MA59', u'MA60', u'MA61', u'MA62', u'MA63', u'MA64', u'MA65', u'MA66', u'MA67', u'MA68', u'MA69', u'MA70', u'MA71', u'MA72', u'MA73', u'MA74', u'MA75', u'MA76', u'MA77', u'MA78', u'MA79', u'MA80', u'MA81', u'MA82', u'MA83', u'MA84', u'MA85', u'MA86', u'MA87', u'MA88', u'MA89', u'MA90', u'MA91', u'MA92', u'MA93', u'MA94', u'MA95', u'MA96', u'MA97', u'MA98', u'MA99', u'MA100', u'MA101', u'MA102', u'MA103', u'MA104', u'MA105', u'MA106', u'MA107', u'MA108', u'MA109', u'MA110', u'MA111', u'MA112', u'MA113', u'MA114', u'MA115', u'MA116', u'MA117', u'MA118', u'MA119', u'MA120', u'MA121', u'MA122', u'MA123', u'MA124', u'MA125', u'MA126', u'MA127', u'MA128', u'MA129', u'MA130', u'MA131', u'MA132', u'MA133', u'MA134', u'N1', u'N2', u'N3', u'N4', u'N5', u'N6', u'N7', u'N8', u'N9', u'N10', u'N11', u'N12', u'N13', u'N14', u'N15', u'N16', u'N17', u'N18', u'N19', u'N20', u'N21', u'N22', u'N23', u'N24', u'N25', u'N26', u'N27', u'N28', u'N29', u'N30', u'N31', u'N32', u'N33', u'N34', u'N35', u'N36', u'N37', u'N38', u'N39', u'N40', u'N41', u'N42', u'N43', u'N44', u'N45', u'N46', u'N47', u'N48', u'N49', u'N50', u'N51', u'N52', u'N53', u'N54', u'N55', u'N56', u'N57', u'N58', u'N59', u'N60', u'N61', u'N62', u'N63', u'N64', u'N65', u'N66', u'N67', u'N68', u'N69', u'N70', u'N71', u'N72', u'N73', u'N74', u'N75', u'N76', u'N77', u'N78', u'N79', u'N80', u'N81', u'N82', u'N83', u'N84', u'N85', u'N86', u'N87', u'N88', u'N89', u'N90', u'N91', u'N92', u'N93', u'N94', u'N95', u'N96', u'N97', u'N98', u'N99', u'N100', u'N101', u'N102', u'N103', u'N104', u'N105', u'N106', u'N107', u'N108', u'N109', u'N110', u'N111', u'N112', u'N113', u'N114', u'N115', u'N116', u'N117', u'N118', u'N119', u'N120', u'N121', u'N122', u'N123', u'N124', u'N125', u'N126', u'N127', u'N128', u'N129', u'N130', u'N131', u'N132', u'N133', u'N134', u'N135', u'N136', u'N137', u'N138', u'N139', u'N140', u'N141', u'N142', u'N143', u'N144', u'N145', u'N146', u'N147', u'N148', u'N149', u'N150', u'N151', u'N152', u'N153', u'N154', u'N155', u'N156 '] ) ),
  Element( u'MOA04', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=4,
    codes=[u'M1', u'M2', u'M3', u'M4', u'M5', u'M6', u'M7', u'M8', u'M9', u'M10', u'M11', u'M12', u'M13', u'M14', u'M15', u'M16', u'M17', u'M18', u'M19', u'M20', u'M21', u'M22', u'M23', u'M24', u'M25', u'M26', u'M27', u'M28', u'M29', u'M30', u'M31', u'M32', u'M33', u'M34', u'M35', u'M36', u'M37', u'M38', u'M39', u'M40', u'M41', u'M42', u'M43', u'M44', u'M45', u'M46', u'M47', u'M48', u'M49', u'M50', u'M51', u'M52', u'M53', u'M54', u'M55', u'M56', u'M57', u'M58', u'M59', u'M60', u'M61', u'M62', u'M63', u'M64', u'M65', u'M66', u'M67', u'M68', u'M69', u'M70', u'M71', u'M72', u'M73', u'M74', u'M75', u'M76', u'M77', u'M78', u'M79', u'M80', u'M81', u'M82', u'M83', u'M84', u'M85', u'M86', u'M87', u'M88', u'M89', u'M90', u'M91', u'M92', u'M93', u'M94', u'M95', u'M96', u'M97', u'M98', u'M99', u'M100', u'M101', u'M102', u'M103', u'M104', u'M105', u'M106', u'M107', u'M108', u'M109', u'M110', u'M111', u'M112', u'M113', u'M114', u'M115', u'M116', u'M117', u'M118', u'M119', u'M120', u'M121', u'M122', u'M123', u'M124', u'M125', u'M126', u'M127', u'M128', u'M129', u'M130', u'M131', u'M132', u'M133', u'M134', u'M135', u'M136', u'M137', u'M138', u'M139', u'M140', u'M141', u'M142', u'M143', u'M144', u'MA01', u'MA02', u'MA03', u'MA04', u'MA05', u'MA06', u'MA07', u'MA08', u'MA09', u'MA10', u'MA11', u'MA12', u'MA13', u'MA14', u'MA15', u'MA16', u'MA17', u'MA18', u'MA19', u'MA20', u'MA21', u'MA22', u'MA23', u'MA24', u'MA25', u'MA26', u'MA27', u'MA28', u'MA29', u'MA30', u'MA31', u'MA32', u'MA33', u'MA34', u'MA35', u'MA36', u'MA37', u'MA38', u'MA39', u'MA40', u'MA41', u'MA42', u'MA43', u'MA44', u'MA45', u'MA46', u'MA47', u'MA48', u'MA49', u'MA50', u'MA51', u'MA52', u'MA53', u'MA54', u'MA55', u'MA56', u'MA57', u'MA58', u'MA59', u'MA60', u'MA61', u'MA62', u'MA63', u'MA64', u'MA65', u'MA66', u'MA67', u'MA68', u'MA69', u'MA70', u'MA71', u'MA72', u'MA73', u'MA74', u'MA75', u'MA76', u'MA77', u'MA78', u'MA79', u'MA80', u'MA81', u'MA82', u'MA83', u'MA84', u'MA85', u'MA86', u'MA87', u'MA88', u'MA89', u'MA90', u'MA91', u'MA92', u'MA93', u'MA94', u'MA95', u'MA96', u'MA97', u'MA98', u'MA99', u'MA100', u'MA101', u'MA102', u'MA103', u'MA104', u'MA105', u'MA106', u'MA107', u'MA108', u'MA109', u'MA110', u'MA111', u'MA112', u'MA113', u'MA114', u'MA115', u'MA116', u'MA117', u'MA118', u'MA119', u'MA120', u'MA121', u'MA122', u'MA123', u'MA124', u'MA125', u'MA126', u'MA127', u'MA128', u'MA129', u'MA130', u'MA131', u'MA132', u'MA133', u'MA134', u'N1', u'N2', u'N3', u'N4', u'N5', u'N6', u'N7', u'N8', u'N9', u'N10', u'N11', u'N12', u'N13', u'N14', u'N15', u'N16', u'N17', u'N18', u'N19', u'N20', u'N21', u'N22', u'N23', u'N24', u'N25', u'N26', u'N27', u'N28', u'N29', u'N30', u'N31', u'N32', u'N33', u'N34', u'N35', u'N36', u'N37', u'N38', u'N39', u'N40', u'N41', u'N42', u'N43', u'N44', u'N45', u'N46', u'N47', u'N48', u'N49', u'N50', u'N51', u'N52', u'N53', u'N54', u'N55', u'N56', u'N57', u'N58', u'N59', u'N60', u'N61', u'N62', u'N63', u'N64', u'N65', u'N66', u'N67', u'N68', u'N69', u'N70', u'N71', u'N72', u'N73', u'N74', u'N75', u'N76', u'N77', u'N78', u'N79', u'N80', u'N81', u'N82', u'N83', u'N84', u'N85', u'N86', u'N87', u'N88', u'N89', u'N90', u'N91', u'N92', u'N93', u'N94', u'N95', u'N96', u'N97', u'N98', u'N99', u'N100', u'N101', u'N102', u'N103', u'N104', u'N105', u'N106', u'N107', u'N108', u'N109', u'N110', u'N111', u'N112', u'N113', u'N114', u'N115', u'N116', u'N117', u'N118', u'N119', u'N120', u'N121', u'N122', u'N123', u'N124', u'N125', u'N126', u'N127', u'N128', u'N129', u'N130', u'N131', u'N132', u'N133', u'N134', u'N135', u'N136', u'N137', u'N138', u'N139', u'N140', u'N141', u'N142', u'N143', u'N144', u'N145', u'N146', u'N147', u'N148', u'N149', u'N150', u'N151', u'N152', u'N153', u'N154', u'N155', u'N156 '] ) ),
  Element( u'MOA05', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=5,
    codes=[u'M1', u'M2', u'M3', u'M4', u'M5', u'M6', u'M7', u'M8', u'M9', u'M10', u'M11', u'M12', u'M13', u'M14', u'M15', u'M16', u'M17', u'M18', u'M19', u'M20', u'M21', u'M22', u'M23', u'M24', u'M25', u'M26', u'M27', u'M28', u'M29', u'M30', u'M31', u'M32', u'M33', u'M34', u'M35', u'M36', u'M37', u'M38', u'M39', u'M40', u'M41', u'M42', u'M43', u'M44', u'M45', u'M46', u'M47', u'M48', u'M49', u'M50', u'M51', u'M52', u'M53', u'M54', u'M55', u'M56', u'M57', u'M58', u'M59', u'M60', u'M61', u'M62', u'M63', u'M64', u'M65', u'M66', u'M67', u'M68', u'M69', u'M70', u'M71', u'M72', u'M73', u'M74', u'M75', u'M76', u'M77', u'M78', u'M79', u'M80', u'M81', u'M82', u'M83', u'M84', u'M85', u'M86', u'M87', u'M88', u'M89', u'M90', u'M91', u'M92', u'M93', u'M94', u'M95', u'M96', u'M97', u'M98', u'M99', u'M100', u'M101', u'M102', u'M103', u'M104', u'M105', u'M106', u'M107', u'M108', u'M109', u'M110', u'M111', u'M112', u'M113', u'M114', u'M115', u'M116', u'M117', u'M118', u'M119', u'M120', u'M121', u'M122', u'M123', u'M124', u'M125', u'M126', u'M127', u'M128', u'M129', u'M130', u'M131', u'M132', u'M133', u'M134', u'M135', u'M136', u'M137', u'M138', u'M139', u'M140', u'M141', u'M142', u'M143', u'M144', u'MA01', u'MA02', u'MA03', u'MA04', u'MA05', u'MA06', u'MA07', u'MA08', u'MA09', u'MA10', u'MA11', u'MA12', u'MA13', u'MA14', u'MA15', u'MA16', u'MA17', u'MA18', u'MA19', u'MA20', u'MA21', u'MA22', u'MA23', u'MA24', u'MA25', u'MA26', u'MA27', u'MA28', u'MA29', u'MA30', u'MA31', u'MA32', u'MA33', u'MA34', u'MA35', u'MA36', u'MA37', u'MA38', u'MA39', u'MA40', u'MA41', u'MA42', u'MA43', u'MA44', u'MA45', u'MA46', u'MA47', u'MA48', u'MA49', u'MA50', u'MA51', u'MA52', u'MA53', u'MA54', u'MA55', u'MA56', u'MA57', u'MA58', u'MA59', u'MA60', u'MA61', u'MA62', u'MA63', u'MA64', u'MA65', u'MA66', u'MA67', u'MA68', u'MA69', u'MA70', u'MA71', u'MA72', u'MA73', u'MA74', u'MA75', u'MA76', u'MA77', u'MA78', u'MA79', u'MA80', u'MA81', u'MA82', u'MA83', u'MA84', u'MA85', u'MA86', u'MA87', u'MA88', u'MA89', u'MA90', u'MA91', u'MA92', u'MA93', u'MA94', u'MA95', u'MA96', u'MA97', u'MA98', u'MA99', u'MA100', u'MA101', u'MA102', u'MA103', u'MA104', u'MA105', u'MA106', u'MA107', u'MA108', u'MA109', u'MA110', u'MA111', u'MA112', u'MA113', u'MA114', u'MA115', u'MA116', u'MA117', u'MA118', u'MA119', u'MA120', u'MA121', u'MA122', u'MA123', u'MA124', u'MA125', u'MA126', u'MA127', u'MA128', u'MA129', u'MA130', u'MA131', u'MA132', u'MA133', u'MA134', u'N1', u'N2', u'N3', u'N4', u'N5', u'N6', u'N7', u'N8', u'N9', u'N10', u'N11', u'N12', u'N13', u'N14', u'N15', u'N16', u'N17', u'N18', u'N19', u'N20', u'N21', u'N22', u'N23', u'N24', u'N25', u'N26', u'N27', u'N28', u'N29', u'N30', u'N31', u'N32', u'N33', u'N34', u'N35', u'N36', u'N37', u'N38', u'N39', u'N40', u'N41', u'N42', u'N43', u'N44', u'N45', u'N46', u'N47', u'N48', u'N49', u'N50', u'N51', u'N52', u'N53', u'N54', u'N55', u'N56', u'N57', u'N58', u'N59', u'N60', u'N61', u'N62', u'N63', u'N64', u'N65', u'N66', u'N67', u'N68', u'N69', u'N70', u'N71', u'N72', u'N73', u'N74', u'N75', u'N76', u'N77', u'N78', u'N79', u'N80', u'N81', u'N82', u'N83', u'N84', u'N85', u'N86', u'N87', u'N88', u'N89', u'N90', u'N91', u'N92', u'N93', u'N94', u'N95', u'N96', u'N97', u'N98', u'N99', u'N100', u'N101', u'N102', u'N103', u'N104', u'N105', u'N106', u'N107', u'N108', u'N109', u'N110', u'N111', u'N112', u'N113', u'N114', u'N115', u'N116', u'N117', u'N118', u'N119', u'N120', u'N121', u'N122', u'N123', u'N124', u'N125', u'N126', u'N127', u'N128', u'N129', u'N130', u'N131', u'N132', u'N133', u'N134', u'N135', u'N136', u'N137', u'N138', u'N139', u'N140', u'N141', u'N142', u'N143', u'N144', u'N145', u'N146', u'N147', u'N148', u'N149', u'N150', u'N151', u'N152', u'N153', u'N154', u'N155', u'N156 '] ) ),
  Element( u'MOA06', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=6,
    codes=[u'M1', u'M2', u'M3', u'M4', u'M5', u'M6', u'M7', u'M8', u'M9', u'M10', u'M11', u'M12', u'M13', u'M14', u'M15', u'M16', u'M17', u'M18', u'M19', u'M20', u'M21', u'M22', u'M23', u'M24', u'M25', u'M26', u'M27', u'M28', u'M29', u'M30', u'M31', u'M32', u'M33', u'M34', u'M35', u'M36', u'M37', u'M38', u'M39', u'M40', u'M41', u'M42', u'M43', u'M44', u'M45', u'M46', u'M47', u'M48', u'M49', u'M50', u'M51', u'M52', u'M53', u'M54', u'M55', u'M56', u'M57', u'M58', u'M59', u'M60', u'M61', u'M62', u'M63', u'M64', u'M65', u'M66', u'M67', u'M68', u'M69', u'M70', u'M71', u'M72', u'M73', u'M74', u'M75', u'M76', u'M77', u'M78', u'M79', u'M80', u'M81', u'M82', u'M83', u'M84', u'M85', u'M86', u'M87', u'M88', u'M89', u'M90', u'M91', u'M92', u'M93', u'M94', u'M95', u'M96', u'M97', u'M98', u'M99', u'M100', u'M101', u'M102', u'M103', u'M104', u'M105', u'M106', u'M107', u'M108', u'M109', u'M110', u'M111', u'M112', u'M113', u'M114', u'M115', u'M116', u'M117', u'M118', u'M119', u'M120', u'M121', u'M122', u'M123', u'M124', u'M125', u'M126', u'M127', u'M128', u'M129', u'M130', u'M131', u'M132', u'M133', u'M134', u'M135', u'M136', u'M137', u'M138', u'M139', u'M140', u'M141', u'M142', u'M143', u'M144', u'MA01', u'MA02', u'MA03', u'MA04', u'MA05', u'MA06', u'MA07', u'MA08', u'MA09', u'MA10', u'MA11', u'MA12', u'MA13', u'MA14', u'MA15', u'MA16', u'MA17', u'MA18', u'MA19', u'MA20', u'MA21', u'MA22', u'MA23', u'MA24', u'MA25', u'MA26', u'MA27', u'MA28', u'MA29', u'MA30', u'MA31', u'MA32', u'MA33', u'MA34', u'MA35', u'MA36', u'MA37', u'MA38', u'MA39', u'MA40', u'MA41', u'MA42', u'MA43', u'MA44', u'MA45', u'MA46', u'MA47', u'MA48', u'MA49', u'MA50', u'MA51', u'MA52', u'MA53', u'MA54', u'MA55', u'MA56', u'MA57', u'MA58', u'MA59', u'MA60', u'MA61', u'MA62', u'MA63', u'MA64', u'MA65', u'MA66', u'MA67', u'MA68', u'MA69', u'MA70', u'MA71', u'MA72', u'MA73', u'MA74', u'MA75', u'MA76', u'MA77', u'MA78', u'MA79', u'MA80', u'MA81', u'MA82', u'MA83', u'MA84', u'MA85', u'MA86', u'MA87', u'MA88', u'MA89', u'MA90', u'MA91', u'MA92', u'MA93', u'MA94', u'MA95', u'MA96', u'MA97', u'MA98', u'MA99', u'MA100', u'MA101', u'MA102', u'MA103', u'MA104', u'MA105', u'MA106', u'MA107', u'MA108', u'MA109', u'MA110', u'MA111', u'MA112', u'MA113', u'MA114', u'MA115', u'MA116', u'MA117', u'MA118', u'MA119', u'MA120', u'MA121', u'MA122', u'MA123', u'MA124', u'MA125', u'MA126', u'MA127', u'MA128', u'MA129', u'MA130', u'MA131', u'MA132', u'MA133', u'MA134', u'N1', u'N2', u'N3', u'N4', u'N5', u'N6', u'N7', u'N8', u'N9', u'N10', u'N11', u'N12', u'N13', u'N14', u'N15', u'N16', u'N17', u'N18', u'N19', u'N20', u'N21', u'N22', u'N23', u'N24', u'N25', u'N26', u'N27', u'N28', u'N29', u'N30', u'N31', u'N32', u'N33', u'N34', u'N35', u'N36', u'N37', u'N38', u'N39', u'N40', u'N41', u'N42', u'N43', u'N44', u'N45', u'N46', u'N47', u'N48', u'N49', u'N50', u'N51', u'N52', u'N53', u'N54', u'N55', u'N56', u'N57', u'N58', u'N59', u'N60', u'N61', u'N62', u'N63', u'N64', u'N65', u'N66', u'N67', u'N68', u'N69', u'N70', u'N71', u'N72', u'N73', u'N74', u'N75', u'N76', u'N77', u'N78', u'N79', u'N80', u'N81', u'N82', u'N83', u'N84', u'N85', u'N86', u'N87', u'N88', u'N89', u'N90', u'N91', u'N92', u'N93', u'N94', u'N95', u'N96', u'N97', u'N98', u'N99', u'N100', u'N101', u'N102', u'N103', u'N104', u'N105', u'N106', u'N107', u'N108', u'N109', u'N110', u'N111', u'N112', u'N113', u'N114', u'N115', u'N116', u'N117', u'N118', u'N119', u'N120', u'N121', u'N122', u'N123', u'N124', u'N125', u'N126', u'N127', u'N128', u'N129', u'N130', u'N131', u'N132', u'N133', u'N134', u'N135', u'N136', u'N137', u'N138', u'N139', u'N140', u'N141', u'N142', u'N143', u'N144', u'N145', u'N146', u'N147', u'N148', u'N149', u'N150', u'N151', u'N152', u'N153', u'N154', u'N155', u'N156 '] ) ),
  Element( u'MOA07', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=7,
    codes=[u'M1', u'M2', u'M3', u'M4', u'M5', u'M6', u'M7', u'M8', u'M9', u'M10', u'M11', u'M12', u'M13', u'M14', u'M15', u'M16', u'M17', u'M18', u'M19', u'M20', u'M21', u'M22', u'M23', u'M24', u'M25', u'M26', u'M27', u'M28', u'M29', u'M30', u'M31', u'M32', u'M33', u'M34', u'M35', u'M36', u'M37', u'M38', u'M39', u'M40', u'M41', u'M42', u'M43', u'M44', u'M45', u'M46', u'M47', u'M48', u'M49', u'M50', u'M51', u'M52', u'M53', u'M54', u'M55', u'M56', u'M57', u'M58', u'M59', u'M60', u'M61', u'M62', u'M63', u'M64', u'M65', u'M66', u'M67', u'M68', u'M69', u'M70', u'M71', u'M72', u'M73', u'M74', u'M75', u'M76', u'M77', u'M78', u'M79', u'M80', u'M81', u'M82', u'M83', u'M84', u'M85', u'M86', u'M87', u'M88', u'M89', u'M90', u'M91', u'M92', u'M93', u'M94', u'M95', u'M96', u'M97', u'M98', u'M99', u'M100', u'M101', u'M102', u'M103', u'M104', u'M105', u'M106', u'M107', u'M108', u'M109', u'M110', u'M111', u'M112', u'M113', u'M114', u'M115', u'M116', u'M117', u'M118', u'M119', u'M120', u'M121', u'M122', u'M123', u'M124', u'M125', u'M126', u'M127', u'M128', u'M129', u'M130', u'M131', u'M132', u'M133', u'M134', u'M135', u'M136', u'M137', u'M138', u'M139', u'M140', u'M141', u'M142', u'M143', u'M144', u'MA01', u'MA02', u'MA03', u'MA04', u'MA05', u'MA06', u'MA07', u'MA08', u'MA09', u'MA10', u'MA11', u'MA12', u'MA13', u'MA14', u'MA15', u'MA16', u'MA17', u'MA18', u'MA19', u'MA20', u'MA21', u'MA22', u'MA23', u'MA24', u'MA25', u'MA26', u'MA27', u'MA28', u'MA29', u'MA30', u'MA31', u'MA32', u'MA33', u'MA34', u'MA35', u'MA36', u'MA37', u'MA38', u'MA39', u'MA40', u'MA41', u'MA42', u'MA43', u'MA44', u'MA45', u'MA46', u'MA47', u'MA48', u'MA49', u'MA50', u'MA51', u'MA52', u'MA53', u'MA54', u'MA55', u'MA56', u'MA57', u'MA58', u'MA59', u'MA60', u'MA61', u'MA62', u'MA63', u'MA64', u'MA65', u'MA66', u'MA67', u'MA68', u'MA69', u'MA70', u'MA71', u'MA72', u'MA73', u'MA74', u'MA75', u'MA76', u'MA77', u'MA78', u'MA79', u'MA80', u'MA81', u'MA82', u'MA83', u'MA84', u'MA85', u'MA86', u'MA87', u'MA88', u'MA89', u'MA90', u'MA91', u'MA92', u'MA93', u'MA94', u'MA95', u'MA96', u'MA97', u'MA98', u'MA99', u'MA100', u'MA101', u'MA102', u'MA103', u'MA104', u'MA105', u'MA106', u'MA107', u'MA108', u'MA109', u'MA110', u'MA111', u'MA112', u'MA113', u'MA114', u'MA115', u'MA116', u'MA117', u'MA118', u'MA119', u'MA120', u'MA121', u'MA122', u'MA123', u'MA124', u'MA125', u'MA126', u'MA127', u'MA128', u'MA129', u'MA130', u'MA131', u'MA132', u'MA133', u'MA134', u'N1', u'N2', u'N3', u'N4', u'N5', u'N6', u'N7', u'N8', u'N9', u'N10', u'N11', u'N12', u'N13', u'N14', u'N15', u'N16', u'N17', u'N18', u'N19', u'N20', u'N21', u'N22', u'N23', u'N24', u'N25', u'N26', u'N27', u'N28', u'N29', u'N30', u'N31', u'N32', u'N33', u'N34', u'N35', u'N36', u'N37', u'N38', u'N39', u'N40', u'N41', u'N42', u'N43', u'N44', u'N45', u'N46', u'N47', u'N48', u'N49', u'N50', u'N51', u'N52', u'N53', u'N54', u'N55', u'N56', u'N57', u'N58', u'N59', u'N60', u'N61', u'N62', u'N63', u'N64', u'N65', u'N66', u'N67', u'N68', u'N69', u'N70', u'N71', u'N72', u'N73', u'N74', u'N75', u'N76', u'N77', u'N78', u'N79', u'N80', u'N81', u'N82', u'N83', u'N84', u'N85', u'N86', u'N87', u'N88', u'N89', u'N90', u'N91', u'N92', u'N93', u'N94', u'N95', u'N96', u'N97', u'N98', u'N99', u'N100', u'N101', u'N102', u'N103', u'N104', u'N105', u'N106', u'N107', u'N108', u'N109', u'N110', u'N111', u'N112', u'N113', u'N114', u'N115', u'N116', u'N117', u'N118', u'N119', u'N120', u'N121', u'N122', u'N123', u'N124', u'N125', u'N126', u'N127', u'N128', u'N129', u'N130', u'N131', u'N132', u'N133', u'N134', u'N135', u'N136', u'N137', u'N138', u'N139', u'N140', u'N141', u'N142', u'N143', u'N144', u'N145', u'N146', u'N147', u'N148', u'N149', u'N150', u'N151', u'N152', u'N153', u'N154', u'N155', u'N156 '] ) ),
  Element( u'MOA08', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=8,
    codes=[] ) ),
  Element( u'MOA09', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=9,
    codes=[] ) ),
),
parsed_837_2330A,
parsed_837_2330B,
parsed_837_2330C,
parsed_837_2330D,
parsed_837_2330E,
parsed_837_2330F,
parsed_837_2330H,
)
parsed_837_2410 = Loop( u'2410', Properties(looptype='',repeat=u'25',pos=u'494',req_sit=u'S',desc=u'Drug Identification'),
Segment( u'LIN', Properties(syntax=u'P0405 P0607 P0809 P1011 P1213 P1415 P1617 P1819 P2021 P2223 P2425 P2627 P2829 P3031',req_sit=u'S',repeat=u'1',pos=u'494',desc=u'Drug Identification'),
  Element( u'LIN01', Properties(desc=u'Assigned Identification', req_sit=u'N', data_type=(u'AN',u'1',u'20'), position=1,
    codes=[] ) ),
  Element( u'LIN02', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[u'N4'] ) ),
  Element( u'LIN03', Properties(desc=u'Product/Service ID', req_sit=u'R', data_type=(u'AN',u'1',u'48'), position=3,
    codes=[] ) ),
  Element( u'LIN04', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=4,
    codes=[u'N4'] ) ),
  Element( u'LIN05', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=5,
    codes=[] ) ),
  Element( u'LIN06', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=6,
    codes=[u'N4'] ) ),
  Element( u'LIN07', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=7,
    codes=[] ) ),
  Element( u'LIN08', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=8,
    codes=[u'N4'] ) ),
  Element( u'LIN09', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=9,
    codes=[] ) ),
  Element( u'LIN10', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[u'N4'] ) ),
  Element( u'LIN11', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=11,
    codes=[] ) ),
  Element( u'LIN12', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=12,
    codes=[u'N4'] ) ),
  Element( u'LIN13', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=13,
    codes=[] ) ),
  Element( u'LIN14', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=14,
    codes=[u'N4'] ) ),
  Element( u'LIN15', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=15,
    codes=[] ) ),
  Element( u'LIN16', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=16,
    codes=[u'N4'] ) ),
  Element( u'LIN17', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=17,
    codes=[] ) ),
  Element( u'LIN18', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=18,
    codes=[u'N4'] ) ),
  Element( u'LIN19', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=19,
    codes=[] ) ),
  Element( u'LIN20', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=20,
    codes=[u'N4'] ) ),
  Element( u'LIN21', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=21,
    codes=[] ) ),
  Element( u'LIN22', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=22,
    codes=[u'N4'] ) ),
  Element( u'LIN23', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=23,
    codes=[] ) ),
  Element( u'LIN24', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=24,
    codes=[u'N4'] ) ),
  Element( u'LIN25', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=25,
    codes=[] ) ),
  Element( u'LIN26', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=26,
    codes=[u'N4'] ) ),
  Element( u'LIN27', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=27,
    codes=[] ) ),
  Element( u'LIN28', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=28,
    codes=[u'N4'] ) ),
  Element( u'LIN29', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=29,
    codes=[] ) ),
  Element( u'LIN30', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=30,
    codes=[u'N4'] ) ),
  Element( u'LIN31', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=31,
    codes=[] ) ),
),
Segment( u'CTP', Properties(syntax=u'P0405 C0607 C0902 C1002 C1103',req_sit=u'S',repeat=u'1',pos=u'495',desc=u'Drug Pricing'),
  Element( u'CTP01', Properties(desc=u'Class of Trade Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[] ) ),
  Element( u'CTP02', Properties(desc=u'Price Identifier Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=2,
    codes=[] ) ),
  Element( u'CTP03', Properties(desc=u'Unit Price', req_sit=u'R', data_type=(u'R',u'1',u'17'), position=3,
    codes=[] ) ),
  Element( u'CTP04', Properties(desc=u'Quantity', req_sit=u'R', data_type=(u'R',u'1',u'15'), position=4,
    codes=[] ) ),
  Composite( u'C001', Properties(req_sit=u'R',refdes='',seq=u'05',desc=u'Composite Unit of Measure'),
    Element( u'CTP05-01', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=0,
      codes=[u'F2', u'GR', u'ML', u'UN'] ) ),
    Element( u'CTP05-02', Properties(desc=u'Exponent', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=1,
      codes=[] ) ),
    Element( u'CTP05-03', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=2,
      codes=[] ) ),
    Element( u'CTP05-04', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=3,
      codes=[] ) ),
    Element( u'CTP05-05', Properties(desc=u'Exponent', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=4,
      codes=[] ) ),
    Element( u'CTP05-06', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=5,
      codes=[] ) ),
    Element( u'CTP05-07', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=6,
      codes=[] ) ),
    Element( u'CTP05-08', Properties(desc=u'Exponent', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=7,
      codes=[] ) ),
    Element( u'CTP05-09', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=8,
      codes=[] ) ),
    Element( u'CTP05-10', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=9,
      codes=[] ) ),
    Element( u'CTP05-11', Properties(desc=u'Exponent', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=10,
      codes=[] ) ),
    Element( u'CTP05-12', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=11,
      codes=[] ) ),
    Element( u'CTP05-13', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=12,
      codes=[] ) ),
    Element( u'CTP05-14', Properties(desc=u'Exponent', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=13,
      codes=[] ) ),
    Element( u'CTP05-15', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=14,
      codes=[] ) ),
  ),
  Element( u'CTP06', Properties(desc=u'Price Multiplier Qualifier', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=6,
    codes=[] ) ),
  Element( u'CTP07', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'CTP08', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=8,
    codes=[] ) ),
  Element( u'CTP09', Properties(desc=u'Basis of Unit Price Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=9,
    codes=[] ) ),
  Element( u'CTP10', Properties(desc=u'Condition Value', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=10,
    codes=[] ) ),
  Element( u'CTP11', Properties(desc=u'Multiple Price Quantity', req_sit=u'N', data_type=(u'N0',u'1',u'2'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'496',desc=u'Prescription Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'XZ'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2420A = Loop( u'2420A', Properties(looptype='',repeat=u'1',pos=u'500',req_sit=u'S',desc=u'Attending Physician Name'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'500',desc=u'Attending Physician Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'71'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'PRV', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'505',desc=u'Attending Physician Specialty Information'),
  Element( u'PRV01', Properties(desc=u'Provider Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'AT'] ) ),
  Element( u'PRV02', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'ZZ'] ) ),
  Element( u'PRV03', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'PRV04', Properties(desc=u'State or Province Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=4,
    codes=[] ) ),
  Composite( u'C035', Properties(req_sit=u'N',refdes='',seq=u'05',desc=u'Provider Specialty Information'),
  ),
  Element( u'PRV06', Properties(desc=u'Provider Organization Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'525',desc=u'Attending Physician Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2420B = Loop( u'2420B', Properties(looptype='',repeat=u'1',pos=u'500',req_sit=u'S',desc=u'Operating Physician Name'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'500',desc=u'Operating Physician Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'72'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'PRV', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'505',desc=u'Operating Physician Specialty Information'),
  Element( u'PRV01', Properties(desc=u'Provider Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'OP'] ) ),
  Element( u'PRV02', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'ZZ'] ) ),
  Element( u'PRV03', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'PRV04', Properties(desc=u'State or Province Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=4,
    codes=[] ) ),
  Composite( u'C035', Properties(req_sit=u'N',refdes='',seq=u'05',desc=u'Provider Specialty Information'),
  ),
  Element( u'PRV06', Properties(desc=u'Provider Organization Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'525',desc=u'Operating Physician Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2420C = Loop( u'2420C', Properties(looptype='',repeat=u'1',pos=u'500',req_sit=u'S',desc=u'Other Provider Name'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'500',desc=u'Other Provider Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'73'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'PRV', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'505',desc=u'Other Provider Specialty Information'),
  Element( u'PRV01', Properties(desc=u'Provider Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'OT', u'PE'] ) ),
  Element( u'PRV02', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'ZZ'] ) ),
  Element( u'PRV03', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'PRV04', Properties(desc=u'State or Province Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=4,
    codes=[] ) ),
  Composite( u'C035', Properties(req_sit=u'N',refdes='',seq=u'05',desc=u'Provider Specialty Information'),
  ),
  Element( u'PRV06', Properties(desc=u'Provider Organization Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'525',desc=u'Other Provider Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2430 = Loop( u'2430', Properties(looptype='',repeat=u'25',pos=u'540',req_sit=u'S',desc=u'Service Line Adjudication Information'),
Segment( u'SVD', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'540',desc=u'Service Line Adjudication Information'),
  Element( u'SVD01', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=1,
    codes=[] ) ),
  Element( u'SVD02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Composite( u'C003', Properties(req_sit=u'S',refdes='',seq=u'03',desc=u'Composite Medical Procedure Identifier'),
    Element( u'SVD03-01', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=0,
      codes=[u'HC', u'IV', u'ZZ'] ) ),
    Element( u'SVD03-02', Properties(desc=u'Product/Service ID', req_sit=u'R', data_type=(u'AN',u'1',u'48'), position=1,
      codes=[] ) ),
    Element( u'SVD03-03', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=2,
      codes=[] ) ),
    Element( u'SVD03-04', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=3,
      codes=[] ) ),
    Element( u'SVD03-05', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=4,
      codes=[] ) ),
    Element( u'SVD03-06', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=5,
      codes=[] ) ),
    Element( u'SVD03-07', Properties(desc=u'Description', req_sit=u'S', data_type=(u'AN',u'1',u'80'), position=6,
      codes=[] ) ),
  ),
  Element( u'SVD04', Properties(desc=u'Product/Service ID', req_sit=u'R', data_type=(u'AN',u'1',u'48'), position=4,
    codes=[] ) ),
  Element( u'SVD05', Properties(desc=u'Quantity', req_sit=u'R', data_type=(u'R',u'1',u'15'), position=5,
    codes=[] ) ),
  Element( u'SVD06', Properties(desc=u'Assigned Number', req_sit=u'S', data_type=(u'N0',u'1',u'6'), position=6,
    codes=[] ) ),
),
Segment( u'CAS', Properties(syntax='',req_sit=u'S',repeat=u'99',pos=u'545',desc=u'Service Line Adjustment'),
  Element( u'CAS01', Properties(desc=u'Claim Adjustment Group Code', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=1,
    codes=[u'CO', u'CR', u'OA', u'PI', u'PR'] ) ),
  Element( u'CAS02', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'R', data_type=(u'ID',u'1',u'5'), position=2,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'10', u'11', u'12', u'13', u'14', u'15', u'16', u'17', u'18', u'19', u'20', u'21', u'22', u'23', u'24', u'25', u'26', u'27', u'28', u'29', u'30', u'31', u'32', u'33', u'34', u'35', u'36', u'37', u'38', u'39', u'40', u'41', u'42', u'43', u'44', u'45', u'46', u'47', u'48', u'49', u'50', u'51', u'52', u'53', u'54', u'55', u'56', u'57', u'58', u'59', u'60', u'61', u'62', u'63', u'64', u'65', u'66', u'67', u'68', u'69', u'70', u'71', u'72', u'73', u'74', u'75', u'76', u'77', u'78', u'79', u'80', u'81', u'82', u'83', u'84', u'85', u'86', u'87', u'88', u'89', u'90', u'91', u'92', u'93', u'94', u'95', u'96', u'97', u'98', u'99', u'100', u'101', u'102', u'103', u'104', u'105', u'106', u'107', u'108', u'109', u'110', u'111', u'112', u'113', u'114', u'115', u'116', u'117', u'118', u'119', u'120', u'121', u'122', u'123', u'124', u'125', u'126', u'127', u'128', u'129', u'130', u'131', u'132', u'133', u'134', u'135', u'136', u'137', u'138', u'139', u'140', u'141', u'142', u'143', u'144', u'145', u'146', u'147', u'148', u'149', u'150', u'151', u'152', u'153', u'154', u'A0', u'A1', u'A2', u'A3', u'A4', u'A5', u'A6', u'A7', u'A8', u'B1', u'B2', u'B3', u'B4', u'B5', u'B6', u'B7', u'B8', u'B9', u'B10', u'B11', u'B12', u'B13', u'B14', u'B15', u'B16', u'B17', u'B18', u'B19', u'B20', u'B21', u'B22', u'B23', u'D1', u'D2', u'D3', u'D4', u'D5', u'D6', u'D7', u'D8', u'D9', u'D10', u'D11', u'D12', u'D13', u'D14', u'D15', u'W1'] ) ),
  Element( u'CAS03', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=3,
    codes=[] ) ),
  Element( u'CAS04', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=4,
    codes=[] ) ),
  Element( u'CAS05', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=5,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'10', u'11', u'12', u'13', u'14', u'15', u'16', u'17', u'18', u'19', u'20', u'21', u'22', u'23', u'24', u'25', u'26', u'27', u'28', u'29', u'30', u'31', u'32', u'33', u'34', u'35', u'36', u'37', u'38', u'39', u'40', u'41', u'42', u'43', u'44', u'45', u'46', u'47', u'48', u'49', u'50', u'51', u'52', u'53', u'54', u'55', u'56', u'57', u'58', u'59', u'60', u'61', u'62', u'63', u'64', u'65', u'66', u'67', u'68', u'69', u'70', u'71', u'72', u'73', u'74', u'75', u'76', u'77', u'78', u'79', u'80', u'81', u'82', u'83', u'84', u'85', u'86', u'87', u'88', u'89', u'90', u'91', u'92', u'93', u'94', u'95', u'96', u'97', u'98', u'99', u'100', u'101', u'102', u'103', u'104', u'105', u'106', u'107', u'108', u'109', u'110', u'111', u'112', u'113', u'114', u'115', u'116', u'117', u'118', u'119', u'120', u'121', u'122', u'123', u'124', u'125', u'126', u'127', u'128', u'129', u'130', u'131', u'132', u'133', u'134', u'135', u'136', u'137', u'138', u'139', u'140', u'141', u'142', u'143', u'144', u'145', u'146', u'147', u'148', u'149', u'150', u'151', u'152', u'153', u'154', u'A0', u'A1', u'A2', u'A3', u'A4', u'A5', u'A6', u'A7', u'A8', u'B1', u'B2', u'B3', u'B4', u'B5', u'B6', u'B7', u'B8', u'B9', u'B10', u'B11', u'B12', u'B13', u'B14', u'B15', u'B16', u'B17', u'B18', u'B19', u'B20', u'B21', u'B22', u'B23', u'D1', u'D2', u'D3', u'D4', u'D5', u'D6', u'D7', u'D8', u'D9', u'D10', u'D11', u'D12', u'D13', u'D14', u'D15', u'W1'] ) ),
  Element( u'CAS06', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=6,
    codes=[] ) ),
  Element( u'CAS07', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=7,
    codes=[] ) ),
  Element( u'CAS08', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=8,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'10', u'11', u'12', u'13', u'14', u'15', u'16', u'17', u'18', u'19', u'20', u'21', u'22', u'23', u'24', u'25', u'26', u'27', u'28', u'29', u'30', u'31', u'32', u'33', u'34', u'35', u'36', u'37', u'38', u'39', u'40', u'41', u'42', u'43', u'44', u'45', u'46', u'47', u'48', u'49', u'50', u'51', u'52', u'53', u'54', u'55', u'56', u'57', u'58', u'59', u'60', u'61', u'62', u'63', u'64', u'65', u'66', u'67', u'68', u'69', u'70', u'71', u'72', u'73', u'74', u'75', u'76', u'77', u'78', u'79', u'80', u'81', u'82', u'83', u'84', u'85', u'86', u'87', u'88', u'89', u'90', u'91', u'92', u'93', u'94', u'95', u'96', u'97', u'98', u'99', u'100', u'101', u'102', u'103', u'104', u'105', u'106', u'107', u'108', u'109', u'110', u'111', u'112', u'113', u'114', u'115', u'116', u'117', u'118', u'119', u'120', u'121', u'122', u'123', u'124', u'125', u'126', u'127', u'128', u'129', u'130', u'131', u'132', u'133', u'134', u'135', u'136', u'137', u'138', u'139', u'140', u'141', u'142', u'143', u'144', u'145', u'146', u'147', u'148', u'149', u'150', u'151', u'152', u'153', u'154', u'A0', u'A1', u'A2', u'A3', u'A4', u'A5', u'A6', u'A7', u'A8', u'B1', u'B2', u'B3', u'B4', u'B5', u'B6', u'B7', u'B8', u'B9', u'B10', u'B11', u'B12', u'B13', u'B14', u'B15', u'B16', u'B17', u'B18', u'B19', u'B20', u'B21', u'B22', u'B23', u'D1', u'D2', u'D3', u'D4', u'D5', u'D6', u'D7', u'D8', u'D9', u'D10', u'D11', u'D12', u'D13', u'D14', u'D15', u'W1'] ) ),
  Element( u'CAS09', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=9,
    codes=[] ) ),
  Element( u'CAS10', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=10,
    codes=[] ) ),
  Element( u'CAS11', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=11,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'10', u'11', u'12', u'13', u'14', u'15', u'16', u'17', u'18', u'19', u'20', u'21', u'22', u'23', u'24', u'25', u'26', u'27', u'28', u'29', u'30', u'31', u'32', u'33', u'34', u'35', u'36', u'37', u'38', u'39', u'40', u'41', u'42', u'43', u'44', u'45', u'46', u'47', u'48', u'49', u'50', u'51', u'52', u'53', u'54', u'55', u'56', u'57', u'58', u'59', u'60', u'61', u'62', u'63', u'64', u'65', u'66', u'67', u'68', u'69', u'70', u'71', u'72', u'73', u'74', u'75', u'76', u'77', u'78', u'79', u'80', u'81', u'82', u'83', u'84', u'85', u'86', u'87', u'88', u'89', u'90', u'91', u'92', u'93', u'94', u'95', u'96', u'97', u'98', u'99', u'100', u'101', u'102', u'103', u'104', u'105', u'106', u'107', u'108', u'109', u'110', u'111', u'112', u'113', u'114', u'115', u'116', u'117', u'118', u'119', u'120', u'121', u'122', u'123', u'124', u'125', u'126', u'127', u'128', u'129', u'130', u'131', u'132', u'133', u'134', u'135', u'136', u'137', u'138', u'139', u'140', u'141', u'142', u'143', u'144', u'145', u'146', u'147', u'148', u'149', u'150', u'151', u'152', u'153', u'154', u'A0', u'A1', u'A2', u'A3', u'A4', u'A5', u'A6', u'A7', u'A8', u'B1', u'B2', u'B3', u'B4', u'B5', u'B6', u'B7', u'B8', u'B9', u'B10', u'B11', u'B12', u'B13', u'B14', u'B15', u'B16', u'B17', u'B18', u'B19', u'B20', u'B21', u'B22', u'B23', u'D1', u'D2', u'D3', u'D4', u'D5', u'D6', u'D7', u'D8', u'D9', u'D10', u'D11', u'D12', u'D13', u'D14', u'D15', u'W1'] ) ),
  Element( u'CAS12', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=12,
    codes=[] ) ),
  Element( u'CAS13', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=13,
    codes=[] ) ),
  Element( u'CAS14', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=14,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'10', u'11', u'12', u'13', u'14', u'15', u'16', u'17', u'18', u'19', u'20', u'21', u'22', u'23', u'24', u'25', u'26', u'27', u'28', u'29', u'30', u'31', u'32', u'33', u'34', u'35', u'36', u'37', u'38', u'39', u'40', u'41', u'42', u'43', u'44', u'45', u'46', u'47', u'48', u'49', u'50', u'51', u'52', u'53', u'54', u'55', u'56', u'57', u'58', u'59', u'60', u'61', u'62', u'63', u'64', u'65', u'66', u'67', u'68', u'69', u'70', u'71', u'72', u'73', u'74', u'75', u'76', u'77', u'78', u'79', u'80', u'81', u'82', u'83', u'84', u'85', u'86', u'87', u'88', u'89', u'90', u'91', u'92', u'93', u'94', u'95', u'96', u'97', u'98', u'99', u'100', u'101', u'102', u'103', u'104', u'105', u'106', u'107', u'108', u'109', u'110', u'111', u'112', u'113', u'114', u'115', u'116', u'117', u'118', u'119', u'120', u'121', u'122', u'123', u'124', u'125', u'126', u'127', u'128', u'129', u'130', u'131', u'132', u'133', u'134', u'135', u'136', u'137', u'138', u'139', u'140', u'141', u'142', u'143', u'144', u'145', u'146', u'147', u'148', u'149', u'150', u'151', u'152', u'153', u'154', u'A0', u'A1', u'A2', u'A3', u'A4', u'A5', u'A6', u'A7', u'A8', u'B1', u'B2', u'B3', u'B4', u'B5', u'B6', u'B7', u'B8', u'B9', u'B10', u'B11', u'B12', u'B13', u'B14', u'B15', u'B16', u'B17', u'B18', u'B19', u'B20', u'B21', u'B22', u'B23', u'D1', u'D2', u'D3', u'D4', u'D5', u'D6', u'D7', u'D8', u'D9', u'D10', u'D11', u'D12', u'D13', u'D14', u'D15', u'W1'] ) ),
  Element( u'CAS15', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=15,
    codes=[] ) ),
  Element( u'CAS16', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=16,
    codes=[] ) ),
  Element( u'CAS17', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=17,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'10', u'11', u'12', u'13', u'14', u'15', u'16', u'17', u'18', u'19', u'20', u'21', u'22', u'23', u'24', u'25', u'26', u'27', u'28', u'29', u'30', u'31', u'32', u'33', u'34', u'35', u'36', u'37', u'38', u'39', u'40', u'41', u'42', u'43', u'44', u'45', u'46', u'47', u'48', u'49', u'50', u'51', u'52', u'53', u'54', u'55', u'56', u'57', u'58', u'59', u'60', u'61', u'62', u'63', u'64', u'65', u'66', u'67', u'68', u'69', u'70', u'71', u'72', u'73', u'74', u'75', u'76', u'77', u'78', u'79', u'80', u'81', u'82', u'83', u'84', u'85', u'86', u'87', u'88', u'89', u'90', u'91', u'92', u'93', u'94', u'95', u'96', u'97', u'98', u'99', u'100', u'101', u'102', u'103', u'104', u'105', u'106', u'107', u'108', u'109', u'110', u'111', u'112', u'113', u'114', u'115', u'116', u'117', u'118', u'119', u'120', u'121', u'122', u'123', u'124', u'125', u'126', u'127', u'128', u'129', u'130', u'131', u'132', u'133', u'134', u'135', u'136', u'137', u'138', u'139', u'140', u'141', u'142', u'143', u'144', u'145', u'146', u'147', u'148', u'149', u'150', u'151', u'152', u'153', u'154', u'A0', u'A1', u'A2', u'A3', u'A4', u'A5', u'A6', u'A7', u'A8', u'B1', u'B2', u'B3', u'B4', u'B5', u'B6', u'B7', u'B8', u'B9', u'B10', u'B11', u'B12', u'B13', u'B14', u'B15', u'B16', u'B17', u'B18', u'B19', u'B20', u'B21', u'B22', u'B23', u'D1', u'D2', u'D3', u'D4', u'D5', u'D6', u'D7', u'D8', u'D9', u'D10', u'D11', u'D12', u'D13', u'D14', u'D15', u'W1'] ) ),
  Element( u'CAS18', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=18,
    codes=[] ) ),
  Element( u'CAS19', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=19,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'550',desc=u'Service Adjudication Date'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'573'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
)
parsed_837_2400 = Loop( u'2400', Properties(looptype='',repeat=u'999',pos=u'365',req_sit=u'R',desc=u'Service Line Number'),
Segment( u'LX', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'365',desc=u'Service Line Number'),
  Element( u'LX01', Properties(desc=u'Assigned Number', req_sit=u'R', data_type=(u'N0',u'1',u'6'), position=1,
    codes=[] ) ),
),
Segment( u'SV2', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'375',desc=u'Institutional Service Line'),
  Element( u'SV201', Properties(desc=u'Product/Service ID', req_sit=u'R', data_type=(u'AN',u'1',u'48'), position=1,
    codes=[] ) ),
  Composite( u'C003', Properties(req_sit=u'S',refdes='',seq=u'02',desc=u'Service Line Procedure Code'),
    Element( u'SV202-01', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=0,
      codes=[u'HC', u'IV', u'N4', u'ZZ'] ) ),
    Element( u'SV202-02', Properties(desc=u'Product/Service ID', req_sit=u'R', data_type=(u'AN',u'1',u'48'), position=1,
      codes=[] ) ),
    Element( u'SV202-03', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=2,
      codes=[] ) ),
    Element( u'SV202-04', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=3,
      codes=[] ) ),
    Element( u'SV202-05', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=4,
      codes=[] ) ),
    Element( u'SV202-06', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=5,
      codes=[] ) ),
    Element( u'SV202-07', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=6,
      codes=[] ) ),
  ),
  Element( u'SV203', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=3,
    codes=[] ) ),
  Element( u'SV204', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=4,
    codes=[u'DA', u'F2', u'UN'] ) ),
  Element( u'SV205', Properties(desc=u'Quantity', req_sit=u'R', data_type=(u'R',u'1',u'15'), position=5,
    codes=[] ) ),
  Element( u'SV206', Properties(desc=u'Unit Rate', req_sit=u'S', data_type=(u'R',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'SV207', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=7,
    codes=[] ) ),
  Element( u'SV208', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=8,
    codes=[] ) ),
  Element( u'SV209', Properties(desc=u'Nursing Home Residential Status Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=9,
    codes=[] ) ),
  Element( u'SV210', Properties(desc=u'Level of Care Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=10,
    codes=[] ) ),
),
Segment( u'PWK', Properties(syntax='',req_sit=u'S',repeat=u'5',pos=u'420',desc=u'Line Supplemental Information'),
  Element( u'PWK01', Properties(desc=u'Report Type Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'AS', u'B2', u'B3', u'B4', u'CT', u'DA', u'DG', u'DS', u'EB', u'MT', u'NN', u'OB', u'OZ', u'PN', u'PO', u'PZ', u'RB', u'RR', u'RT'] ) ),
  Element( u'PWK02', Properties(desc=u'Report Transmission Code', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=2,
    codes=[u'AA', u'AB', u'AD', u'AF', u'AG', u'BM', u'EL', u'EM', u'FX'] ) ),
  Element( u'PWK03', Properties(desc=u'Report Copies Needed', req_sit=u'N', data_type=(u'N0',u'1',u'2'), position=3,
    codes=[] ) ),
  Element( u'PWK04', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'PWK05', Properties(desc=u'Identification Code Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[u'AC'] ) ),
  Element( u'PWK06', Properties(desc=u'Identification Code', req_sit=u'S', data_type=(u'AN',u'2',u'80'), position=6,
    codes=[] ) ),
  Element( u'PWK07', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=7,
    codes=[] ) ),
  Composite( u'C002', Properties(req_sit=u'N',refdes='',seq=u'08',desc=u'Actions Indicated'),
  ),
  Element( u'PWK09', Properties(desc=u'Request Category Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=9,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'455',desc=u'Service Line Date'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'472'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8', u'RD8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'455',desc=u'Assessment Date'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'866'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'475',desc=u'Service Tax Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'GT'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'475',desc=u'Facility Tax Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'N8'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'HCP', Properties(syntax=u'R0113 P0910 P1112',req_sit=u'S',repeat=u'1',pos=u'492',desc=u'Line Pricing/Repricing Information'),
  Element( u'HCP01', Properties(desc=u'Pricing Methodology', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'00', u'01', u'02', u'03', u'04', u'05', u'06', u'07', u'08', u'09', u'10', u'11', u'12', u'13', u'14'] ) ),
  Element( u'HCP02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'HCP03', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=3,
    codes=[] ) ),
  Element( u'HCP04', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=4,
    codes=[] ) ),
  Element( u'HCP05', Properties(desc=u'Rate', req_sit=u'S', data_type=(u'R',u'1',u'9'), position=5,
    codes=[] ) ),
  Element( u'HCP06', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=6,
    codes=[] ) ),
  Element( u'HCP07', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=7,
    codes=[] ) ),
  Element( u'HCP08', Properties(desc=u'Product/Service ID', req_sit=u'S', data_type=(u'AN',u'1',u'48'), position=8,
    codes=[] ) ),
  Element( u'HCP09', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=9,
    codes=[u'HC'] ) ),
  Element( u'HCP10', Properties(desc=u'Product/Service ID', req_sit=u'S', data_type=(u'AN',u'1',u'48'), position=10,
    codes=[] ) ),
  Element( u'HCP11', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=11,
    codes=[u'DA', u'UN'] ) ),
  Element( u'HCP12', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=12,
    codes=[] ) ),
  Element( u'HCP13', Properties(desc=u'Reject Reason Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=13,
    codes=[u'T1', u'T2', u'T3', u'T4', u'T5', u'T6'] ) ),
  Element( u'HCP14', Properties(desc=u'Policy Compliance Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=14,
    codes=[u'1', u'2', u'3', u'4', u'5'] ) ),
  Element( u'HCP15', Properties(desc=u'Exception Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=15,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6'] ) ),
),
parsed_837_2410,
parsed_837_2420A,
parsed_837_2420B,
parsed_837_2420C,
parsed_837_2430,
)
parsed_837_2300 = Loop( u'2300', Properties(looptype='',repeat=u'100',pos=u'130',req_sit=u'S',desc=u'Claim Information'),
Segment( u'CLM', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'130',desc=u'Claim Information'),
  Element( u'CLM01', Properties(desc=u"Claim Submitter's Identifier", req_sit=u'R', data_type=(u'AN',u'1',u'38'), position=1,
    codes=[] ) ),
  Element( u'CLM02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'CLM03', Properties(desc=u'Claim Filing Indicator Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=3,
    codes=[] ) ),
  Element( u'CLM04', Properties(desc=u'Non-Institutional Claim Type Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=4,
    codes=[] ) ),
  Composite( u'C023', Properties(req_sit=u'R',refdes='',seq=u'05',desc=u'Type of Bill'),
    Element( u'CLM05-01', Properties(desc=u'Facility Code Value', req_sit=u'R', data_type=(u'AN',u'1',u'2'), position=0,
      codes=[] ) ),
    Element( u'CLM05-02', Properties(desc=u'Facility Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=1,
      codes=[u'A'] ) ),
    Element( u'CLM05-03', Properties(desc=u'Claim Frequency Type Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
      codes=[u'0', u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'A', u'B', u'C', u'D', u'E', u'F', u'G', u'H', u'I', u'J', u'K', u'L', u'M', u'N', u'O', u'X', u'Y', u'Z '] ) ),
  ),
  Element( u'CLM06', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=6,
    codes=[u'N', u'Y'] ) ),
  Element( u'CLM07', Properties(desc=u'Provider Accept Assignment Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=7,
    codes=[u'A', u'C'] ) ),
  Element( u'CLM08', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=8,
    codes=[u'N', u'Y'] ) ),
  Element( u'CLM09', Properties(desc=u'Release of Information Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=9,
    codes=[u'A', u'I', u'M', u'N', u'O', u'Y'] ) ),
  Element( u'CLM10', Properties(desc=u'Patient Signature Source Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=10,
    codes=[] ) ),
  Composite( u'C024', Properties(req_sit=u'N',refdes='',seq=u'11',desc=u'Property and Casualty Related Causes Codes'),
  ),
  Element( u'CLM12', Properties(desc=u'Special Program Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=12,
    codes=[u'01', u'02', u'03', u'05', u'07', u'08', u'09'] ) ),
  Element( u'CLM13', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=13,
    codes=[] ) ),
  Element( u'CLM14', Properties(desc=u'Level of Service Code', req_sit=u'N', data_type=(u'ID',u'1',u'3'), position=14,
    codes=[] ) ),
  Element( u'CLM15', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=15,
    codes=[] ) ),
  Element( u'CLM16', Properties(desc=u'Provider Agreement Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=16,
    codes=[] ) ),
  Element( u'CLM17', Properties(desc=u'Claim Status Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=17,
    codes=[] ) ),
  Element( u'CLM18', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=18,
    codes=[u'N', u'Y'] ) ),
  Element( u'CLM19', Properties(desc=u'Claim Submission Reason Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=19,
    codes=[] ) ),
  Element( u'CLM20', Properties(desc=u'Delay Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=20,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'10', u'11'] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'135',desc=u'Discharge Hour'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'096'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'TM'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'135',desc=u'Statement Dates'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'434'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8', u'RD8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'135',desc=u'Admission Date/Hour'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'435'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'DT'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'CL1', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'140',desc=u'Institutional Claim Code'),
  Element( u'CL101', Properties(desc=u'Admission Type Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=1,
    codes=[] ) ),
  Element( u'CL102', Properties(desc=u'Admission Source Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[] ) ),
  Element( u'CL103', Properties(desc=u'Patient Status Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=3,
    codes=[] ) ),
  Element( u'CL104', Properties(desc=u'Nursing Home Residential Status Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[] ) ),
),
Segment( u'PWK', Properties(syntax='',req_sit=u'S',repeat=u'10',pos=u'155',desc=u'Claim Supplemental Information'),
  Element( u'PWK01', Properties(desc=u'Report Type Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'AS', u'B2', u'B3', u'B4', u'CT', u'DA', u'DG', u'DS', u'EB', u'MT', u'NN', u'OB', u'OZ', u'PN', u'PO', u'PZ', u'RB', u'RR', u'RT'] ) ),
  Element( u'PWK02', Properties(desc=u'Report Transmission Code', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=2,
    codes=[u'AA', u'BM', u'EL', u'EM', u'FX'] ) ),
  Element( u'PWK03', Properties(desc=u'Report Copies Needed', req_sit=u'N', data_type=(u'N0',u'1',u'2'), position=3,
    codes=[] ) ),
  Element( u'PWK04', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'PWK05', Properties(desc=u'Identification Code Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[u'AC'] ) ),
  Element( u'PWK06', Properties(desc=u'Identification Code', req_sit=u'S', data_type=(u'AN',u'2',u'80'), position=6,
    codes=[] ) ),
  Element( u'PWK07', Properties(desc=u'Description', req_sit=u'S', data_type=(u'AN',u'1',u'80'), position=7,
    codes=[] ) ),
  Composite( u'C002', Properties(req_sit=u'N',refdes='',seq=u'08',desc=u'Actions Indicated'),
  ),
  Element( u'PWK09', Properties(desc=u'Request Category Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=9,
    codes=[] ) ),
),
Segment( u'CN1', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'160',desc=u'Contract Information'),
  Element( u'CN101', Properties(desc=u'Contract Type Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'01', u'02', u'03', u'04', u'05', u'06', u'09'] ) ),
  Element( u'CN102', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'CN103', Properties(desc=u'Percent, Decimal Format', req_sit=u'S', data_type=(u'R',u'1',u'6'), position=3,
    codes=[] ) ),
  Element( u'CN104', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=4,
    codes=[] ) ),
  Element( u'CN105', Properties(desc=u'Terms Discount Percent', req_sit=u'S', data_type=(u'R',u'1',u'6'), position=5,
    codes=[] ) ),
  Element( u'CN106', Properties(desc=u'Version Identifier', req_sit=u'S', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'175',desc=u'Payer Estimated Amount Due'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'C5'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'175',desc=u'Patient Estimated Amount Due'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'F3'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'175',desc=u'Patient Paid Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'F5'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'175',desc=u'Credit/Debit Card Maximum Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'MA'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Adjusted Repriced Claim Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'9C'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Repriced Claim Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'9A'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Claim Identification Number For Clearinghouses and Other Transmission Intermediaries'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'D9'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'2',pos=u'180',desc=u'Document Identification Code'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'DD'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Original Reference Number (ICN/DCN)'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'F8'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Investigational Device Exemption Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'LX'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Service Authorization Exception Code'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'4N'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7'] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Peer Review Organization (PRO) Approval Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'G4'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'2',pos=u'180',desc=u'Prior Authorization or Referral Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'9F', u'G1'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Medical Record Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'EA'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Demonstration Project Identifier'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'P4'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'K3', Properties(syntax='',req_sit=u'S',repeat=u'10',pos=u'185',desc=u'File Information'),
  Element( u'K301', Properties(desc=u'Fixed Format Information', req_sit=u'R', data_type=(u'AN',u'1',u'80'), position=1,
    codes=[] ) ),
  Element( u'K302', Properties(desc=u'Record Format Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=2,
    codes=[] ) ),
  Composite( u'C001', Properties(req_sit=u'N',refdes='',seq=u'03',desc=u'Composite Unit of Measure'),
  ),
),
Segment( u'NTE', Properties(syntax='',req_sit=u'S',repeat=u'10',pos=u'190',desc=u'Claim Note'),
  Element( u'NTE01', Properties(desc=u'Note Reference Code', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'ALG', u'DCP', u'DGN', u'DME', u'MED', u'NTR', u'ODT', u'RHB', u'RLH', u'RNH', u'SET', u'SFM', u'SPT', u'UPI'] ) ),
  Element( u'NTE02', Properties(desc=u'Description', req_sit=u'R', data_type=(u'AN',u'1',u'80'), position=2,
    codes=[] ) ),
),
Segment( u'NTE', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'190',desc=u'Billing Note'),
  Element( u'NTE01', Properties(desc=u'Note Reference Code', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'ADD'] ) ),
  Element( u'NTE02', Properties(desc=u'Description', req_sit=u'R', data_type=(u'AN',u'1',u'80'), position=2,
    codes=[] ) ),
),
Segment( u'CR6', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'216',desc=u'Home Health Care Information'),
  Element( u'CR601', Properties(desc=u'Prognosis Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=1,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8'] ) ),
  Element( u'CR602', Properties(desc=u'Date', req_sit=u'R', data_type=(u'DT',u'8',u'8'), position=2,
    codes=[] ) ),
  Element( u'CR603', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=3,
    codes=[u'RD8'] ) ),
  Element( u'CR604', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'CR605', Properties(desc=u'Date', req_sit=u'R', data_type=(u'DT',u'8',u'8'), position=5,
    codes=[] ) ),
  Element( u'CR606', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=6,
    codes=[u'N', u'U', u'Y'] ) ),
  Element( u'CR607', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=7,
    codes=[u'N', u'Y'] ) ),
  Element( u'CR608', Properties(desc=u'Certification Type Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=8,
    codes=[u'I', u'R', u'S'] ) ),
  Element( u'CR609', Properties(desc=u'Date', req_sit=u'S', data_type=(u'DT',u'8',u'8'), position=9,
    codes=[] ) ),
  Element( u'CR610', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[u'HC', u'ID'] ) ),
  Element( u'CR611', Properties(desc=u'Medical Code Value', req_sit=u'S', data_type=(u'AN',u'1',u'15'), position=11,
    codes=[] ) ),
  Element( u'CR612', Properties(desc=u'Date', req_sit=u'S', data_type=(u'DT',u'8',u'8'), position=12,
    codes=[] ) ),
  Element( u'CR613', Properties(desc=u'Date', req_sit=u'S', data_type=(u'DT',u'8',u'8'), position=13,
    codes=[] ) ),
  Element( u'CR614', Properties(desc=u'Date', req_sit=u'S', data_type=(u'DT',u'8',u'8'), position=14,
    codes=[] ) ),
  Element( u'CR615', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=15,
    codes=[u'RD8'] ) ),
  Element( u'CR616', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=16,
    codes=[] ) ),
  Element( u'CR617', Properties(desc=u'Patient Location Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=17,
    codes=[u'A', u'B', u'C', u'D', u'E', u'F', u'G', u'H', u'L', u'M', u'O', u'R', u'S', u'T'] ) ),
  Element( u'CR618', Properties(desc=u'Date', req_sit=u'S', data_type=(u'DT',u'8',u'8'), position=18,
    codes=[] ) ),
  Element( u'CR619', Properties(desc=u'Date', req_sit=u'S', data_type=(u'DT',u'8',u'8'), position=19,
    codes=[] ) ),
  Element( u'CR620', Properties(desc=u'Date', req_sit=u'S', data_type=(u'DT',u'8',u'8'), position=20,
    codes=[] ) ),
  Element( u'CR621', Properties(desc=u'Date', req_sit=u'S', data_type=(u'DT',u'8',u'8'), position=21,
    codes=[] ) ),
),
Segment( u'CRC', Properties(syntax='',req_sit=u'S',repeat=u'3',pos=u'220',desc=u'Home Health Functional Limitations'),
  Element( u'CRC01', Properties(desc=u'Code Category', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'75'] ) ),
  Element( u'CRC02', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'N', u'Y'] ) ),
  Element( u'CRC03', Properties(desc=u'Condition Indicator', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=3,
    codes=[u'AA', u'AL', u'BL', u'CO', u'DY', u'EL', u'HL', u'LB', u'OL', u'PA', u'SL'] ) ),
  Element( u'CRC04', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[u'AA', u'AL', u'BL', u'CO', u'DY', u'EL', u'HL', u'LB', u'OL', u'PA', u'SL'] ) ),
  Element( u'CRC05', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=5,
    codes=[u'AA', u'AL', u'BL', u'CO', u'DY', u'EL', u'HL', u'LB', u'OL', u'PA', u'SL'] ) ),
  Element( u'CRC06', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=6,
    codes=[u'AA', u'AL', u'BL', u'CO', u'DY', u'EL', u'HL', u'LB', u'OL', u'PA', u'SL'] ) ),
  Element( u'CRC07', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=7,
    codes=[u'AA', u'AL', u'BL', u'CO', u'DY', u'EL', u'HL', u'LB', u'OL', u'PA', u'SL'] ) ),
),
Segment( u'CRC', Properties(syntax='',req_sit=u'S',repeat=u'3',pos=u'220',desc=u'Home Health Activities Permitted'),
  Element( u'CRC01', Properties(desc=u'Code Category', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'76'] ) ),
  Element( u'CRC02', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'N', u'Y'] ) ),
  Element( u'CRC03', Properties(desc=u'Condition Indicator', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=3,
    codes=[u'BR', u'CA', u'CB', u'CR', u'EP', u'IH', u'NR', u'PW', u'TR', u'UT', u'WA', u'WR'] ) ),
  Element( u'CRC04', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[u'BR', u'CA', u'CB', u'CR', u'EP', u'IH', u'NR', u'PW', u'TR', u'UT', u'WA', u'WR'] ) ),
  Element( u'CRC05', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=5,
    codes=[u'BR', u'CA', u'CB', u'CR', u'EP', u'IH', u'NR', u'PW', u'TR', u'UT', u'WA', u'WR'] ) ),
  Element( u'CRC06', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=6,
    codes=[u'BR', u'CA', u'CB', u'CR', u'EP', u'IH', u'NR', u'PW', u'TR', u'UT', u'WA', u'WR'] ) ),
  Element( u'CRC07', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=7,
    codes=[u'BR', u'CA', u'CB', u'CR', u'EP', u'IH', u'NR', u'PW', u'TR', u'UT', u'WA', u'WR'] ) ),
),
Segment( u'CRC', Properties(syntax='',req_sit=u'S',repeat=u'2',pos=u'220',desc=u'Home Health Mental Status'),
  Element( u'CRC01', Properties(desc=u'Code Category', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'77'] ) ),
  Element( u'CRC02', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'N', u'Y'] ) ),
  Element( u'CRC03', Properties(desc=u'Condition Indicator', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=3,
    codes=[u'AG', u'CM', u'DI', u'DP', u'FO', u'LE', u'MC', u'OT'] ) ),
  Element( u'CRC04', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[u'AG', u'CM', u'DI', u'DP', u'FO', u'LE', u'MC', u'OT'] ) ),
  Element( u'CRC05', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=5,
    codes=[u'AG', u'CM', u'DI', u'DP', u'FO', u'LE', u'MC', u'OT'] ) ),
  Element( u'CRC06', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=6,
    codes=[u'AG', u'CM', u'DI', u'DP', u'FO', u'LE', u'MC', u'OT'] ) ),
  Element( u'CRC07', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=7,
    codes=[u'AG', u'CM', u'DI', u'DP', u'FO', u'LE', u'MC', u'OT'] ) ),
),
Segment( u'HI', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'231',desc=u'Principal, Admitting, E-Code and Patient Reason for Visit Diagnosis Information'),
  Composite( u'C022', Properties(req_sit=u'R',refdes='',seq=u'01',desc=u'Health Care Code Information'),
    Element( u'HI01-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BK'] ) ),
    Element( u'HI01-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI01-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI01-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI01-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI01-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI01-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'02',desc=u'Health Care Code Information'),
    Element( u'HI02-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BJ', u'ZZ'] ) ),
    Element( u'HI02-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI02-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI02-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI02-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI02-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI02-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'03',desc=u'Health Care Code Information'),
    Element( u'HI03-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BN'] ) ),
    Element( u'HI03-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI03-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI03-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI03-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI03-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI03-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'05',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'06',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'07',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'08',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'09',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'10',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'11',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'12',desc=u'Health Care Code Information'),
  ),
),
Segment( u'HI', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'231',desc=u'Diagnosis Related Group (DRG) Information'),
  Composite( u'C022', Properties(req_sit=u'R',refdes='',seq=u'01',desc=u'Health Care Code Information'),
    Element( u'HI01-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'DR'] ) ),
    Element( u'HI01-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI01-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI01-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI01-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI01-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI01-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'02',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'03',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'05',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'06',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'07',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'08',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'09',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'10',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'11',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'12',desc=u'Health Care Code Information'),
  ),
),
Segment( u'HI', Properties(syntax='',req_sit=u'S',repeat=u'2',pos=u'231',desc=u'Other Diagnosis Information'),
  Composite( u'C022', Properties(req_sit=u'R',refdes='',seq=u'01',desc=u'Health Care Code Information'),
    Element( u'HI01-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI01-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI01-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI01-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI01-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI01-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI01-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'02',desc=u'Health Care Code Information'),
    Element( u'HI02-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI02-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI02-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI02-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI02-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI02-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI02-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'03',desc=u'Health Care Code Information'),
    Element( u'HI03-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI03-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI03-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI03-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI03-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI03-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI03-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'04',desc=u'Health Care Code Information'),
    Element( u'HI04-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI04-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI04-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI04-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI04-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI04-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI04-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'05',desc=u'Health Care Code Information'),
    Element( u'HI05-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI05-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI05-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI05-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI05-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI05-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI05-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'06',desc=u'Health Care Code Information'),
    Element( u'HI06-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI06-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI06-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI06-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI06-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI06-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI06-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'07',desc=u'Health Care Code Information'),
    Element( u'HI07-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI07-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI07-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI07-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI07-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI07-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI07-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'08',desc=u'Health Care Code Information'),
    Element( u'HI08-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI08-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI08-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI08-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI08-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI08-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI08-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'09',desc=u'Health Care Code Information'),
    Element( u'HI09-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI09-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI09-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI09-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI09-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI09-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI09-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'10',desc=u'Health Care Code Information'),
    Element( u'HI10-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI10-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI10-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI10-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI10-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI10-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI10-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'11',desc=u'Health Care Code Information'),
    Element( u'HI11-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI11-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI11-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI11-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI11-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI11-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI11-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'12',desc=u'Health Care Code Information'),
    Element( u'HI12-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI12-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI12-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI12-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI12-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI12-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI12-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
),
Segment( u'HI', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'231',desc=u'Principal Procedure Information'),
  Composite( u'C022', Properties(req_sit=u'R',refdes='',seq=u'01',desc=u'Health Care Code Information'),
    Element( u'HI01-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BP', u'BR'] ) ),
    Element( u'HI01-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI01-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI01-04', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI01-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI01-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI01-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'02',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'03',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'05',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'06',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'07',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'08',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'09',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'10',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'11',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'12',desc=u'Health Care Code Information'),
  ),
),
Segment( u'HI', Properties(syntax='',req_sit=u'S',repeat=u'2',pos=u'231',desc=u'Other Procedure Information'),
  Composite( u'C022', Properties(req_sit=u'R',refdes='',seq=u'01',desc=u'Health Care Code Information'),
    Element( u'HI01-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BO', u'BQ'] ) ),
    Element( u'HI01-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI01-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI01-04', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI01-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI01-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI01-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'02',desc=u'Health Care Code Information'),
    Element( u'HI02-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BO', u'BQ'] ) ),
    Element( u'HI02-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI02-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI02-04', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI02-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI02-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI02-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'03',desc=u'Health Care Code Information'),
    Element( u'HI03-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BO', u'BQ'] ) ),
    Element( u'HI03-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI03-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI03-04', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI03-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI03-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI03-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'04',desc=u'Health Care Code Information'),
    Element( u'HI04-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BO', u'BQ'] ) ),
    Element( u'HI04-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI04-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI04-04', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI04-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI04-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI04-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'05',desc=u'Health Care Code Information'),
    Element( u'HI05-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BO', u'BQ'] ) ),
    Element( u'HI05-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI05-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI05-04', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI05-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI05-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI05-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'06',desc=u'Health Care Code Information'),
    Element( u'HI06-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BO', u'BQ'] ) ),
    Element( u'HI06-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI06-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI06-04', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI06-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI06-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI06-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'07',desc=u'Health Care Code Information'),
    Element( u'HI07-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BO', u'BQ'] ) ),
    Element( u'HI07-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI07-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI07-04', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI07-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI07-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI07-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'08',desc=u'Health Care Code Information'),
    Element( u'HI08-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BO', u'BQ'] ) ),
    Element( u'HI08-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI08-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI08-04', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI08-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI08-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI08-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'09',desc=u'Health Care Code Information'),
    Element( u'HI09-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BO', u'BQ'] ) ),
    Element( u'HI09-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI09-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI09-04', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI09-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI09-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI09-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'10',desc=u'Health Care Code Information'),
    Element( u'HI10-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BO', u'BQ'] ) ),
    Element( u'HI10-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI10-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI10-04', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI10-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI10-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI10-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'11',desc=u'Health Care Code Information'),
    Element( u'HI11-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BO', u'BQ'] ) ),
    Element( u'HI11-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI11-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI11-04', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI11-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI11-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI11-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'12',desc=u'Health Care Code Information'),
    Element( u'HI12-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BO', u'BQ'] ) ),
    Element( u'HI12-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI12-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI12-04', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI12-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI12-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI12-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
),
Segment( u'HI', Properties(syntax='',req_sit=u'S',repeat=u'2',pos=u'231',desc=u'Occurrence Span Information'),
  Composite( u'C022', Properties(req_sit=u'R',refdes='',seq=u'01',desc=u'Health Care Code Information'),
    Element( u'HI01-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BI'] ) ),
    Element( u'HI01-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI01-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'RD8'] ) ),
    Element( u'HI01-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI01-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI01-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI01-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'02',desc=u'Health Care Code Information'),
    Element( u'HI02-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BI'] ) ),
    Element( u'HI02-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI02-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'RD8'] ) ),
    Element( u'HI02-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI02-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI02-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI02-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'03',desc=u'Health Care Code Information'),
    Element( u'HI03-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BI'] ) ),
    Element( u'HI03-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI03-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'RD8'] ) ),
    Element( u'HI03-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI03-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI03-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI03-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'04',desc=u'Health Care Code Information'),
    Element( u'HI04-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BI'] ) ),
    Element( u'HI04-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI04-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'RD8'] ) ),
    Element( u'HI04-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI04-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI04-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI04-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'05',desc=u'Health Care Code Information'),
    Element( u'HI05-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BI'] ) ),
    Element( u'HI05-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI05-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'RD8'] ) ),
    Element( u'HI05-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI05-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI05-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI05-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'06',desc=u'Health Care Code Information'),
    Element( u'HI06-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BI'] ) ),
    Element( u'HI06-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI06-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'RD8'] ) ),
    Element( u'HI06-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI06-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI06-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI06-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'07',desc=u'Health Care Code Information'),
    Element( u'HI07-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BI'] ) ),
    Element( u'HI07-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI07-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'RD8'] ) ),
    Element( u'HI07-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI07-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI07-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI07-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'08',desc=u'Health Care Code Information'),
    Element( u'HI08-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BI'] ) ),
    Element( u'HI08-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI08-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'RD8'] ) ),
    Element( u'HI08-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI08-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI08-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI08-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'09',desc=u'Health Care Code Information'),
    Element( u'HI09-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BI'] ) ),
    Element( u'HI09-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI09-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'RD8'] ) ),
    Element( u'HI09-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI09-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI09-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI09-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'10',desc=u'Health Care Code Information'),
    Element( u'HI10-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BI'] ) ),
    Element( u'HI10-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI10-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'RD8'] ) ),
    Element( u'HI10-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI10-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI10-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI10-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'11',desc=u'Health Care Code Information'),
    Element( u'HI11-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BI'] ) ),
    Element( u'HI11-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI11-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'RD8'] ) ),
    Element( u'HI11-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI11-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI11-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI11-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'12',desc=u'Health Care Code Information'),
    Element( u'HI12-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BI'] ) ),
    Element( u'HI12-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI12-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'RD8'] ) ),
    Element( u'HI12-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI12-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI12-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI12-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
),
Segment( u'HI', Properties(syntax='',req_sit=u'S',repeat=u'2',pos=u'231',desc=u'Occurrence Information'),
  Composite( u'C022', Properties(req_sit=u'R',refdes='',seq=u'01',desc=u'Health Care Code Information'),
    Element( u'HI01-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BH'] ) ),
    Element( u'HI01-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI01-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI01-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI01-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI01-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI01-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'02',desc=u'Health Care Code Information'),
    Element( u'HI02-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BH'] ) ),
    Element( u'HI02-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI02-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI02-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI02-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI02-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI02-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'03',desc=u'Health Care Code Information'),
    Element( u'HI03-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BH'] ) ),
    Element( u'HI03-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI03-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI03-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI03-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI03-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI03-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'04',desc=u'Health Care Code Information'),
    Element( u'HI04-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BH'] ) ),
    Element( u'HI04-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI04-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI04-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI04-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI04-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI04-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'05',desc=u'Health Care Code Information'),
    Element( u'HI05-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BH'] ) ),
    Element( u'HI05-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI05-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI05-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI05-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI05-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI05-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'06',desc=u'Health Care Code Information'),
    Element( u'HI06-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BH'] ) ),
    Element( u'HI06-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI06-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI06-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI06-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI06-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI06-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'07',desc=u'Health Care Code Information'),
    Element( u'HI07-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BH'] ) ),
    Element( u'HI07-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI07-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI07-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI07-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI07-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI07-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'08',desc=u'Health Care Code Information'),
    Element( u'HI08-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BH'] ) ),
    Element( u'HI08-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI08-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI08-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI08-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI08-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI08-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'09',desc=u'Health Care Code Information'),
    Element( u'HI09-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BH'] ) ),
    Element( u'HI09-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI09-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI09-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI09-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI09-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI09-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'10',desc=u'Health Care Code Information'),
    Element( u'HI10-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BH'] ) ),
    Element( u'HI10-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI10-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI10-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI10-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI10-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI10-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'11',desc=u'Health Care Code Information'),
    Element( u'HI11-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BH'] ) ),
    Element( u'HI11-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI11-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI11-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI11-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI11-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI11-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'12',desc=u'Health Care Code Information'),
    Element( u'HI12-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BH'] ) ),
    Element( u'HI12-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI12-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI12-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI12-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI12-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI12-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
),
Segment( u'HI', Properties(syntax='',req_sit=u'S',repeat=u'2',pos=u'231',desc=u'Value Information'),
  Composite( u'C022', Properties(req_sit=u'R',refdes='',seq=u'01',desc=u'Health Care Code Information'),
    Element( u'HI01-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BE'] ) ),
    Element( u'HI01-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI01-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI01-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI01-05', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI01-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI01-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'02',desc=u'Health Care Code Information'),
    Element( u'HI02-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BE'] ) ),
    Element( u'HI02-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI02-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI02-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI02-05', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI02-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI02-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'03',desc=u'Health Care Code Information'),
    Element( u'HI03-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BE'] ) ),
    Element( u'HI03-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI03-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI03-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI03-05', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI03-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI03-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'04',desc=u'Health Care Code Information'),
    Element( u'HI04-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BE'] ) ),
    Element( u'HI04-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI04-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI04-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI04-05', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI04-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI04-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'05',desc=u'Health Care Code Information'),
    Element( u'HI05-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BE'] ) ),
    Element( u'HI05-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI05-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI05-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI05-05', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI05-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI05-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'06',desc=u'Health Care Code Information'),
    Element( u'HI06-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BE'] ) ),
    Element( u'HI06-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI06-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI06-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI06-05', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI06-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI06-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'07',desc=u'Health Care Code Information'),
    Element( u'HI07-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BE'] ) ),
    Element( u'HI07-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI07-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI07-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI07-05', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI07-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI07-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'08',desc=u'Health Care Code Information'),
    Element( u'HI08-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BE'] ) ),
    Element( u'HI08-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI08-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI08-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI08-05', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI08-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI08-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'09',desc=u'Health Care Code Information'),
    Element( u'HI09-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BE'] ) ),
    Element( u'HI09-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI09-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI09-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI09-05', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI09-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI09-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'10',desc=u'Health Care Code Information'),
    Element( u'HI10-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BE'] ) ),
    Element( u'HI10-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI10-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI10-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI10-05', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI10-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI10-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'11',desc=u'Health Care Code Information'),
    Element( u'HI11-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BE'] ) ),
    Element( u'HI11-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI11-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI11-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI11-05', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI11-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI11-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'12',desc=u'Health Care Code Information'),
    Element( u'HI12-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BE'] ) ),
    Element( u'HI12-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI12-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI12-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI12-05', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI12-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI12-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
),
Segment( u'HI', Properties(syntax='',req_sit=u'S',repeat=u'2',pos=u'231',desc=u'Condition Information'),
  Composite( u'C022', Properties(req_sit=u'R',refdes='',seq=u'01',desc=u'Health Care Code Information'),
    Element( u'HI01-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BG'] ) ),
    Element( u'HI01-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI01-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI01-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI01-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI01-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI01-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'02',desc=u'Health Care Code Information'),
    Element( u'HI02-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BG'] ) ),
    Element( u'HI02-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI02-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI02-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI02-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI02-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI02-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'03',desc=u'Health Care Code Information'),
    Element( u'HI03-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BG'] ) ),
    Element( u'HI03-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI03-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI03-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI03-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI03-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI03-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'04',desc=u'Health Care Code Information'),
    Element( u'HI04-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BG'] ) ),
    Element( u'HI04-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI04-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI04-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI04-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI04-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI04-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'05',desc=u'Health Care Code Information'),
    Element( u'HI05-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BG'] ) ),
    Element( u'HI05-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI05-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI05-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI05-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI05-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI05-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'06',desc=u'Health Care Code Information'),
    Element( u'HI06-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BG'] ) ),
    Element( u'HI06-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI06-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI06-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI06-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI06-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI06-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'07',desc=u'Health Care Code Information'),
    Element( u'HI07-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BG'] ) ),
    Element( u'HI07-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI07-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI07-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI07-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI07-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI07-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'08',desc=u'Health Care Code Information'),
    Element( u'HI08-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BG'] ) ),
    Element( u'HI08-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI08-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI08-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI08-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI08-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI08-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'09',desc=u'Health Care Code Information'),
    Element( u'HI09-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BG'] ) ),
    Element( u'HI09-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI09-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI09-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI09-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI09-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI09-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'10',desc=u'Health Care Code Information'),
    Element( u'HI10-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BG'] ) ),
    Element( u'HI10-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI10-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI10-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI10-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI10-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI10-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'11',desc=u'Health Care Code Information'),
    Element( u'HI11-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BG'] ) ),
    Element( u'HI11-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI11-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI11-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI11-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI11-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI11-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'12',desc=u'Health Care Code Information'),
    Element( u'HI12-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BG'] ) ),
    Element( u'HI12-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI12-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI12-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI12-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI12-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI12-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
),
Segment( u'HI', Properties(syntax='',req_sit=u'S',repeat=u'2',pos=u'231',desc=u'Treatment Code Information'),
  Composite( u'C022', Properties(req_sit=u'R',refdes='',seq=u'01',desc=u'Health Care Code Information'),
    Element( u'HI01-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'TC'] ) ),
    Element( u'HI01-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI01-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI01-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI01-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI01-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI01-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'02',desc=u'Health Care Code Information'),
    Element( u'HI02-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'TC'] ) ),
    Element( u'HI02-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI02-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI02-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI02-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI02-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI02-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'03',desc=u'Health Care Code Information'),
    Element( u'HI03-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'TC'] ) ),
    Element( u'HI03-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI03-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI03-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI03-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI03-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI03-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'04',desc=u'Health Care Code Information'),
    Element( u'HI04-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'TC'] ) ),
    Element( u'HI04-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI04-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI04-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI04-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI04-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI04-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'05',desc=u'Health Care Code Information'),
    Element( u'HI05-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'TC'] ) ),
    Element( u'HI05-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI05-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI05-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI05-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI05-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI05-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'06',desc=u'Health Care Code Information'),
    Element( u'HI06-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'TC'] ) ),
    Element( u'HI06-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI06-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI06-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI06-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI06-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI06-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'07',desc=u'Health Care Code Information'),
    Element( u'HI07-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'TC'] ) ),
    Element( u'HI07-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI07-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI07-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI07-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI07-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI07-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'08',desc=u'Health Care Code Information'),
    Element( u'HI08-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'TC'] ) ),
    Element( u'HI08-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI08-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI08-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI08-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI08-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI08-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'09',desc=u'Health Care Code Information'),
    Element( u'HI09-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'TC'] ) ),
    Element( u'HI09-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI09-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI09-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI09-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI09-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI09-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'10',desc=u'Health Care Code Information'),
    Element( u'HI10-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'TC'] ) ),
    Element( u'HI10-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI10-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI10-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI10-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI10-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI10-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'11',desc=u'Health Care Code Information'),
    Element( u'HI11-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'TC'] ) ),
    Element( u'HI11-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI11-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI11-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI11-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI11-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI11-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'12',desc=u'Health Care Code Information'),
    Element( u'HI12-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'TC'] ) ),
    Element( u'HI12-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI12-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI12-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI12-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI12-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI12-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
),
Segment( u'QTY', Properties(syntax='',req_sit=u'S',repeat=u'4',pos=u'240',desc=u'Claim Quantity'),
  Element( u'QTY01', Properties(desc=u'Quantity Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'CA', u'CD', u'LA', u'NA'] ) ),
  Element( u'QTY02', Properties(desc=u'Quantity', req_sit=u'R', data_type=(u'R',u'1',u'15'), position=2,
    codes=[] ) ),
  Composite( u'C001', Properties(req_sit=u'R',refdes='',seq=u'03',desc=u'Composite Unit of Measure'),
    Element( u'QTY03-01', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=0,
      codes=[u'DA'] ) ),
    Element( u'QTY03-02', Properties(desc=u'Exponent', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=1,
      codes=[] ) ),
    Element( u'QTY03-03', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=2,
      codes=[] ) ),
    Element( u'QTY03-04', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=3,
      codes=[] ) ),
    Element( u'QTY03-05', Properties(desc=u'Exponent', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=4,
      codes=[] ) ),
    Element( u'QTY03-06', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=5,
      codes=[] ) ),
    Element( u'QTY03-07', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=6,
      codes=[] ) ),
    Element( u'QTY03-08', Properties(desc=u'Exponent', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=7,
      codes=[] ) ),
    Element( u'QTY03-09', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=8,
      codes=[] ) ),
    Element( u'QTY03-10', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=9,
      codes=[] ) ),
    Element( u'QTY03-11', Properties(desc=u'Exponent', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=10,
      codes=[] ) ),
    Element( u'QTY03-12', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=11,
      codes=[] ) ),
    Element( u'QTY03-13', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=12,
      codes=[] ) ),
    Element( u'QTY03-14', Properties(desc=u'Exponent', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=13,
      codes=[] ) ),
    Element( u'QTY03-15', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=14,
      codes=[] ) ),
  ),
  Element( u'QTY04', Properties(desc=u'Free-form Information', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=4,
    codes=[] ) ),
),
Segment( u'HCP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'241',desc=u'Claim Pricing/Repricing Information'),
  Element( u'HCP01', Properties(desc=u'Pricing Methodology', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'00', u'01', u'02', u'03', u'04', u'05', u'06', u'07', u'08', u'09', u'10', u'11', u'12', u'13', u'14'] ) ),
  Element( u'HCP02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'HCP03', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=3,
    codes=[] ) ),
  Element( u'HCP04', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=4,
    codes=[] ) ),
  Element( u'HCP05', Properties(desc=u'Rate', req_sit=u'S', data_type=(u'R',u'1',u'9'), position=5,
    codes=[] ) ),
  Element( u'HCP06', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=6,
    codes=[] ) ),
  Element( u'HCP07', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=7,
    codes=[] ) ),
  Element( u'HCP08', Properties(desc=u'Product/Service ID', req_sit=u'S', data_type=(u'AN',u'1',u'48'), position=8,
    codes=[] ) ),
  Element( u'HCP09', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=9,
    codes=[u'HC'] ) ),
  Element( u'HCP10', Properties(desc=u'Product/Service ID', req_sit=u'S', data_type=(u'AN',u'1',u'48'), position=10,
    codes=[] ) ),
  Element( u'HCP11', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=11,
    codes=[u'DA', u'UN'] ) ),
  Element( u'HCP12', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=12,
    codes=[] ) ),
  Element( u'HCP13', Properties(desc=u'Reject Reason Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=13,
    codes=[u'T1', u'T2', u'T3', u'T4', u'T5', u'T6'] ) ),
  Element( u'HCP14', Properties(desc=u'Policy Compliance Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=14,
    codes=[u'1', u'2', u'3', u'4', u'5'] ) ),
  Element( u'HCP15', Properties(desc=u'Exception Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=15,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6'] ) ),
),
parsed_837_2305,
parsed_837_2310A,
parsed_837_2310B,
parsed_837_2310C,
parsed_837_2310E,
parsed_837_2320,
parsed_837_2400,
)
parsed_837_2010CA = Loop( u'2010CA', Properties(looptype='',repeat=u'1',pos=u'015',req_sit=u'R',desc=u'Patient Name'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'015',desc=u'Patient Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'QC'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'MI', u'ZZ'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'S', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'N3', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'025',desc=u'Patient Address'),
  Element( u'N301', Properties(desc=u'Address Information', req_sit=u'R', data_type=(u'AN',u'1',u'55'), position=1,
    codes=[] ) ),
  Element( u'N302', Properties(desc=u'Address Information', req_sit=u'S', data_type=(u'AN',u'1',u'55'), position=2,
    codes=[] ) ),
),
Segment( u'N4', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'030',desc=u'Patient City/State/ZIP Code'),
  Element( u'N401', Properties(desc=u'City Name', req_sit=u'R', data_type=(u'AN',u'2',u'30'), position=1,
    codes=[] ) ),
  Element( u'N402', Properties(desc=u'State or Province Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[] ) ),
  Element( u'N403', Properties(desc=u'Postal Code', req_sit=u'R', data_type=(u'ID',u'3',u'15'), position=3,
    codes=[] ) ),
  Element( u'N404', Properties(desc=u'Country Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'N405', Properties(desc=u'Location Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[] ) ),
  Element( u'N406', Properties(desc=u'Location Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
Segment( u'DMG', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'032',desc=u'Patient Demographic Information'),
  Element( u'DMG01', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'D8'] ) ),
  Element( u'DMG02', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=2,
    codes=[] ) ),
  Element( u'DMG03', Properties(desc=u'Gender Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[u'F', u'M', u'U'] ) ),
  Element( u'DMG04', Properties(desc=u'Marital Status Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[] ) ),
  Element( u'DMG05', Properties(desc=u'Race or Ethnicity Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=5,
    codes=[] ) ),
  Element( u'DMG06', Properties(desc=u'Citizenship Status Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=6,
    codes=[] ) ),
  Element( u'DMG07', Properties(desc=u'Country Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=7,
    codes=[] ) ),
  Element( u'DMG08', Properties(desc=u'Basis of Verification Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[] ) ),
  Element( u'DMG09', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=9,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'5',pos=u'035',desc=u'Patient Secondary Identification Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1W', u'23', u'IG', u'SY'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'035',desc=u'Property and Casualty Claim Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'Y4'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2305 = Loop( u'2305', Properties(looptype='',repeat=u'6',pos=u'242',req_sit=u'S',desc=u'Home Health Care Plan Information'),
Segment( u'CR7', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'242',desc=u'Home Health Care Plan Information'),
  Element( u'CR701', Properties(desc=u'Discipline Type Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'AI', u'MS', u'OT', u'PT', u'SN', u'ST'] ) ),
  Element( u'CR702', Properties(desc=u'Number', req_sit=u'R', data_type=(u'N0',u'1',u'9'), position=2,
    codes=[] ) ),
  Element( u'CR703', Properties(desc=u'Number', req_sit=u'R', data_type=(u'N0',u'1',u'9'), position=3,
    codes=[] ) ),
),
Segment( u'HSD', Properties(syntax='',req_sit=u'S',repeat=u'12',pos=u'243',desc=u'Health Care Services Delivery'),
  Element( u'HSD01', Properties(desc=u'Quantity Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'VS'] ) ),
  Element( u'HSD02', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=2,
    codes=[] ) ),
  Element( u'HSD03', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=3,
    codes=[u'DA', u'MO', u'Q1', u'WK'] ) ),
  Element( u'HSD04', Properties(desc=u'Sample Selection Modulus', req_sit=u'S', data_type=(u'R',u'1',u'6'), position=4,
    codes=[] ) ),
  Element( u'HSD05', Properties(desc=u'Time Period Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[u'7', u'35'] ) ),
  Element( u'HSD06', Properties(desc=u'Number of Periods', req_sit=u'S', data_type=(u'N0',u'1',u'3'), position=6,
    codes=[] ) ),
  Element( u'HSD07', Properties(desc=u'Ship/Delivery or Calendar Pattern Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=7,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'A', u'B', u'C', u'D', u'E', u'F', u'G', u'H', u'J', u'K', u'L', u'N', u'O', u'S', u'SA', u'SB', u'SC', u'SD', u'SG', u'SL', u'SP', u'SX', u'SY', u'SZ', u'W'] ) ),
  Element( u'HSD08', Properties(desc=u'Ship/Delivery Pattern Time Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=8,
    codes=[u'D', u'E', u'F'] ) ),
),
)
parsed_837_2310A = Loop( u'2310A', Properties(looptype='',repeat=u'1',pos=u'250',req_sit=u'S',desc=u'Attending Physician Name'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'250',desc=u'Attending Physician Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'71'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'PRV', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'255',desc=u'Attending Physician Specialty Information'),
  Element( u'PRV01', Properties(desc=u'Provider Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'AT', u'SU'] ) ),
  Element( u'PRV02', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'ZZ'] ) ),
  Element( u'PRV03', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'PRV04', Properties(desc=u'State or Province Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=4,
    codes=[] ) ),
  Composite( u'C035', Properties(req_sit=u'N',refdes='',seq=u'05',desc=u'Provider Specialty Information'),
  ),
  Element( u'PRV06', Properties(desc=u'Provider Organization Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'5',pos=u'271',desc=u'Attending Physician Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2310B = Loop( u'2310B', Properties(looptype='',repeat=u'1',pos=u'250',req_sit=u'S',desc=u'Operating Physician Name'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'250',desc=u'Operating Physician Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'72'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'PRV', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'255',desc=u'Operating Physician Specialty Information'),
  Element( u'PRV01', Properties(desc=u'Provider Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'OP'] ) ),
  Element( u'PRV02', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'ZZ'] ) ),
  Element( u'PRV03', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'PRV04', Properties(desc=u'State or Province Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=4,
    codes=[] ) ),
  Composite( u'C035', Properties(req_sit=u'N',refdes='',seq=u'05',desc=u'Provider Specialty Information'),
  ),
  Element( u'PRV06', Properties(desc=u'Provider Organization Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'5',pos=u'271',desc=u'Operating Physician Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2310C = Loop( u'2310C', Properties(looptype='',repeat=u'1',pos=u'250',req_sit=u'S',desc=u'Other Provider Name'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'250',desc=u'Other Provider Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'73'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'PRV', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'255',desc=u'Other Provider Specialty Information'),
  Element( u'PRV01', Properties(desc=u'Provider Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'OT', u'PE'] ) ),
  Element( u'PRV02', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'ZZ'] ) ),
  Element( u'PRV03', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'PRV04', Properties(desc=u'State or Province Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=4,
    codes=[] ) ),
  Composite( u'C035', Properties(req_sit=u'N',refdes='',seq=u'05',desc=u'Provider Specialty Information'),
  ),
  Element( u'PRV06', Properties(desc=u'Provider Organization Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'5',pos=u'271',desc=u'Other Provider Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2310E = Loop( u'2310E', Properties(looptype='',repeat=u'1',pos=u'250',req_sit=u'S',desc=u'Service Facility Name'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'250',desc=u'Service Facility Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'FA'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'S', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'PRV', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'255',desc=u'Service Facility Specialty Information'),
  Element( u'PRV01', Properties(desc=u'Provider Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'RP'] ) ),
  Element( u'PRV02', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'ZZ'] ) ),
  Element( u'PRV03', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'PRV04', Properties(desc=u'State or Province Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=4,
    codes=[] ) ),
  Composite( u'C035', Properties(req_sit=u'N',refdes='',seq=u'05',desc=u'Provider Specialty Information'),
  ),
  Element( u'PRV06', Properties(desc=u'Provider Organization Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=6,
    codes=[] ) ),
),
Segment( u'N3', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'265',desc=u'Service Facility Address'),
  Element( u'N301', Properties(desc=u'Address Information', req_sit=u'R', data_type=(u'AN',u'1',u'55'), position=1,
    codes=[] ) ),
  Element( u'N302', Properties(desc=u'Address Information', req_sit=u'S', data_type=(u'AN',u'1',u'55'), position=2,
    codes=[] ) ),
),
Segment( u'N4', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'270',desc=u'Service Facility City/State/Zip Code'),
  Element( u'N401', Properties(desc=u'City Name', req_sit=u'R', data_type=(u'AN',u'2',u'30'), position=1,
    codes=[] ) ),
  Element( u'N402', Properties(desc=u'State or Province Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[] ) ),
  Element( u'N403', Properties(desc=u'Postal Code', req_sit=u'R', data_type=(u'ID',u'3',u'15'), position=3,
    codes=[] ) ),
  Element( u'N404', Properties(desc=u'Country Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'N405', Properties(desc=u'Location Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[] ) ),
  Element( u'N406', Properties(desc=u'Location Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'5',pos=u'271',desc=u'Service Facility Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'1J', u'EI', u'FH', u'G2', u'G5', u'LU', u'N5', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2330A = Loop( u'2330A', Properties(looptype='',repeat=u'1',pos=u'325',req_sit=u'R',desc=u'Other Subscriber Name'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'325',desc=u'Other Subscriber Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'IL'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'MI', u'ZZ'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'N3', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'332',desc=u'Other Subscriber Address'),
  Element( u'N301', Properties(desc=u'Address Information', req_sit=u'R', data_type=(u'AN',u'1',u'55'), position=1,
    codes=[] ) ),
  Element( u'N302', Properties(desc=u'Address Information', req_sit=u'S', data_type=(u'AN',u'1',u'55'), position=2,
    codes=[] ) ),
),
Segment( u'N4', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'340',desc=u'Other Subscriber City/State/ZIP Code'),
  Element( u'N401', Properties(desc=u'City Name', req_sit=u'R', data_type=(u'AN',u'2',u'30'), position=1,
    codes=[] ) ),
  Element( u'N402', Properties(desc=u'State or Province Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[] ) ),
  Element( u'N403', Properties(desc=u'Postal Code', req_sit=u'R', data_type=(u'ID',u'3',u'15'), position=3,
    codes=[] ) ),
  Element( u'N404', Properties(desc=u'Country Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'N405', Properties(desc=u'Location Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[] ) ),
  Element( u'N406', Properties(desc=u'Location Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'3',pos=u'355',desc=u'Other Subscriber Secondary Information'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1W', u'23', u'IG', u'SY'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2330B = Loop( u'2330B', Properties(looptype='',repeat=u'1',pos=u'325',req_sit=u'R',desc=u'Other Payer Name'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'325',desc=u'Other Payer Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'PR'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'PI', u'XV'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'N3', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'332',desc=u'Other Payer Address'),
  Element( u'N301', Properties(desc=u'Address Information', req_sit=u'R', data_type=(u'AN',u'1',u'55'), position=1,
    codes=[] ) ),
  Element( u'N302', Properties(desc=u'Address Information', req_sit=u'S', data_type=(u'AN',u'1',u'55'), position=2,
    codes=[] ) ),
),
Segment( u'N4', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'340',desc=u'Other Payer City/State/ZIP Code'),
  Element( u'N401', Properties(desc=u'City Name', req_sit=u'R', data_type=(u'AN',u'2',u'30'), position=1,
    codes=[] ) ),
  Element( u'N402', Properties(desc=u'State or Province Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[] ) ),
  Element( u'N403', Properties(desc=u'Postal Code', req_sit=u'R', data_type=(u'ID',u'3',u'15'), position=3,
    codes=[] ) ),
  Element( u'N404', Properties(desc=u'Country Code', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'N405', Properties(desc=u'Location Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[] ) ),
  Element( u'N406', Properties(desc=u'Location Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'350',desc=u'Claim Adjudication Date'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'573'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'2',pos=u'355',desc=u'Other Payer Secondary Identification and Reference Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'2U', u'F8', u'FY', u'NF', u'TJ'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'355',desc=u'Other Payer Prior Authorization or Referral Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'9F', u'G1'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2330C = Loop( u'2330C', Properties(looptype='',repeat=u'1',pos=u'325',req_sit=u'S',desc=u'Other Payer Patient Information'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'325',desc=u'Other Payer Patient Information'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'QC'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'N', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'EI', u'MI'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'3',pos=u'355',desc=u'Other Payer identification Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1W', u'IG', u'SY'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2330D = Loop( u'2330D', Properties(looptype='',repeat=u'1',pos=u'325',req_sit=u'S',desc=u'Other Payer Attending Provider'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'325',desc=u'Other Payer Attending Provider'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'71'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'N', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'N', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'R',repeat=u'3',pos=u'355',desc=u'Other Payer Attending Provider Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2330E = Loop( u'2330E', Properties(looptype='',repeat=u'1',pos=u'325',req_sit=u'S',desc=u'Other Payer Operating Provider'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'325',desc=u'Other Payer Operating Provider'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'72'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'N', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'N', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'R',repeat=u'3',pos=u'355',desc=u'Other Payer Operating Provider Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2330F = Loop( u'2330F', Properties(looptype='',repeat=u'1',pos=u'325',req_sit=u'S',desc=u'Other Payer Other Provider'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'325',desc=u'Other Payer Other Provider'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'73'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'N', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'N', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'R',repeat=u'3',pos=u'355',desc=u'Other Payer Other Provider Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2330H = Loop( u'2330H', Properties(looptype='',repeat=u'1',pos=u'325',req_sit=u'S',desc=u'Other Payer Service Facility Provider'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'325',desc=u'Other Payer Service Facility Provider'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'FA'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'N', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'N', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'N', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'R',repeat=u'3',pos=u'355',desc=u'Other Payer Service Facility Provider Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'1B', u'1C', u'1D', u'EI', u'G2', u'LU', u'N5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2320 = Loop( u'2320', Properties(looptype='',repeat=u'10',pos=u'290',req_sit=u'S',desc=u'Other Subscriber Information'),
Segment( u'SBR', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'290',desc=u'Other Subscriber Information'),
  Element( u'SBR01', Properties(desc=u'Payer Responsibility Sequence Number Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=1,
    codes=[u'P', u'S', u'T'] ) ),
  Element( u'SBR02', Properties(desc=u'Individual Relationship Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[u'01', u'04', u'05', u'07', u'10', u'15', u'17', u'18', u'19', u'20', u'21', u'22', u'23', u'24', u'29', u'32', u'33', u'36', u'39', u'40', u'41', u'43', u'53', u'G8'] ) ),
  Element( u'SBR03', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'SBR04', Properties(desc=u'Name', req_sit=u'S', data_type=(u'AN',u'1',u'60'), position=4,
    codes=[] ) ),
  Element( u'SBR05', Properties(desc=u'Insurance Type Code', req_sit=u'N', data_type=(u'ID',u'1',u'3'), position=5,
    codes=[] ) ),
  Element( u'SBR06', Properties(desc=u'Coordination of Benefits Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=6,
    codes=[] ) ),
  Element( u'SBR07', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=7,
    codes=[] ) ),
  Element( u'SBR08', Properties(desc=u'Employment Status Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=8,
    codes=[] ) ),
  Element( u'SBR09', Properties(desc=u'Claim Filing Indicator Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=9,
    codes=[u'09', u'10', u'11', u'12', u'13', u'14', u'15', u'16', u'AM', u'BL', u'CH', u'CI', u'DS', u'HM', u'LI', u'LM', u'MA', u'MB', u'MC', u'OF', u'TV', u'VA', u'WC', u'ZZ'] ) ),
),
Segment( u'CAS', Properties(syntax='',req_sit=u'S',repeat=u'5',pos=u'295',desc=u'Claim Level Adjustment'),
  Element( u'CAS01', Properties(desc=u'Claim Adjustment Group Code', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=1,
    codes=[u'CO', u'CR', u'OA', u'PI', u'PR'] ) ),
  Element( u'CAS02', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'R', data_type=(u'ID',u'1',u'5'), position=2,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'10', u'11', u'12', u'13', u'14', u'15', u'16', u'17', u'18', u'19', u'20', u'21', u'22', u'23', u'24', u'25', u'26', u'27', u'28', u'29', u'30', u'31', u'32', u'33', u'34', u'35', u'36', u'37', u'38', u'39', u'40', u'41', u'42', u'43', u'44', u'45', u'46', u'47', u'48', u'49', u'50', u'51', u'52', u'53', u'54', u'55', u'56', u'57', u'58', u'59', u'60', u'61', u'62', u'63', u'64', u'65', u'66', u'67', u'68', u'69', u'70', u'71', u'72', u'73', u'74', u'75', u'76', u'77', u'78', u'79', u'80', u'81', u'82', u'83', u'84', u'85', u'86', u'87', u'88', u'89', u'90', u'91', u'92', u'93', u'94', u'95', u'96', u'97', u'98', u'99', u'100', u'101', u'102', u'103', u'104', u'105', u'106', u'107', u'108', u'109', u'110', u'111', u'112', u'113', u'114', u'115', u'116', u'117', u'118', u'119', u'120', u'121', u'122', u'123', u'124', u'125', u'126', u'127', u'128', u'129', u'130', u'131', u'132', u'133', u'134', u'135', u'136', u'137', u'138', u'139', u'140', u'141', u'142', u'143', u'144', u'145', u'146', u'147', u'148', u'149', u'150', u'151', u'152', u'153', u'154', u'A0', u'A1', u'A2', u'A3', u'A4', u'A5', u'A6', u'A7', u'A8', u'B1', u'B2', u'B3', u'B4', u'B5', u'B6', u'B7', u'B8', u'B9', u'B10', u'B11', u'B12', u'B13', u'B14', u'B15', u'B16', u'B17', u'B18', u'B19', u'B20', u'B21', u'B22', u'B23', u'D1', u'D2', u'D3', u'D4', u'D5', u'D6', u'D7', u'D8', u'D9', u'D10', u'D11', u'D12', u'D13', u'D14', u'D15', u'W1'] ) ),
  Element( u'CAS03', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=3,
    codes=[] ) ),
  Element( u'CAS04', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=4,
    codes=[] ) ),
  Element( u'CAS05', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=5,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'10', u'11', u'12', u'13', u'14', u'15', u'16', u'17', u'18', u'19', u'20', u'21', u'22', u'23', u'24', u'25', u'26', u'27', u'28', u'29', u'30', u'31', u'32', u'33', u'34', u'35', u'36', u'37', u'38', u'39', u'40', u'41', u'42', u'43', u'44', u'45', u'46', u'47', u'48', u'49', u'50', u'51', u'52', u'53', u'54', u'55', u'56', u'57', u'58', u'59', u'60', u'61', u'62', u'63', u'64', u'65', u'66', u'67', u'68', u'69', u'70', u'71', u'72', u'73', u'74', u'75', u'76', u'77', u'78', u'79', u'80', u'81', u'82', u'83', u'84', u'85', u'86', u'87', u'88', u'89', u'90', u'91', u'92', u'93', u'94', u'95', u'96', u'97', u'98', u'99', u'100', u'101', u'102', u'103', u'104', u'105', u'106', u'107', u'108', u'109', u'110', u'111', u'112', u'113', u'114', u'115', u'116', u'117', u'118', u'119', u'120', u'121', u'122', u'123', u'124', u'125', u'126', u'127', u'128', u'129', u'130', u'131', u'132', u'133', u'134', u'135', u'136', u'137', u'138', u'139', u'140', u'141', u'142', u'143', u'144', u'145', u'146', u'147', u'148', u'149', u'150', u'151', u'152', u'153', u'154', u'A0', u'A1', u'A2', u'A3', u'A4', u'A5', u'A6', u'A7', u'A8', u'B1', u'B2', u'B3', u'B4', u'B5', u'B6', u'B7', u'B8', u'B9', u'B10', u'B11', u'B12', u'B13', u'B14', u'B15', u'B16', u'B17', u'B18', u'B19', u'B20', u'B21', u'B22', u'B23', u'D1', u'D2', u'D3', u'D4', u'D5', u'D6', u'D7', u'D8', u'D9', u'D10', u'D11', u'D12', u'D13', u'D14', u'D15', u'W1'] ) ),
  Element( u'CAS06', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=6,
    codes=[] ) ),
  Element( u'CAS07', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=7,
    codes=[] ) ),
  Element( u'CAS08', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=8,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'10', u'11', u'12', u'13', u'14', u'15', u'16', u'17', u'18', u'19', u'20', u'21', u'22', u'23', u'24', u'25', u'26', u'27', u'28', u'29', u'30', u'31', u'32', u'33', u'34', u'35', u'36', u'37', u'38', u'39', u'40', u'41', u'42', u'43', u'44', u'45', u'46', u'47', u'48', u'49', u'50', u'51', u'52', u'53', u'54', u'55', u'56', u'57', u'58', u'59', u'60', u'61', u'62', u'63', u'64', u'65', u'66', u'67', u'68', u'69', u'70', u'71', u'72', u'73', u'74', u'75', u'76', u'77', u'78', u'79', u'80', u'81', u'82', u'83', u'84', u'85', u'86', u'87', u'88', u'89', u'90', u'91', u'92', u'93', u'94', u'95', u'96', u'97', u'98', u'99', u'100', u'101', u'102', u'103', u'104', u'105', u'106', u'107', u'108', u'109', u'110', u'111', u'112', u'113', u'114', u'115', u'116', u'117', u'118', u'119', u'120', u'121', u'122', u'123', u'124', u'125', u'126', u'127', u'128', u'129', u'130', u'131', u'132', u'133', u'134', u'135', u'136', u'137', u'138', u'139', u'140', u'141', u'142', u'143', u'144', u'145', u'146', u'147', u'148', u'149', u'150', u'151', u'152', u'153', u'154', u'A0', u'A1', u'A2', u'A3', u'A4', u'A5', u'A6', u'A7', u'A8', u'B1', u'B2', u'B3', u'B4', u'B5', u'B6', u'B7', u'B8', u'B9', u'B10', u'B11', u'B12', u'B13', u'B14', u'B15', u'B16', u'B17', u'B18', u'B19', u'B20', u'B21', u'B22', u'B23', u'D1', u'D2', u'D3', u'D4', u'D5', u'D6', u'D7', u'D8', u'D9', u'D10', u'D11', u'D12', u'D13', u'D14', u'D15', u'W1'] ) ),
  Element( u'CAS09', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=9,
    codes=[] ) ),
  Element( u'CAS10', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=10,
    codes=[] ) ),
  Element( u'CAS11', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=11,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'10', u'11', u'12', u'13', u'14', u'15', u'16', u'17', u'18', u'19', u'20', u'21', u'22', u'23', u'24', u'25', u'26', u'27', u'28', u'29', u'30', u'31', u'32', u'33', u'34', u'35', u'36', u'37', u'38', u'39', u'40', u'41', u'42', u'43', u'44', u'45', u'46', u'47', u'48', u'49', u'50', u'51', u'52', u'53', u'54', u'55', u'56', u'57', u'58', u'59', u'60', u'61', u'62', u'63', u'64', u'65', u'66', u'67', u'68', u'69', u'70', u'71', u'72', u'73', u'74', u'75', u'76', u'77', u'78', u'79', u'80', u'81', u'82', u'83', u'84', u'85', u'86', u'87', u'88', u'89', u'90', u'91', u'92', u'93', u'94', u'95', u'96', u'97', u'98', u'99', u'100', u'101', u'102', u'103', u'104', u'105', u'106', u'107', u'108', u'109', u'110', u'111', u'112', u'113', u'114', u'115', u'116', u'117', u'118', u'119', u'120', u'121', u'122', u'123', u'124', u'125', u'126', u'127', u'128', u'129', u'130', u'131', u'132', u'133', u'134', u'135', u'136', u'137', u'138', u'139', u'140', u'141', u'142', u'143', u'144', u'145', u'146', u'147', u'148', u'149', u'150', u'151', u'152', u'153', u'154', u'A0', u'A1', u'A2', u'A3', u'A4', u'A5', u'A6', u'A7', u'A8', u'B1', u'B2', u'B3', u'B4', u'B5', u'B6', u'B7', u'B8', u'B9', u'B10', u'B11', u'B12', u'B13', u'B14', u'B15', u'B16', u'B17', u'B18', u'B19', u'B20', u'B21', u'B22', u'B23', u'D1', u'D2', u'D3', u'D4', u'D5', u'D6', u'D7', u'D8', u'D9', u'D10', u'D11', u'D12', u'D13', u'D14', u'D15', u'W1'] ) ),
  Element( u'CAS12', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=12,
    codes=[] ) ),
  Element( u'CAS13', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=13,
    codes=[] ) ),
  Element( u'CAS14', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=14,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'10', u'11', u'12', u'13', u'14', u'15', u'16', u'17', u'18', u'19', u'20', u'21', u'22', u'23', u'24', u'25', u'26', u'27', u'28', u'29', u'30', u'31', u'32', u'33', u'34', u'35', u'36', u'37', u'38', u'39', u'40', u'41', u'42', u'43', u'44', u'45', u'46', u'47', u'48', u'49', u'50', u'51', u'52', u'53', u'54', u'55', u'56', u'57', u'58', u'59', u'60', u'61', u'62', u'63', u'64', u'65', u'66', u'67', u'68', u'69', u'70', u'71', u'72', u'73', u'74', u'75', u'76', u'77', u'78', u'79', u'80', u'81', u'82', u'83', u'84', u'85', u'86', u'87', u'88', u'89', u'90', u'91', u'92', u'93', u'94', u'95', u'96', u'97', u'98', u'99', u'100', u'101', u'102', u'103', u'104', u'105', u'106', u'107', u'108', u'109', u'110', u'111', u'112', u'113', u'114', u'115', u'116', u'117', u'118', u'119', u'120', u'121', u'122', u'123', u'124', u'125', u'126', u'127', u'128', u'129', u'130', u'131', u'132', u'133', u'134', u'135', u'136', u'137', u'138', u'139', u'140', u'141', u'142', u'143', u'144', u'145', u'146', u'147', u'148', u'149', u'150', u'151', u'152', u'153', u'154', u'A0', u'A1', u'A2', u'A3', u'A4', u'A5', u'A6', u'A7', u'A8', u'B1', u'B2', u'B3', u'B4', u'B5', u'B6', u'B7', u'B8', u'B9', u'B10', u'B11', u'B12', u'B13', u'B14', u'B15', u'B16', u'B17', u'B18', u'B19', u'B20', u'B21', u'B22', u'B23', u'D1', u'D2', u'D3', u'D4', u'D5', u'D6', u'D7', u'D8', u'D9', u'D10', u'D11', u'D12', u'D13', u'D14', u'D15', u'W1'] ) ),
  Element( u'CAS15', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=15,
    codes=[] ) ),
  Element( u'CAS16', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=16,
    codes=[] ) ),
  Element( u'CAS17', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=17,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'10', u'11', u'12', u'13', u'14', u'15', u'16', u'17', u'18', u'19', u'20', u'21', u'22', u'23', u'24', u'25', u'26', u'27', u'28', u'29', u'30', u'31', u'32', u'33', u'34', u'35', u'36', u'37', u'38', u'39', u'40', u'41', u'42', u'43', u'44', u'45', u'46', u'47', u'48', u'49', u'50', u'51', u'52', u'53', u'54', u'55', u'56', u'57', u'58', u'59', u'60', u'61', u'62', u'63', u'64', u'65', u'66', u'67', u'68', u'69', u'70', u'71', u'72', u'73', u'74', u'75', u'76', u'77', u'78', u'79', u'80', u'81', u'82', u'83', u'84', u'85', u'86', u'87', u'88', u'89', u'90', u'91', u'92', u'93', u'94', u'95', u'96', u'97', u'98', u'99', u'100', u'101', u'102', u'103', u'104', u'105', u'106', u'107', u'108', u'109', u'110', u'111', u'112', u'113', u'114', u'115', u'116', u'117', u'118', u'119', u'120', u'121', u'122', u'123', u'124', u'125', u'126', u'127', u'128', u'129', u'130', u'131', u'132', u'133', u'134', u'135', u'136', u'137', u'138', u'139', u'140', u'141', u'142', u'143', u'144', u'145', u'146', u'147', u'148', u'149', u'150', u'151', u'152', u'153', u'154', u'A0', u'A1', u'A2', u'A3', u'A4', u'A5', u'A6', u'A7', u'A8', u'B1', u'B2', u'B3', u'B4', u'B5', u'B6', u'B7', u'B8', u'B9', u'B10', u'B11', u'B12', u'B13', u'B14', u'B15', u'B16', u'B17', u'B18', u'B19', u'B20', u'B21', u'B22', u'B23', u'D1', u'D2', u'D3', u'D4', u'D5', u'D6', u'D7', u'D8', u'D9', u'D10', u'D11', u'D12', u'D13', u'D14', u'D15', u'W1'] ) ),
  Element( u'CAS18', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=18,
    codes=[] ) ),
  Element( u'CAS19', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=19,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Payer Prior Payment'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'C4'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Total Allowed Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'B6'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Total Submitted Charges'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'T3'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Diagnostic Related Group (DRG) Outlier Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'ZZ'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Total Medicare Paid Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'N1'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Medicare Paid Amount - 100%'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'KF'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Medicare Paid Amount - 80%'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'PG'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Medicare A Trust Fund Paid Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'AA'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Medicare B Trust Fund Paid Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'B1'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Total Non-Covered Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'A8'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'300',desc=u'Coordination of Benefits (COB) Total Denied Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'YT'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'DMG', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'305',desc=u'Other Subscriber Demographic Information'),
  Element( u'DMG01', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'D8'] ) ),
  Element( u'DMG02', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=2,
    codes=[] ) ),
  Element( u'DMG03', Properties(desc=u'Gender Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[u'F', u'M', u'U'] ) ),
  Element( u'DMG04', Properties(desc=u'Marital Status Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[] ) ),
  Element( u'DMG05', Properties(desc=u'Race or Ethnicity Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=5,
    codes=[] ) ),
  Element( u'DMG06', Properties(desc=u'Citizenship Status Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=6,
    codes=[] ) ),
  Element( u'DMG07', Properties(desc=u'Country Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=7,
    codes=[] ) ),
  Element( u'DMG08', Properties(desc=u'Basis of Verification Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[] ) ),
  Element( u'DMG09', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=9,
    codes=[] ) ),
),
Segment( u'OI', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'310',desc=u'Other Insurance Coverage Information'),
  Element( u'OI01', Properties(desc=u'Claim Filing Indicator Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=1,
    codes=[] ) ),
  Element( u'OI02', Properties(desc=u'Claim Submission Reason Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[] ) ),
  Element( u'OI03', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[u'N', u'Y'] ) ),
  Element( u'OI04', Properties(desc=u'Patient Signature Source Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[] ) ),
  Element( u'OI05', Properties(desc=u'Provider Agreement Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=5,
    codes=[] ) ),
  Element( u'OI06', Properties(desc=u'Release of Information Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=6,
    codes=[u'A', u'I', u'M', u'N', u'O', u'Y'] ) ),
),
Segment( u'MIA', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'315',desc=u'Medicare Inpatient Adjudication Information'),
  Element( u'MIA01', Properties(desc=u'Quantity', req_sit=u'R', data_type=(u'R',u'1',u'15'), position=1,
    codes=[] ) ),
  Element( u'MIA02', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=2,
    codes=[] ) ),
  Element( u'MIA03', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=3,
    codes=[] ) ),
  Element( u'MIA04', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=4,
    codes=[] ) ),
  Element( u'MIA05', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=5,
    codes=[u'M1', u'M2', u'M3', u'M4', u'M5', u'M6', u'M7', u'M8', u'M9', u'M10', u'M11', u'M12', u'M13', u'M14', u'M15', u'M16', u'M17', u'M18', u'M19', u'M20', u'M21', u'M22', u'M23', u'M24', u'M25', u'M26', u'M27', u'M28', u'M29', u'M30', u'M31', u'M32', u'M33', u'M34', u'M35', u'M36', u'M37', u'M38', u'M39', u'M40', u'M41', u'M42', u'M43', u'M44', u'M45', u'M46', u'M47', u'M48', u'M49', u'M50', u'M51', u'M52', u'M53', u'M54', u'M55', u'M56', u'M57', u'M58', u'M59', u'M60', u'M61', u'M62', u'M63', u'M64', u'M65', u'M66', u'M67', u'M68', u'M69', u'M70', u'M71', u'M72', u'M73', u'M74', u'M75', u'M76', u'M77', u'M78', u'M79', u'M80', u'M81', u'M82', u'M83', u'M84', u'M85', u'M86', u'M87', u'M88', u'M89', u'M90', u'M91', u'M92', u'M93', u'M94', u'M95', u'M96', u'M97', u'M98', u'M99', u'M100', u'M101', u'M102', u'M103', u'M104', u'M105', u'M106', u'M107', u'M108', u'M109', u'M110', u'M111', u'M112', u'M113', u'M114', u'M115', u'M116', u'M117', u'M118', u'M119', u'M120', u'M121', u'M122', u'M123', u'M124', u'M125', u'M126', u'M127', u'M128', u'M129', u'M130', u'M131', u'M132', u'M133', u'M134', u'M135', u'M136', u'M137', u'M138', u'M139', u'M140', u'M141', u'M142', u'M143', u'M144', u'MA01', u'MA02', u'MA03', u'MA04', u'MA05', u'MA06', u'MA07', u'MA08', u'MA09', u'MA10', u'MA11', u'MA12', u'MA13', u'MA14', u'MA15', u'MA16', u'MA17', u'MA18', u'MA19', u'MA20', u'MA21', u'MA22', u'MA23', u'MA24', u'MA25', u'MA26', u'MA27', u'MA28', u'MA29', u'MA30', u'MA31', u'MA32', u'MA33', u'MA34', u'MA35', u'MA36', u'MA37', u'MA38', u'MA39', u'MA40', u'MA41', u'MA42', u'MA43', u'MA44', u'MA45', u'MA46', u'MA47', u'MA48', u'MA49', u'MA50', u'MA51', u'MA52', u'MA53', u'MA54', u'MA55', u'MA56', u'MA57', u'MA58', u'MA59', u'MA60', u'MA61', u'MA62', u'MA63', u'MA64', u'MA65', u'MA66', u'MA67', u'MA68', u'MA69', u'MA70', u'MA71', u'MA72', u'MA73', u'MA74', u'MA75', u'MA76', u'MA77', u'MA78', u'MA79', u'MA80', u'MA81', u'MA82', u'MA83', u'MA84', u'MA85', u'MA86', u'MA87', u'MA88', u'MA89', u'MA90', u'MA91', u'MA92', u'MA93', u'MA94', u'MA95', u'MA96', u'MA97', u'MA98', u'MA99', u'MA100', u'MA101', u'MA102', u'MA103', u'MA104', u'MA105', u'MA106', u'MA107', u'MA108', u'MA109', u'MA110', u'MA111', u'MA112', u'MA113', u'MA114', u'MA115', u'MA116', u'MA117', u'MA118', u'MA119', u'MA120', u'MA121', u'MA122', u'MA123', u'MA124', u'MA125', u'MA126', u'MA127', u'MA128', u'MA129', u'MA130', u'MA131', u'MA132', u'MA133', u'MA134', u'N1', u'N2', u'N3', u'N4', u'N5', u'N6', u'N7', u'N8', u'N9', u'N10', u'N11', u'N12', u'N13', u'N14', u'N15', u'N16', u'N17', u'N18', u'N19', u'N20', u'N21', u'N22', u'N23', u'N24', u'N25', u'N26', u'N27', u'N28', u'N29', u'N30', u'N31', u'N32', u'N33', u'N34', u'N35', u'N36', u'N37', u'N38', u'N39', u'N40', u'N41', u'N42', u'N43', u'N44', u'N45', u'N46', u'N47', u'N48', u'N49', u'N50', u'N51', u'N52', u'N53', u'N54', u'N55', u'N56', u'N57', u'N58', u'N59', u'N60', u'N61', u'N62', u'N63', u'N64', u'N65', u'N66', u'N67', u'N68', u'N69', u'N70', u'N71', u'N72', u'N73', u'N74', u'N75', u'N76', u'N77', u'N78', u'N79', u'N80', u'N81', u'N82', u'N83', u'N84', u'N85', u'N86', u'N87', u'N88', u'N89', u'N90', u'N91', u'N92', u'N93', u'N94', u'N95', u'N96', u'N97', u'N98', u'N99', u'N100', u'N101', u'N102', u'N103', u'N104', u'N105', u'N106', u'N107', u'N108', u'N109', u'N110', u'N111', u'N112', u'N113', u'N114', u'N115', u'N116', u'N117', u'N118', u'N119', u'N120', u'N121', u'N122', u'N123', u'N124', u'N125', u'N126', u'N127', u'N128', u'N129', u'N130', u'N131', u'N132', u'N133', u'N134', u'N135', u'N136', u'N137', u'N138', u'N139', u'N140', u'N141', u'N142', u'N143', u'N144', u'N145', u'N146', u'N147', u'N148', u'N149', u'N150', u'N151', u'N152', u'N153', u'N154', u'N155', u'N156 '] ) ),
  Element( u'MIA06', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=6,
    codes=[] ) ),
  Element( u'MIA07', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=7,
    codes=[] ) ),
  Element( u'MIA08', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=8,
    codes=[] ) ),
  Element( u'MIA09', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=9,
    codes=[] ) ),
  Element( u'MIA10', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=10,
    codes=[] ) ),
  Element( u'MIA11', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=11,
    codes=[] ) ),
  Element( u'MIA12', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=12,
    codes=[] ) ),
  Element( u'MIA13', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=13,
    codes=[] ) ),
  Element( u'MIA14', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=14,
    codes=[] ) ),
  Element( u'MIA15', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=15,
    codes=[] ) ),
  Element( u'MIA16', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=16,
    codes=[] ) ),
  Element( u'MIA17', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=17,
    codes=[] ) ),
  Element( u'MIA18', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=18,
    codes=[] ) ),
  Element( u'MIA19', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=19,
    codes=[] ) ),
  Element( u'MIA20', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=20,
    codes=[u'M1', u'M2', u'M3', u'M4', u'M5', u'M6', u'M7', u'M8', u'M9', u'M10', u'M11', u'M12', u'M13', u'M14', u'M15', u'M16', u'M17', u'M18', u'M19', u'M20', u'M21', u'M22', u'M23', u'M24', u'M25', u'M26', u'M27', u'M28', u'M29', u'M30', u'M31', u'M32', u'M33', u'M34', u'M35', u'M36', u'M37', u'M38', u'M39', u'M40', u'M41', u'M42', u'M43', u'M44', u'M45', u'M46', u'M47', u'M48', u'M49', u'M50', u'M51', u'M52', u'M53', u'M54', u'M55', u'M56', u'M57', u'M58', u'M59', u'M60', u'M61', u'M62', u'M63', u'M64', u'M65', u'M66', u'M67', u'M68', u'M69', u'M70', u'M71', u'M72', u'M73', u'M74', u'M75', u'M76', u'M77', u'M78', u'M79', u'M80', u'M81', u'M82', u'M83', u'M84', u'M85', u'M86', u'M87', u'M88', u'M89', u'M90', u'M91', u'M92', u'M93', u'M94', u'M95', u'M96', u'M97', u'M98', u'M99', u'M100', u'M101', u'M102', u'M103', u'M104', u'M105', u'M106', u'M107', u'M108', u'M109', u'M110', u'M111', u'M112', u'M113', u'M114', u'M115', u'M116', u'M117', u'M118', u'M119', u'M120', u'M121', u'M122', u'M123', u'M124', u'M125', u'M126', u'M127', u'M128', u'M129', u'M130', u'M131', u'M132', u'M133', u'M134', u'M135', u'M136', u'M137', u'M138', u'M139', u'M140', u'M141', u'M142', u'M143', u'M144', u'MA01', u'MA02', u'MA03', u'MA04', u'MA05', u'MA06', u'MA07', u'MA08', u'MA09', u'MA10', u'MA11', u'MA12', u'MA13', u'MA14', u'MA15', u'MA16', u'MA17', u'MA18', u'MA19', u'MA20', u'MA21', u'MA22', u'MA23', u'MA24', u'MA25', u'MA26', u'MA27', u'MA28', u'MA29', u'MA30', u'MA31', u'MA32', u'MA33', u'MA34', u'MA35', u'MA36', u'MA37', u'MA38', u'MA39', u'MA40', u'MA41', u'MA42', u'MA43', u'MA44', u'MA45', u'MA46', u'MA47', u'MA48', u'MA49', u'MA50', u'MA51', u'MA52', u'MA53', u'MA54', u'MA55', u'MA56', u'MA57', u'MA58', u'MA59', u'MA60', u'MA61', u'MA62', u'MA63', u'MA64', u'MA65', u'MA66', u'MA67', u'MA68', u'MA69', u'MA70', u'MA71', u'MA72', u'MA73', u'MA74', u'MA75', u'MA76', u'MA77', u'MA78', u'MA79', u'MA80', u'MA81', u'MA82', u'MA83', u'MA84', u'MA85', u'MA86', u'MA87', u'MA88', u'MA89', u'MA90', u'MA91', u'MA92', u'MA93', u'MA94', u'MA95', u'MA96', u'MA97', u'MA98', u'MA99', u'MA100', u'MA101', u'MA102', u'MA103', u'MA104', u'MA105', u'MA106', u'MA107', u'MA108', u'MA109', u'MA110', u'MA111', u'MA112', u'MA113', u'MA114', u'MA115', u'MA116', u'MA117', u'MA118', u'MA119', u'MA120', u'MA121', u'MA122', u'MA123', u'MA124', u'MA125', u'MA126', u'MA127', u'MA128', u'MA129', u'MA130', u'MA131', u'MA132', u'MA133', u'MA134', u'N1', u'N2', u'N3', u'N4', u'N5', u'N6', u'N7', u'N8', u'N9', u'N10', u'N11', u'N12', u'N13', u'N14', u'N15', u'N16', u'N17', u'N18', u'N19', u'N20', u'N21', u'N22', u'N23', u'N24', u'N25', u'N26', u'N27', u'N28', u'N29', u'N30', u'N31', u'N32', u'N33', u'N34', u'N35', u'N36', u'N37', u'N38', u'N39', u'N40', u'N41', u'N42', u'N43', u'N44', u'N45', u'N46', u'N47', u'N48', u'N49', u'N50', u'N51', u'N52', u'N53', u'N54', u'N55', u'N56', u'N57', u'N58', u'N59', u'N60', u'N61', u'N62', u'N63', u'N64', u'N65', u'N66', u'N67', u'N68', u'N69', u'N70', u'N71', u'N72', u'N73', u'N74', u'N75', u'N76', u'N77', u'N78', u'N79', u'N80', u'N81', u'N82', u'N83', u'N84', u'N85', u'N86', u'N87', u'N88', u'N89', u'N90', u'N91', u'N92', u'N93', u'N94', u'N95', u'N96', u'N97', u'N98', u'N99', u'N100', u'N101', u'N102', u'N103', u'N104', u'N105', u'N106', u'N107', u'N108', u'N109', u'N110', u'N111', u'N112', u'N113', u'N114', u'N115', u'N116', u'N117', u'N118', u'N119', u'N120', u'N121', u'N122', u'N123', u'N124', u'N125', u'N126', u'N127', u'N128', u'N129', u'N130', u'N131', u'N132', u'N133', u'N134', u'N135', u'N136', u'N137', u'N138', u'N139', u'N140', u'N141', u'N142', u'N143', u'N144', u'N145', u'N146', u'N147', u'N148', u'N149', u'N150', u'N151', u'N152', u'N153', u'N154', u'N155', u'N156 '] ) ),
  Element( u'MIA21', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=21,
    codes=[u'M1', u'M2', u'M3', u'M4', u'M5', u'M6', u'M7', u'M8', u'M9', u'M10', u'M11', u'M12', u'M13', u'M14', u'M15', u'M16', u'M17', u'M18', u'M19', u'M20', u'M21', u'M22', u'M23', u'M24', u'M25', u'M26', u'M27', u'M28', u'M29', u'M30', u'M31', u'M32', u'M33', u'M34', u'M35', u'M36', u'M37', u'M38', u'M39', u'M40', u'M41', u'M42', u'M43', u'M44', u'M45', u'M46', u'M47', u'M48', u'M49', u'M50', u'M51', u'M52', u'M53', u'M54', u'M55', u'M56', u'M57', u'M58', u'M59', u'M60', u'M61', u'M62', u'M63', u'M64', u'M65', u'M66', u'M67', u'M68', u'M69', u'M70', u'M71', u'M72', u'M73', u'M74', u'M75', u'M76', u'M77', u'M78', u'M79', u'M80', u'M81', u'M82', u'M83', u'M84', u'M85', u'M86', u'M87', u'M88', u'M89', u'M90', u'M91', u'M92', u'M93', u'M94', u'M95', u'M96', u'M97', u'M98', u'M99', u'M100', u'M101', u'M102', u'M103', u'M104', u'M105', u'M106', u'M107', u'M108', u'M109', u'M110', u'M111', u'M112', u'M113', u'M114', u'M115', u'M116', u'M117', u'M118', u'M119', u'M120', u'M121', u'M122', u'M123', u'M124', u'M125', u'M126', u'M127', u'M128', u'M129', u'M130', u'M131', u'M132', u'M133', u'M134', u'M135', u'M136', u'M137', u'M138', u'M139', u'M140', u'M141', u'M142', u'M143', u'M144', u'MA01', u'MA02', u'MA03', u'MA04', u'MA05', u'MA06', u'MA07', u'MA08', u'MA09', u'MA10', u'MA11', u'MA12', u'MA13', u'MA14', u'MA15', u'MA16', u'MA17', u'MA18', u'MA19', u'MA20', u'MA21', u'MA22', u'MA23', u'MA24', u'MA25', u'MA26', u'MA27', u'MA28', u'MA29', u'MA30', u'MA31', u'MA32', u'MA33', u'MA34', u'MA35', u'MA36', u'MA37', u'MA38', u'MA39', u'MA40', u'MA41', u'MA42', u'MA43', u'MA44', u'MA45', u'MA46', u'MA47', u'MA48', u'MA49', u'MA50', u'MA51', u'MA52', u'MA53', u'MA54', u'MA55', u'MA56', u'MA57', u'MA58', u'MA59', u'MA60', u'MA61', u'MA62', u'MA63', u'MA64', u'MA65', u'MA66', u'MA67', u'MA68', u'MA69', u'MA70', u'MA71', u'MA72', u'MA73', u'MA74', u'MA75', u'MA76', u'MA77', u'MA78', u'MA79', u'MA80', u'MA81', u'MA82', u'MA83', u'MA84', u'MA85', u'MA86', u'MA87', u'MA88', u'MA89', u'MA90', u'MA91', u'MA92', u'MA93', u'MA94', u'MA95', u'MA96', u'MA97', u'MA98', u'MA99', u'MA100', u'MA101', u'MA102', u'MA103', u'MA104', u'MA105', u'MA106', u'MA107', u'MA108', u'MA109', u'MA110', u'MA111', u'MA112', u'MA113', u'MA114', u'MA115', u'MA116', u'MA117', u'MA118', u'MA119', u'MA120', u'MA121', u'MA122', u'MA123', u'MA124', u'MA125', u'MA126', u'MA127', u'MA128', u'MA129', u'MA130', u'MA131', u'MA132', u'MA133', u'MA134', u'N1', u'N2', u'N3', u'N4', u'N5', u'N6', u'N7', u'N8', u'N9', u'N10', u'N11', u'N12', u'N13', u'N14', u'N15', u'N16', u'N17', u'N18', u'N19', u'N20', u'N21', u'N22', u'N23', u'N24', u'N25', u'N26', u'N27', u'N28', u'N29', u'N30', u'N31', u'N32', u'N33', u'N34', u'N35', u'N36', u'N37', u'N38', u'N39', u'N40', u'N41', u'N42', u'N43', u'N44', u'N45', u'N46', u'N47', u'N48', u'N49', u'N50', u'N51', u'N52', u'N53', u'N54', u'N55', u'N56', u'N57', u'N58', u'N59', u'N60', u'N61', u'N62', u'N63', u'N64', u'N65', u'N66', u'N67', u'N68', u'N69', u'N70', u'N71', u'N72', u'N73', u'N74', u'N75', u'N76', u'N77', u'N78', u'N79', u'N80', u'N81', u'N82', u'N83', u'N84', u'N85', u'N86', u'N87', u'N88', u'N89', u'N90', u'N91', u'N92', u'N93', u'N94', u'N95', u'N96', u'N97', u'N98', u'N99', u'N100', u'N101', u'N102', u'N103', u'N104', u'N105', u'N106', u'N107', u'N108', u'N109', u'N110', u'N111', u'N112', u'N113', u'N114', u'N115', u'N116', u'N117', u'N118', u'N119', u'N120', u'N121', u'N122', u'N123', u'N124', u'N125', u'N126', u'N127', u'N128', u'N129', u'N130', u'N131', u'N132', u'N133', u'N134', u'N135', u'N136', u'N137', u'N138', u'N139', u'N140', u'N141', u'N142', u'N143', u'N144', u'N145', u'N146', u'N147', u'N148', u'N149', u'N150', u'N151', u'N152', u'N153', u'N154', u'N155', u'N156 '] ) ),
  Element( u'MIA22', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=22,
    codes=[u'M1', u'M2', u'M3', u'M4', u'M5', u'M6', u'M7', u'M8', u'M9', u'M10', u'M11', u'M12', u'M13', u'M14', u'M15', u'M16', u'M17', u'M18', u'M19', u'M20', u'M21', u'M22', u'M23', u'M24', u'M25', u'M26', u'M27', u'M28', u'M29', u'M30', u'M31', u'M32', u'M33', u'M34', u'M35', u'M36', u'M37', u'M38', u'M39', u'M40', u'M41', u'M42', u'M43', u'M44', u'M45', u'M46', u'M47', u'M48', u'M49', u'M50', u'M51', u'M52', u'M53', u'M54', u'M55', u'M56', u'M57', u'M58', u'M59', u'M60', u'M61', u'M62', u'M63', u'M64', u'M65', u'M66', u'M67', u'M68', u'M69', u'M70', u'M71', u'M72', u'M73', u'M74', u'M75', u'M76', u'M77', u'M78', u'M79', u'M80', u'M81', u'M82', u'M83', u'M84', u'M85', u'M86', u'M87', u'M88', u'M89', u'M90', u'M91', u'M92', u'M93', u'M94', u'M95', u'M96', u'M97', u'M98', u'M99', u'M100', u'M101', u'M102', u'M103', u'M104', u'M105', u'M106', u'M107', u'M108', u'M109', u'M110', u'M111', u'M112', u'M113', u'M114', u'M115', u'M116', u'M117', u'M118', u'M119', u'M120', u'M121', u'M122', u'M123', u'M124', u'M125', u'M126', u'M127', u'M128', u'M129', u'M130', u'M131', u'M132', u'M133', u'M134', u'M135', u'M136', u'M137', u'M138', u'M139', u'M140', u'M141', u'M142', u'M143', u'M144', u'MA01', u'MA02', u'MA03', u'MA04', u'MA05', u'MA06', u'MA07', u'MA08', u'MA09', u'MA10', u'MA11', u'MA12', u'MA13', u'MA14', u'MA15', u'MA16', u'MA17', u'MA18', u'MA19', u'MA20', u'MA21', u'MA22', u'MA23', u'MA24', u'MA25', u'MA26', u'MA27', u'MA28', u'MA29', u'MA30', u'MA31', u'MA32', u'MA33', u'MA34', u'MA35', u'MA36', u'MA37', u'MA38', u'MA39', u'MA40', u'MA41', u'MA42', u'MA43', u'MA44', u'MA45', u'MA46', u'MA47', u'MA48', u'MA49', u'MA50', u'MA51', u'MA52', u'MA53', u'MA54', u'MA55', u'MA56', u'MA57', u'MA58', u'MA59', u'MA60', u'MA61', u'MA62', u'MA63', u'MA64', u'MA65', u'MA66', u'MA67', u'MA68', u'MA69', u'MA70', u'MA71', u'MA72', u'MA73', u'MA74', u'MA75', u'MA76', u'MA77', u'MA78', u'MA79', u'MA80', u'MA81', u'MA82', u'MA83', u'MA84', u'MA85', u'MA86', u'MA87', u'MA88', u'MA89', u'MA90', u'MA91', u'MA92', u'MA93', u'MA94', u'MA95', u'MA96', u'MA97', u'MA98', u'MA99', u'MA100', u'MA101', u'MA102', u'MA103', u'MA104', u'MA105', u'MA106', u'MA107', u'MA108', u'MA109', u'MA110', u'MA111', u'MA112', u'MA113', u'MA114', u'MA115', u'MA116', u'MA117', u'MA118', u'MA119', u'MA120', u'MA121', u'MA122', u'MA123', u'MA124', u'MA125', u'MA126', u'MA127', u'MA128', u'MA129', u'MA130', u'MA131', u'MA132', u'MA133', u'MA134', u'N1', u'N2', u'N3', u'N4', u'N5', u'N6', u'N7', u'N8', u'N9', u'N10', u'N11', u'N12', u'N13', u'N14', u'N15', u'N16', u'N17', u'N18', u'N19', u'N20', u'N21', u'N22', u'N23', u'N24', u'N25', u'N26', u'N27', u'N28', u'N29', u'N30', u'N31', u'N32', u'N33', u'N34', u'N35', u'N36', u'N37', u'N38', u'N39', u'N40', u'N41', u'N42', u'N43', u'N44', u'N45', u'N46', u'N47', u'N48', u'N49', u'N50', u'N51', u'N52', u'N53', u'N54', u'N55', u'N56', u'N57', u'N58', u'N59', u'N60', u'N61', u'N62', u'N63', u'N64', u'N65', u'N66', u'N67', u'N68', u'N69', u'N70', u'N71', u'N72', u'N73', u'N74', u'N75', u'N76', u'N77', u'N78', u'N79', u'N80', u'N81', u'N82', u'N83', u'N84', u'N85', u'N86', u'N87', u'N88', u'N89', u'N90', u'N91', u'N92', u'N93', u'N94', u'N95', u'N96', u'N97', u'N98', u'N99', u'N100', u'N101', u'N102', u'N103', u'N104', u'N105', u'N106', u'N107', u'N108', u'N109', u'N110', u'N111', u'N112', u'N113', u'N114', u'N115', u'N116', u'N117', u'N118', u'N119', u'N120', u'N121', u'N122', u'N123', u'N124', u'N125', u'N126', u'N127', u'N128', u'N129', u'N130', u'N131', u'N132', u'N133', u'N134', u'N135', u'N136', u'N137', u'N138', u'N139', u'N140', u'N141', u'N142', u'N143', u'N144', u'N145', u'N146', u'N147', u'N148', u'N149', u'N150', u'N151', u'N152', u'N153', u'N154', u'N155', u'N156 '] ) ),
  Element( u'MIA23', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=23,
    codes=[u'M1', u'M2', u'M3', u'M4', u'M5', u'M6', u'M7', u'M8', u'M9', u'M10', u'M11', u'M12', u'M13', u'M14', u'M15', u'M16', u'M17', u'M18', u'M19', u'M20', u'M21', u'M22', u'M23', u'M24', u'M25', u'M26', u'M27', u'M28', u'M29', u'M30', u'M31', u'M32', u'M33', u'M34', u'M35', u'M36', u'M37', u'M38', u'M39', u'M40', u'M41', u'M42', u'M43', u'M44', u'M45', u'M46', u'M47', u'M48', u'M49', u'M50', u'M51', u'M52', u'M53', u'M54', u'M55', u'M56', u'M57', u'M58', u'M59', u'M60', u'M61', u'M62', u'M63', u'M64', u'M65', u'M66', u'M67', u'M68', u'M69', u'M70', u'M71', u'M72', u'M73', u'M74', u'M75', u'M76', u'M77', u'M78', u'M79', u'M80', u'M81', u'M82', u'M83', u'M84', u'M85', u'M86', u'M87', u'M88', u'M89', u'M90', u'M91', u'M92', u'M93', u'M94', u'M95', u'M96', u'M97', u'M98', u'M99', u'M100', u'M101', u'M102', u'M103', u'M104', u'M105', u'M106', u'M107', u'M108', u'M109', u'M110', u'M111', u'M112', u'M113', u'M114', u'M115', u'M116', u'M117', u'M118', u'M119', u'M120', u'M121', u'M122', u'M123', u'M124', u'M125', u'M126', u'M127', u'M128', u'M129', u'M130', u'M131', u'M132', u'M133', u'M134', u'M135', u'M136', u'M137', u'M138', u'M139', u'M140', u'M141', u'M142', u'M143', u'M144', u'MA01', u'MA02', u'MA03', u'MA04', u'MA05', u'MA06', u'MA07', u'MA08', u'MA09', u'MA10', u'MA11', u'MA12', u'MA13', u'MA14', u'MA15', u'MA16', u'MA17', u'MA18', u'MA19', u'MA20', u'MA21', u'MA22', u'MA23', u'MA24', u'MA25', u'MA26', u'MA27', u'MA28', u'MA29', u'MA30', u'MA31', u'MA32', u'MA33', u'MA34', u'MA35', u'MA36', u'MA37', u'MA38', u'MA39', u'MA40', u'MA41', u'MA42', u'MA43', u'MA44', u'MA45', u'MA46', u'MA47', u'MA48', u'MA49', u'MA50', u'MA51', u'MA52', u'MA53', u'MA54', u'MA55', u'MA56', u'MA57', u'MA58', u'MA59', u'MA60', u'MA61', u'MA62', u'MA63', u'MA64', u'MA65', u'MA66', u'MA67', u'MA68', u'MA69', u'MA70', u'MA71', u'MA72', u'MA73', u'MA74', u'MA75', u'MA76', u'MA77', u'MA78', u'MA79', u'MA80', u'MA81', u'MA82', u'MA83', u'MA84', u'MA85', u'MA86', u'MA87', u'MA88', u'MA89', u'MA90', u'MA91', u'MA92', u'MA93', u'MA94', u'MA95', u'MA96', u'MA97', u'MA98', u'MA99', u'MA100', u'MA101', u'MA102', u'MA103', u'MA104', u'MA105', u'MA106', u'MA107', u'MA108', u'MA109', u'MA110', u'MA111', u'MA112', u'MA113', u'MA114', u'MA115', u'MA116', u'MA117', u'MA118', u'MA119', u'MA120', u'MA121', u'MA122', u'MA123', u'MA124', u'MA125', u'MA126', u'MA127', u'MA128', u'MA129', u'MA130', u'MA131', u'MA132', u'MA133', u'MA134', u'N1', u'N2', u'N3', u'N4', u'N5', u'N6', u'N7', u'N8', u'N9', u'N10', u'N11', u'N12', u'N13', u'N14', u'N15', u'N16', u'N17', u'N18', u'N19', u'N20', u'N21', u'N22', u'N23', u'N24', u'N25', u'N26', u'N27', u'N28', u'N29', u'N30', u'N31', u'N32', u'N33', u'N34', u'N35', u'N36', u'N37', u'N38', u'N39', u'N40', u'N41', u'N42', u'N43', u'N44', u'N45', u'N46', u'N47', u'N48', u'N49', u'N50', u'N51', u'N52', u'N53', u'N54', u'N55', u'N56', u'N57', u'N58', u'N59', u'N60', u'N61', u'N62', u'N63', u'N64', u'N65', u'N66', u'N67', u'N68', u'N69', u'N70', u'N71', u'N72', u'N73', u'N74', u'N75', u'N76', u'N77', u'N78', u'N79', u'N80', u'N81', u'N82', u'N83', u'N84', u'N85', u'N86', u'N87', u'N88', u'N89', u'N90', u'N91', u'N92', u'N93', u'N94', u'N95', u'N96', u'N97', u'N98', u'N99', u'N100', u'N101', u'N102', u'N103', u'N104', u'N105', u'N106', u'N107', u'N108', u'N109', u'N110', u'N111', u'N112', u'N113', u'N114', u'N115', u'N116', u'N117', u'N118', u'N119', u'N120', u'N121', u'N122', u'N123', u'N124', u'N125', u'N126', u'N127', u'N128', u'N129', u'N130', u'N131', u'N132', u'N133', u'N134', u'N135', u'N136', u'N137', u'N138', u'N139', u'N140', u'N141', u'N142', u'N143', u'N144', u'N145', u'N146', u'N147', u'N148', u'N149', u'N150', u'N151', u'N152', u'N153', u'N154', u'N155', u'N156 '] ) ),
  Element( u'MIA24', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=24,
    codes=[] ) ),
),
Segment( u'MOA', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'320',desc=u'Medicare Outpatient Adjudication Information'),
  Element( u'MOA01', Properties(desc=u'Percentage as Decimal', req_sit=u'S', data_type=(u'R',u'1',u'10'), position=1,
    codes=[] ) ),
  Element( u'MOA02', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'MOA03', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[u'M1', u'M2', u'M3', u'M4', u'M5', u'M6', u'M7', u'M8', u'M9', u'M10', u'M11', u'M12', u'M13', u'M14', u'M15', u'M16', u'M17', u'M18', u'M19', u'M20', u'M21', u'M22', u'M23', u'M24', u'M25', u'M26', u'M27', u'M28', u'M29', u'M30', u'M31', u'M32', u'M33', u'M34', u'M35', u'M36', u'M37', u'M38', u'M39', u'M40', u'M41', u'M42', u'M43', u'M44', u'M45', u'M46', u'M47', u'M48', u'M49', u'M50', u'M51', u'M52', u'M53', u'M54', u'M55', u'M56', u'M57', u'M58', u'M59', u'M60', u'M61', u'M62', u'M63', u'M64', u'M65', u'M66', u'M67', u'M68', u'M69', u'M70', u'M71', u'M72', u'M73', u'M74', u'M75', u'M76', u'M77', u'M78', u'M79', u'M80', u'M81', u'M82', u'M83', u'M84', u'M85', u'M86', u'M87', u'M88', u'M89', u'M90', u'M91', u'M92', u'M93', u'M94', u'M95', u'M96', u'M97', u'M98', u'M99', u'M100', u'M101', u'M102', u'M103', u'M104', u'M105', u'M106', u'M107', u'M108', u'M109', u'M110', u'M111', u'M112', u'M113', u'M114', u'M115', u'M116', u'M117', u'M118', u'M119', u'M120', u'M121', u'M122', u'M123', u'M124', u'M125', u'M126', u'M127', u'M128', u'M129', u'M130', u'M131', u'M132', u'M133', u'M134', u'M135', u'M136', u'M137', u'M138', u'M139', u'M140', u'M141', u'M142', u'M143', u'M144', u'MA01', u'MA02', u'MA03', u'MA04', u'MA05', u'MA06', u'MA07', u'MA08', u'MA09', u'MA10', u'MA11', u'MA12', u'MA13', u'MA14', u'MA15', u'MA16', u'MA17', u'MA18', u'MA19', u'MA20', u'MA21', u'MA22', u'MA23', u'MA24', u'MA25', u'MA26', u'MA27', u'MA28', u'MA29', u'MA30', u'MA31', u'MA32', u'MA33', u'MA34', u'MA35', u'MA36', u'MA37', u'MA38', u'MA39', u'MA40', u'MA41', u'MA42', u'MA43', u'MA44', u'MA45', u'MA46', u'MA47', u'MA48', u'MA49', u'MA50', u'MA51', u'MA52', u'MA53', u'MA54', u'MA55', u'MA56', u'MA57', u'MA58', u'MA59', u'MA60', u'MA61', u'MA62', u'MA63', u'MA64', u'MA65', u'MA66', u'MA67', u'MA68', u'MA69', u'MA70', u'MA71', u'MA72', u'MA73', u'MA74', u'MA75', u'MA76', u'MA77', u'MA78', u'MA79', u'MA80', u'MA81', u'MA82', u'MA83', u'MA84', u'MA85', u'MA86', u'MA87', u'MA88', u'MA89', u'MA90', u'MA91', u'MA92', u'MA93', u'MA94', u'MA95', u'MA96', u'MA97', u'MA98', u'MA99', u'MA100', u'MA101', u'MA102', u'MA103', u'MA104', u'MA105', u'MA106', u'MA107', u'MA108', u'MA109', u'MA110', u'MA111', u'MA112', u'MA113', u'MA114', u'MA115', u'MA116', u'MA117', u'MA118', u'MA119', u'MA120', u'MA121', u'MA122', u'MA123', u'MA124', u'MA125', u'MA126', u'MA127', u'MA128', u'MA129', u'MA130', u'MA131', u'MA132', u'MA133', u'MA134', u'N1', u'N2', u'N3', u'N4', u'N5', u'N6', u'N7', u'N8', u'N9', u'N10', u'N11', u'N12', u'N13', u'N14', u'N15', u'N16', u'N17', u'N18', u'N19', u'N20', u'N21', u'N22', u'N23', u'N24', u'N25', u'N26', u'N27', u'N28', u'N29', u'N30', u'N31', u'N32', u'N33', u'N34', u'N35', u'N36', u'N37', u'N38', u'N39', u'N40', u'N41', u'N42', u'N43', u'N44', u'N45', u'N46', u'N47', u'N48', u'N49', u'N50', u'N51', u'N52', u'N53', u'N54', u'N55', u'N56', u'N57', u'N58', u'N59', u'N60', u'N61', u'N62', u'N63', u'N64', u'N65', u'N66', u'N67', u'N68', u'N69', u'N70', u'N71', u'N72', u'N73', u'N74', u'N75', u'N76', u'N77', u'N78', u'N79', u'N80', u'N81', u'N82', u'N83', u'N84', u'N85', u'N86', u'N87', u'N88', u'N89', u'N90', u'N91', u'N92', u'N93', u'N94', u'N95', u'N96', u'N97', u'N98', u'N99', u'N100', u'N101', u'N102', u'N103', u'N104', u'N105', u'N106', u'N107', u'N108', u'N109', u'N110', u'N111', u'N112', u'N113', u'N114', u'N115', u'N116', u'N117', u'N118', u'N119', u'N120', u'N121', u'N122', u'N123', u'N124', u'N125', u'N126', u'N127', u'N128', u'N129', u'N130', u'N131', u'N132', u'N133', u'N134', u'N135', u'N136', u'N137', u'N138', u'N139', u'N140', u'N141', u'N142', u'N143', u'N144', u'N145', u'N146', u'N147', u'N148', u'N149', u'N150', u'N151', u'N152', u'N153', u'N154', u'N155', u'N156 '] ) ),
  Element( u'MOA04', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=4,
    codes=[u'M1', u'M2', u'M3', u'M4', u'M5', u'M6', u'M7', u'M8', u'M9', u'M10', u'M11', u'M12', u'M13', u'M14', u'M15', u'M16', u'M17', u'M18', u'M19', u'M20', u'M21', u'M22', u'M23', u'M24', u'M25', u'M26', u'M27', u'M28', u'M29', u'M30', u'M31', u'M32', u'M33', u'M34', u'M35', u'M36', u'M37', u'M38', u'M39', u'M40', u'M41', u'M42', u'M43', u'M44', u'M45', u'M46', u'M47', u'M48', u'M49', u'M50', u'M51', u'M52', u'M53', u'M54', u'M55', u'M56', u'M57', u'M58', u'M59', u'M60', u'M61', u'M62', u'M63', u'M64', u'M65', u'M66', u'M67', u'M68', u'M69', u'M70', u'M71', u'M72', u'M73', u'M74', u'M75', u'M76', u'M77', u'M78', u'M79', u'M80', u'M81', u'M82', u'M83', u'M84', u'M85', u'M86', u'M87', u'M88', u'M89', u'M90', u'M91', u'M92', u'M93', u'M94', u'M95', u'M96', u'M97', u'M98', u'M99', u'M100', u'M101', u'M102', u'M103', u'M104', u'M105', u'M106', u'M107', u'M108', u'M109', u'M110', u'M111', u'M112', u'M113', u'M114', u'M115', u'M116', u'M117', u'M118', u'M119', u'M120', u'M121', u'M122', u'M123', u'M124', u'M125', u'M126', u'M127', u'M128', u'M129', u'M130', u'M131', u'M132', u'M133', u'M134', u'M135', u'M136', u'M137', u'M138', u'M139', u'M140', u'M141', u'M142', u'M143', u'M144', u'MA01', u'MA02', u'MA03', u'MA04', u'MA05', u'MA06', u'MA07', u'MA08', u'MA09', u'MA10', u'MA11', u'MA12', u'MA13', u'MA14', u'MA15', u'MA16', u'MA17', u'MA18', u'MA19', u'MA20', u'MA21', u'MA22', u'MA23', u'MA24', u'MA25', u'MA26', u'MA27', u'MA28', u'MA29', u'MA30', u'MA31', u'MA32', u'MA33', u'MA34', u'MA35', u'MA36', u'MA37', u'MA38', u'MA39', u'MA40', u'MA41', u'MA42', u'MA43', u'MA44', u'MA45', u'MA46', u'MA47', u'MA48', u'MA49', u'MA50', u'MA51', u'MA52', u'MA53', u'MA54', u'MA55', u'MA56', u'MA57', u'MA58', u'MA59', u'MA60', u'MA61', u'MA62', u'MA63', u'MA64', u'MA65', u'MA66', u'MA67', u'MA68', u'MA69', u'MA70', u'MA71', u'MA72', u'MA73', u'MA74', u'MA75', u'MA76', u'MA77', u'MA78', u'MA79', u'MA80', u'MA81', u'MA82', u'MA83', u'MA84', u'MA85', u'MA86', u'MA87', u'MA88', u'MA89', u'MA90', u'MA91', u'MA92', u'MA93', u'MA94', u'MA95', u'MA96', u'MA97', u'MA98', u'MA99', u'MA100', u'MA101', u'MA102', u'MA103', u'MA104', u'MA105', u'MA106', u'MA107', u'MA108', u'MA109', u'MA110', u'MA111', u'MA112', u'MA113', u'MA114', u'MA115', u'MA116', u'MA117', u'MA118', u'MA119', u'MA120', u'MA121', u'MA122', u'MA123', u'MA124', u'MA125', u'MA126', u'MA127', u'MA128', u'MA129', u'MA130', u'MA131', u'MA132', u'MA133', u'MA134', u'N1', u'N2', u'N3', u'N4', u'N5', u'N6', u'N7', u'N8', u'N9', u'N10', u'N11', u'N12', u'N13', u'N14', u'N15', u'N16', u'N17', u'N18', u'N19', u'N20', u'N21', u'N22', u'N23', u'N24', u'N25', u'N26', u'N27', u'N28', u'N29', u'N30', u'N31', u'N32', u'N33', u'N34', u'N35', u'N36', u'N37', u'N38', u'N39', u'N40', u'N41', u'N42', u'N43', u'N44', u'N45', u'N46', u'N47', u'N48', u'N49', u'N50', u'N51', u'N52', u'N53', u'N54', u'N55', u'N56', u'N57', u'N58', u'N59', u'N60', u'N61', u'N62', u'N63', u'N64', u'N65', u'N66', u'N67', u'N68', u'N69', u'N70', u'N71', u'N72', u'N73', u'N74', u'N75', u'N76', u'N77', u'N78', u'N79', u'N80', u'N81', u'N82', u'N83', u'N84', u'N85', u'N86', u'N87', u'N88', u'N89', u'N90', u'N91', u'N92', u'N93', u'N94', u'N95', u'N96', u'N97', u'N98', u'N99', u'N100', u'N101', u'N102', u'N103', u'N104', u'N105', u'N106', u'N107', u'N108', u'N109', u'N110', u'N111', u'N112', u'N113', u'N114', u'N115', u'N116', u'N117', u'N118', u'N119', u'N120', u'N121', u'N122', u'N123', u'N124', u'N125', u'N126', u'N127', u'N128', u'N129', u'N130', u'N131', u'N132', u'N133', u'N134', u'N135', u'N136', u'N137', u'N138', u'N139', u'N140', u'N141', u'N142', u'N143', u'N144', u'N145', u'N146', u'N147', u'N148', u'N149', u'N150', u'N151', u'N152', u'N153', u'N154', u'N155', u'N156 '] ) ),
  Element( u'MOA05', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=5,
    codes=[u'M1', u'M2', u'M3', u'M4', u'M5', u'M6', u'M7', u'M8', u'M9', u'M10', u'M11', u'M12', u'M13', u'M14', u'M15', u'M16', u'M17', u'M18', u'M19', u'M20', u'M21', u'M22', u'M23', u'M24', u'M25', u'M26', u'M27', u'M28', u'M29', u'M30', u'M31', u'M32', u'M33', u'M34', u'M35', u'M36', u'M37', u'M38', u'M39', u'M40', u'M41', u'M42', u'M43', u'M44', u'M45', u'M46', u'M47', u'M48', u'M49', u'M50', u'M51', u'M52', u'M53', u'M54', u'M55', u'M56', u'M57', u'M58', u'M59', u'M60', u'M61', u'M62', u'M63', u'M64', u'M65', u'M66', u'M67', u'M68', u'M69', u'M70', u'M71', u'M72', u'M73', u'M74', u'M75', u'M76', u'M77', u'M78', u'M79', u'M80', u'M81', u'M82', u'M83', u'M84', u'M85', u'M86', u'M87', u'M88', u'M89', u'M90', u'M91', u'M92', u'M93', u'M94', u'M95', u'M96', u'M97', u'M98', u'M99', u'M100', u'M101', u'M102', u'M103', u'M104', u'M105', u'M106', u'M107', u'M108', u'M109', u'M110', u'M111', u'M112', u'M113', u'M114', u'M115', u'M116', u'M117', u'M118', u'M119', u'M120', u'M121', u'M122', u'M123', u'M124', u'M125', u'M126', u'M127', u'M128', u'M129', u'M130', u'M131', u'M132', u'M133', u'M134', u'M135', u'M136', u'M137', u'M138', u'M139', u'M140', u'M141', u'M142', u'M143', u'M144', u'MA01', u'MA02', u'MA03', u'MA04', u'MA05', u'MA06', u'MA07', u'MA08', u'MA09', u'MA10', u'MA11', u'MA12', u'MA13', u'MA14', u'MA15', u'MA16', u'MA17', u'MA18', u'MA19', u'MA20', u'MA21', u'MA22', u'MA23', u'MA24', u'MA25', u'MA26', u'MA27', u'MA28', u'MA29', u'MA30', u'MA31', u'MA32', u'MA33', u'MA34', u'MA35', u'MA36', u'MA37', u'MA38', u'MA39', u'MA40', u'MA41', u'MA42', u'MA43', u'MA44', u'MA45', u'MA46', u'MA47', u'MA48', u'MA49', u'MA50', u'MA51', u'MA52', u'MA53', u'MA54', u'MA55', u'MA56', u'MA57', u'MA58', u'MA59', u'MA60', u'MA61', u'MA62', u'MA63', u'MA64', u'MA65', u'MA66', u'MA67', u'MA68', u'MA69', u'MA70', u'MA71', u'MA72', u'MA73', u'MA74', u'MA75', u'MA76', u'MA77', u'MA78', u'MA79', u'MA80', u'MA81', u'MA82', u'MA83', u'MA84', u'MA85', u'MA86', u'MA87', u'MA88', u'MA89', u'MA90', u'MA91', u'MA92', u'MA93', u'MA94', u'MA95', u'MA96', u'MA97', u'MA98', u'MA99', u'MA100', u'MA101', u'MA102', u'MA103', u'MA104', u'MA105', u'MA106', u'MA107', u'MA108', u'MA109', u'MA110', u'MA111', u'MA112', u'MA113', u'MA114', u'MA115', u'MA116', u'MA117', u'MA118', u'MA119', u'MA120', u'MA121', u'MA122', u'MA123', u'MA124', u'MA125', u'MA126', u'MA127', u'MA128', u'MA129', u'MA130', u'MA131', u'MA132', u'MA133', u'MA134', u'N1', u'N2', u'N3', u'N4', u'N5', u'N6', u'N7', u'N8', u'N9', u'N10', u'N11', u'N12', u'N13', u'N14', u'N15', u'N16', u'N17', u'N18', u'N19', u'N20', u'N21', u'N22', u'N23', u'N24', u'N25', u'N26', u'N27', u'N28', u'N29', u'N30', u'N31', u'N32', u'N33', u'N34', u'N35', u'N36', u'N37', u'N38', u'N39', u'N40', u'N41', u'N42', u'N43', u'N44', u'N45', u'N46', u'N47', u'N48', u'N49', u'N50', u'N51', u'N52', u'N53', u'N54', u'N55', u'N56', u'N57', u'N58', u'N59', u'N60', u'N61', u'N62', u'N63', u'N64', u'N65', u'N66', u'N67', u'N68', u'N69', u'N70', u'N71', u'N72', u'N73', u'N74', u'N75', u'N76', u'N77', u'N78', u'N79', u'N80', u'N81', u'N82', u'N83', u'N84', u'N85', u'N86', u'N87', u'N88', u'N89', u'N90', u'N91', u'N92', u'N93', u'N94', u'N95', u'N96', u'N97', u'N98', u'N99', u'N100', u'N101', u'N102', u'N103', u'N104', u'N105', u'N106', u'N107', u'N108', u'N109', u'N110', u'N111', u'N112', u'N113', u'N114', u'N115', u'N116', u'N117', u'N118', u'N119', u'N120', u'N121', u'N122', u'N123', u'N124', u'N125', u'N126', u'N127', u'N128', u'N129', u'N130', u'N131', u'N132', u'N133', u'N134', u'N135', u'N136', u'N137', u'N138', u'N139', u'N140', u'N141', u'N142', u'N143', u'N144', u'N145', u'N146', u'N147', u'N148', u'N149', u'N150', u'N151', u'N152', u'N153', u'N154', u'N155', u'N156 '] ) ),
  Element( u'MOA06', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=6,
    codes=[u'M1', u'M2', u'M3', u'M4', u'M5', u'M6', u'M7', u'M8', u'M9', u'M10', u'M11', u'M12', u'M13', u'M14', u'M15', u'M16', u'M17', u'M18', u'M19', u'M20', u'M21', u'M22', u'M23', u'M24', u'M25', u'M26', u'M27', u'M28', u'M29', u'M30', u'M31', u'M32', u'M33', u'M34', u'M35', u'M36', u'M37', u'M38', u'M39', u'M40', u'M41', u'M42', u'M43', u'M44', u'M45', u'M46', u'M47', u'M48', u'M49', u'M50', u'M51', u'M52', u'M53', u'M54', u'M55', u'M56', u'M57', u'M58', u'M59', u'M60', u'M61', u'M62', u'M63', u'M64', u'M65', u'M66', u'M67', u'M68', u'M69', u'M70', u'M71', u'M72', u'M73', u'M74', u'M75', u'M76', u'M77', u'M78', u'M79', u'M80', u'M81', u'M82', u'M83', u'M84', u'M85', u'M86', u'M87', u'M88', u'M89', u'M90', u'M91', u'M92', u'M93', u'M94', u'M95', u'M96', u'M97', u'M98', u'M99', u'M100', u'M101', u'M102', u'M103', u'M104', u'M105', u'M106', u'M107', u'M108', u'M109', u'M110', u'M111', u'M112', u'M113', u'M114', u'M115', u'M116', u'M117', u'M118', u'M119', u'M120', u'M121', u'M122', u'M123', u'M124', u'M125', u'M126', u'M127', u'M128', u'M129', u'M130', u'M131', u'M132', u'M133', u'M134', u'M135', u'M136', u'M137', u'M138', u'M139', u'M140', u'M141', u'M142', u'M143', u'M144', u'MA01', u'MA02', u'MA03', u'MA04', u'MA05', u'MA06', u'MA07', u'MA08', u'MA09', u'MA10', u'MA11', u'MA12', u'MA13', u'MA14', u'MA15', u'MA16', u'MA17', u'MA18', u'MA19', u'MA20', u'MA21', u'MA22', u'MA23', u'MA24', u'MA25', u'MA26', u'MA27', u'MA28', u'MA29', u'MA30', u'MA31', u'MA32', u'MA33', u'MA34', u'MA35', u'MA36', u'MA37', u'MA38', u'MA39', u'MA40', u'MA41', u'MA42', u'MA43', u'MA44', u'MA45', u'MA46', u'MA47', u'MA48', u'MA49', u'MA50', u'MA51', u'MA52', u'MA53', u'MA54', u'MA55', u'MA56', u'MA57', u'MA58', u'MA59', u'MA60', u'MA61', u'MA62', u'MA63', u'MA64', u'MA65', u'MA66', u'MA67', u'MA68', u'MA69', u'MA70', u'MA71', u'MA72', u'MA73', u'MA74', u'MA75', u'MA76', u'MA77', u'MA78', u'MA79', u'MA80', u'MA81', u'MA82', u'MA83', u'MA84', u'MA85', u'MA86', u'MA87', u'MA88', u'MA89', u'MA90', u'MA91', u'MA92', u'MA93', u'MA94', u'MA95', u'MA96', u'MA97', u'MA98', u'MA99', u'MA100', u'MA101', u'MA102', u'MA103', u'MA104', u'MA105', u'MA106', u'MA107', u'MA108', u'MA109', u'MA110', u'MA111', u'MA112', u'MA113', u'MA114', u'MA115', u'MA116', u'MA117', u'MA118', u'MA119', u'MA120', u'MA121', u'MA122', u'MA123', u'MA124', u'MA125', u'MA126', u'MA127', u'MA128', u'MA129', u'MA130', u'MA131', u'MA132', u'MA133', u'MA134', u'N1', u'N2', u'N3', u'N4', u'N5', u'N6', u'N7', u'N8', u'N9', u'N10', u'N11', u'N12', u'N13', u'N14', u'N15', u'N16', u'N17', u'N18', u'N19', u'N20', u'N21', u'N22', u'N23', u'N24', u'N25', u'N26', u'N27', u'N28', u'N29', u'N30', u'N31', u'N32', u'N33', u'N34', u'N35', u'N36', u'N37', u'N38', u'N39', u'N40', u'N41', u'N42', u'N43', u'N44', u'N45', u'N46', u'N47', u'N48', u'N49', u'N50', u'N51', u'N52', u'N53', u'N54', u'N55', u'N56', u'N57', u'N58', u'N59', u'N60', u'N61', u'N62', u'N63', u'N64', u'N65', u'N66', u'N67', u'N68', u'N69', u'N70', u'N71', u'N72', u'N73', u'N74', u'N75', u'N76', u'N77', u'N78', u'N79', u'N80', u'N81', u'N82', u'N83', u'N84', u'N85', u'N86', u'N87', u'N88', u'N89', u'N90', u'N91', u'N92', u'N93', u'N94', u'N95', u'N96', u'N97', u'N98', u'N99', u'N100', u'N101', u'N102', u'N103', u'N104', u'N105', u'N106', u'N107', u'N108', u'N109', u'N110', u'N111', u'N112', u'N113', u'N114', u'N115', u'N116', u'N117', u'N118', u'N119', u'N120', u'N121', u'N122', u'N123', u'N124', u'N125', u'N126', u'N127', u'N128', u'N129', u'N130', u'N131', u'N132', u'N133', u'N134', u'N135', u'N136', u'N137', u'N138', u'N139', u'N140', u'N141', u'N142', u'N143', u'N144', u'N145', u'N146', u'N147', u'N148', u'N149', u'N150', u'N151', u'N152', u'N153', u'N154', u'N155', u'N156 '] ) ),
  Element( u'MOA07', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=7,
    codes=[u'M1', u'M2', u'M3', u'M4', u'M5', u'M6', u'M7', u'M8', u'M9', u'M10', u'M11', u'M12', u'M13', u'M14', u'M15', u'M16', u'M17', u'M18', u'M19', u'M20', u'M21', u'M22', u'M23', u'M24', u'M25', u'M26', u'M27', u'M28', u'M29', u'M30', u'M31', u'M32', u'M33', u'M34', u'M35', u'M36', u'M37', u'M38', u'M39', u'M40', u'M41', u'M42', u'M43', u'M44', u'M45', u'M46', u'M47', u'M48', u'M49', u'M50', u'M51', u'M52', u'M53', u'M54', u'M55', u'M56', u'M57', u'M58', u'M59', u'M60', u'M61', u'M62', u'M63', u'M64', u'M65', u'M66', u'M67', u'M68', u'M69', u'M70', u'M71', u'M72', u'M73', u'M74', u'M75', u'M76', u'M77', u'M78', u'M79', u'M80', u'M81', u'M82', u'M83', u'M84', u'M85', u'M86', u'M87', u'M88', u'M89', u'M90', u'M91', u'M92', u'M93', u'M94', u'M95', u'M96', u'M97', u'M98', u'M99', u'M100', u'M101', u'M102', u'M103', u'M104', u'M105', u'M106', u'M107', u'M108', u'M109', u'M110', u'M111', u'M112', u'M113', u'M114', u'M115', u'M116', u'M117', u'M118', u'M119', u'M120', u'M121', u'M122', u'M123', u'M124', u'M125', u'M126', u'M127', u'M128', u'M129', u'M130', u'M131', u'M132', u'M133', u'M134', u'M135', u'M136', u'M137', u'M138', u'M139', u'M140', u'M141', u'M142', u'M143', u'M144', u'MA01', u'MA02', u'MA03', u'MA04', u'MA05', u'MA06', u'MA07', u'MA08', u'MA09', u'MA10', u'MA11', u'MA12', u'MA13', u'MA14', u'MA15', u'MA16', u'MA17', u'MA18', u'MA19', u'MA20', u'MA21', u'MA22', u'MA23', u'MA24', u'MA25', u'MA26', u'MA27', u'MA28', u'MA29', u'MA30', u'MA31', u'MA32', u'MA33', u'MA34', u'MA35', u'MA36', u'MA37', u'MA38', u'MA39', u'MA40', u'MA41', u'MA42', u'MA43', u'MA44', u'MA45', u'MA46', u'MA47', u'MA48', u'MA49', u'MA50', u'MA51', u'MA52', u'MA53', u'MA54', u'MA55', u'MA56', u'MA57', u'MA58', u'MA59', u'MA60', u'MA61', u'MA62', u'MA63', u'MA64', u'MA65', u'MA66', u'MA67', u'MA68', u'MA69', u'MA70', u'MA71', u'MA72', u'MA73', u'MA74', u'MA75', u'MA76', u'MA77', u'MA78', u'MA79', u'MA80', u'MA81', u'MA82', u'MA83', u'MA84', u'MA85', u'MA86', u'MA87', u'MA88', u'MA89', u'MA90', u'MA91', u'MA92', u'MA93', u'MA94', u'MA95', u'MA96', u'MA97', u'MA98', u'MA99', u'MA100', u'MA101', u'MA102', u'MA103', u'MA104', u'MA105', u'MA106', u'MA107', u'MA108', u'MA109', u'MA110', u'MA111', u'MA112', u'MA113', u'MA114', u'MA115', u'MA116', u'MA117', u'MA118', u'MA119', u'MA120', u'MA121', u'MA122', u'MA123', u'MA124', u'MA125', u'MA126', u'MA127', u'MA128', u'MA129', u'MA130', u'MA131', u'MA132', u'MA133', u'MA134', u'N1', u'N2', u'N3', u'N4', u'N5', u'N6', u'N7', u'N8', u'N9', u'N10', u'N11', u'N12', u'N13', u'N14', u'N15', u'N16', u'N17', u'N18', u'N19', u'N20', u'N21', u'N22', u'N23', u'N24', u'N25', u'N26', u'N27', u'N28', u'N29', u'N30', u'N31', u'N32', u'N33', u'N34', u'N35', u'N36', u'N37', u'N38', u'N39', u'N40', u'N41', u'N42', u'N43', u'N44', u'N45', u'N46', u'N47', u'N48', u'N49', u'N50', u'N51', u'N52', u'N53', u'N54', u'N55', u'N56', u'N57', u'N58', u'N59', u'N60', u'N61', u'N62', u'N63', u'N64', u'N65', u'N66', u'N67', u'N68', u'N69', u'N70', u'N71', u'N72', u'N73', u'N74', u'N75', u'N76', u'N77', u'N78', u'N79', u'N80', u'N81', u'N82', u'N83', u'N84', u'N85', u'N86', u'N87', u'N88', u'N89', u'N90', u'N91', u'N92', u'N93', u'N94', u'N95', u'N96', u'N97', u'N98', u'N99', u'N100', u'N101', u'N102', u'N103', u'N104', u'N105', u'N106', u'N107', u'N108', u'N109', u'N110', u'N111', u'N112', u'N113', u'N114', u'N115', u'N116', u'N117', u'N118', u'N119', u'N120', u'N121', u'N122', u'N123', u'N124', u'N125', u'N126', u'N127', u'N128', u'N129', u'N130', u'N131', u'N132', u'N133', u'N134', u'N135', u'N136', u'N137', u'N138', u'N139', u'N140', u'N141', u'N142', u'N143', u'N144', u'N145', u'N146', u'N147', u'N148', u'N149', u'N150', u'N151', u'N152', u'N153', u'N154', u'N155', u'N156 '] ) ),
  Element( u'MOA08', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=8,
    codes=[] ) ),
  Element( u'MOA09', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=9,
    codes=[] ) ),
),
parsed_837_2330A,
parsed_837_2330B,
parsed_837_2330C,
parsed_837_2330D,
parsed_837_2330E,
parsed_837_2330F,
parsed_837_2330H,
)
parsed_837_2410 = Loop( u'2410', Properties(looptype='',repeat=u'25',pos=u'494',req_sit=u'S',desc=u'Drug Identification'),
Segment( u'LIN', Properties(syntax=u'P0405 P0607 P0809 P1011 P1213 P1415 P1617 P1819 P2021 P2223 P2425 P2627 P2829 P3031',req_sit=u'S',repeat=u'1',pos=u'494',desc=u'Drug Identification'),
  Element( u'LIN01', Properties(desc=u'Assigned Identification', req_sit=u'N', data_type=(u'AN',u'1',u'20'), position=1,
    codes=[] ) ),
  Element( u'LIN02', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[u'N4'] ) ),
  Element( u'LIN03', Properties(desc=u'Product/Service ID', req_sit=u'R', data_type=(u'AN',u'1',u'48'), position=3,
    codes=[] ) ),
  Element( u'LIN04', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=4,
    codes=[u'N4'] ) ),
  Element( u'LIN05', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=5,
    codes=[] ) ),
  Element( u'LIN06', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=6,
    codes=[u'N4'] ) ),
  Element( u'LIN07', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=7,
    codes=[] ) ),
  Element( u'LIN08', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=8,
    codes=[u'N4'] ) ),
  Element( u'LIN09', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=9,
    codes=[] ) ),
  Element( u'LIN10', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[u'N4'] ) ),
  Element( u'LIN11', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=11,
    codes=[] ) ),
  Element( u'LIN12', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=12,
    codes=[u'N4'] ) ),
  Element( u'LIN13', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=13,
    codes=[] ) ),
  Element( u'LIN14', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=14,
    codes=[u'N4'] ) ),
  Element( u'LIN15', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=15,
    codes=[] ) ),
  Element( u'LIN16', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=16,
    codes=[u'N4'] ) ),
  Element( u'LIN17', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=17,
    codes=[] ) ),
  Element( u'LIN18', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=18,
    codes=[u'N4'] ) ),
  Element( u'LIN19', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=19,
    codes=[] ) ),
  Element( u'LIN20', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=20,
    codes=[u'N4'] ) ),
  Element( u'LIN21', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=21,
    codes=[] ) ),
  Element( u'LIN22', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=22,
    codes=[u'N4'] ) ),
  Element( u'LIN23', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=23,
    codes=[] ) ),
  Element( u'LIN24', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=24,
    codes=[u'N4'] ) ),
  Element( u'LIN25', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=25,
    codes=[] ) ),
  Element( u'LIN26', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=26,
    codes=[u'N4'] ) ),
  Element( u'LIN27', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=27,
    codes=[] ) ),
  Element( u'LIN28', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=28,
    codes=[u'N4'] ) ),
  Element( u'LIN29', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=29,
    codes=[] ) ),
  Element( u'LIN30', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=30,
    codes=[u'N4'] ) ),
  Element( u'LIN31', Properties(desc=u'Product/Service ID', req_sit=u'N', data_type=(u'AN',u'1',u'48'), position=31,
    codes=[] ) ),
),
Segment( u'CTP', Properties(syntax=u'P0405 C0607 C0902 C1002 C1103',req_sit=u'S',repeat=u'1',pos=u'495',desc=u'Drug Pricing'),
  Element( u'CTP01', Properties(desc=u'Class of Trade Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[] ) ),
  Element( u'CTP02', Properties(desc=u'Price Identifier Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=2,
    codes=[] ) ),
  Element( u'CTP03', Properties(desc=u'Unit Price', req_sit=u'R', data_type=(u'R',u'1',u'17'), position=3,
    codes=[] ) ),
  Element( u'CTP04', Properties(desc=u'Quantity', req_sit=u'R', data_type=(u'R',u'1',u'15'), position=4,
    codes=[] ) ),
  Composite( u'C001', Properties(req_sit=u'R',refdes='',seq=u'05',desc=u'Composite Unit of Measure'),
    Element( u'CTP05-01', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=0,
      codes=[u'F2', u'GR', u'ML', u'UN'] ) ),
    Element( u'CTP05-02', Properties(desc=u'Exponent', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=1,
      codes=[] ) ),
    Element( u'CTP05-03', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=2,
      codes=[] ) ),
    Element( u'CTP05-04', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=3,
      codes=[] ) ),
    Element( u'CTP05-05', Properties(desc=u'Exponent', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=4,
      codes=[] ) ),
    Element( u'CTP05-06', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=5,
      codes=[] ) ),
    Element( u'CTP05-07', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=6,
      codes=[] ) ),
    Element( u'CTP05-08', Properties(desc=u'Exponent', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=7,
      codes=[] ) ),
    Element( u'CTP05-09', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=8,
      codes=[] ) ),
    Element( u'CTP05-10', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=9,
      codes=[] ) ),
    Element( u'CTP05-11', Properties(desc=u'Exponent', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=10,
      codes=[] ) ),
    Element( u'CTP05-12', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=11,
      codes=[] ) ),
    Element( u'CTP05-13', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=12,
      codes=[] ) ),
    Element( u'CTP05-14', Properties(desc=u'Exponent', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=13,
      codes=[] ) ),
    Element( u'CTP05-15', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=14,
      codes=[] ) ),
  ),
  Element( u'CTP06', Properties(desc=u'Price Multiplier Qualifier', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=6,
    codes=[] ) ),
  Element( u'CTP07', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'CTP08', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=8,
    codes=[] ) ),
  Element( u'CTP09', Properties(desc=u'Basis of Unit Price Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=9,
    codes=[] ) ),
  Element( u'CTP10', Properties(desc=u'Condition Value', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=10,
    codes=[] ) ),
  Element( u'CTP11', Properties(desc=u'Multiple Price Quantity', req_sit=u'N', data_type=(u'N0',u'1',u'2'), position=11,
    codes=[] ) ),
),
)
parsed_837_2420A = Loop( u'2420A', Properties(looptype='',repeat=u'1',pos=u'500',req_sit=u'S',desc=u'Attending Physician Name'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'500',desc=u'Attending Physician Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'71'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'PRV', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'505',desc=u'Attending Physician Specialty Information'),
  Element( u'PRV01', Properties(desc=u'Provider Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'AT'] ) ),
  Element( u'PRV02', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'ZZ'] ) ),
  Element( u'PRV03', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'PRV04', Properties(desc=u'State or Province Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=4,
    codes=[] ) ),
  Composite( u'C035', Properties(req_sit=u'N',refdes='',seq=u'05',desc=u'Provider Specialty Information'),
  ),
  Element( u'PRV06', Properties(desc=u'Provider Organization Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'525',desc=u'Attending Physician Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2420B = Loop( u'2420B', Properties(looptype='',repeat=u'1',pos=u'500',req_sit=u'S',desc=u'Operating Physician Name'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'500',desc=u'Operating Physician Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'72'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'PRV', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'505',desc=u'Operating Physician Specialty Information'),
  Element( u'PRV01', Properties(desc=u'Provider Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'OP'] ) ),
  Element( u'PRV02', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'ZZ'] ) ),
  Element( u'PRV03', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'PRV04', Properties(desc=u'State or Province Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=4,
    codes=[] ) ),
  Composite( u'C035', Properties(req_sit=u'N',refdes='',seq=u'05',desc=u'Provider Specialty Information'),
  ),
  Element( u'PRV06', Properties(desc=u'Provider Organization Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'525',desc=u'Operating Physician Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2420C = Loop( u'2420C', Properties(looptype='',repeat=u'1',pos=u'500',req_sit=u'S',desc=u'Other Provider Name'),
Segment( u'NM1', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'500',desc=u'Other Provider Name'),
  Element( u'NM101', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'73'] ) ),
  Element( u'NM102', Properties(desc=u'Entity Type Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'1', u'2'] ) ),
  Element( u'NM103', Properties(desc=u'Name Last or Organization Name', req_sit=u'R', data_type=(u'AN',u'1',u'60'), position=3,
    codes=[] ) ),
  Element( u'NM104', Properties(desc=u'Name First', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'NM105', Properties(desc=u'Name Middle', req_sit=u'S', data_type=(u'AN',u'1',u'25'), position=5,
    codes=[] ) ),
  Element( u'NM106', Properties(desc=u'Name Prefix', req_sit=u'N', data_type=(u'AN',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'NM107', Properties(desc=u'Name Suffix', req_sit=u'S', data_type=(u'AN',u'1',u'10'), position=7,
    codes=[] ) ),
  Element( u'NM108', Properties(desc=u'Identification Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=8,
    codes=[u'24', u'34', u'XX'] ) ),
  Element( u'NM109', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=9,
    codes=[] ) ),
  Element( u'NM110', Properties(desc=u'Entity Relationship Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[] ) ),
  Element( u'NM111', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=11,
    codes=[] ) ),
),
Segment( u'PRV', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'505',desc=u'Other Provider Specialty Information'),
  Element( u'PRV01', Properties(desc=u'Provider Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'OT', u'PE'] ) ),
  Element( u'PRV02', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'ZZ'] ) ),
  Element( u'PRV03', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'PRV04', Properties(desc=u'State or Province Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=4,
    codes=[] ) ),
  Composite( u'C035', Properties(req_sit=u'N',refdes='',seq=u'05',desc=u'Provider Specialty Information'),
  ),
  Element( u'PRV06', Properties(desc=u'Provider Organization Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=6,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'525',desc=u'Other Provider Secondary Identification'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'0B', u'1A', u'1B', u'1C', u'1D', u'1G', u'1H', u'EI', u'G2', u'LU', u'N5', u'SY', u'X5'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
)
parsed_837_2430 = Loop( u'2430', Properties(looptype='',repeat=u'25',pos=u'540',req_sit=u'S',desc=u'Service Line Adjudication Information'),
Segment( u'SVD', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'540',desc=u'Service Line Adjudication Information'),
  Element( u'SVD01', Properties(desc=u'Identification Code', req_sit=u'R', data_type=(u'AN',u'2',u'80'), position=1,
    codes=[] ) ),
  Element( u'SVD02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Composite( u'C003', Properties(req_sit=u'S',refdes='',seq=u'03',desc=u'Composite Medical Procedure Identifier'),
    Element( u'SVD03-01', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=0,
      codes=[u'HC', u'IV', u'ZZ'] ) ),
    Element( u'SVD03-02', Properties(desc=u'Product/Service ID', req_sit=u'R', data_type=(u'AN',u'1',u'48'), position=1,
      codes=[] ) ),
    Element( u'SVD03-03', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=2,
      codes=[] ) ),
    Element( u'SVD03-04', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=3,
      codes=[] ) ),
    Element( u'SVD03-05', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=4,
      codes=[] ) ),
    Element( u'SVD03-06', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=5,
      codes=[] ) ),
    Element( u'SVD03-07', Properties(desc=u'Description', req_sit=u'S', data_type=(u'AN',u'1',u'80'), position=6,
      codes=[] ) ),
  ),
  Element( u'SVD04', Properties(desc=u'Product/Service ID', req_sit=u'R', data_type=(u'AN',u'1',u'48'), position=4,
    codes=[] ) ),
  Element( u'SVD05', Properties(desc=u'Quantity', req_sit=u'R', data_type=(u'R',u'1',u'15'), position=5,
    codes=[] ) ),
  Element( u'SVD06', Properties(desc=u'Assigned Number', req_sit=u'S', data_type=(u'N0',u'1',u'6'), position=6,
    codes=[] ) ),
),
Segment( u'CAS', Properties(syntax='',req_sit=u'S',repeat=u'99',pos=u'545',desc=u'Service Line Adjustment'),
  Element( u'CAS01', Properties(desc=u'Claim Adjustment Group Code', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=1,
    codes=[u'CO', u'CR', u'OA', u'PI', u'PR'] ) ),
  Element( u'CAS02', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'R', data_type=(u'ID',u'1',u'5'), position=2,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'10', u'11', u'12', u'13', u'14', u'15', u'16', u'17', u'18', u'19', u'20', u'21', u'22', u'23', u'24', u'25', u'26', u'27', u'28', u'29', u'30', u'31', u'32', u'33', u'34', u'35', u'36', u'37', u'38', u'39', u'40', u'41', u'42', u'43', u'44', u'45', u'46', u'47', u'48', u'49', u'50', u'51', u'52', u'53', u'54', u'55', u'56', u'57', u'58', u'59', u'60', u'61', u'62', u'63', u'64', u'65', u'66', u'67', u'68', u'69', u'70', u'71', u'72', u'73', u'74', u'75', u'76', u'77', u'78', u'79', u'80', u'81', u'82', u'83', u'84', u'85', u'86', u'87', u'88', u'89', u'90', u'91', u'92', u'93', u'94', u'95', u'96', u'97', u'98', u'99', u'100', u'101', u'102', u'103', u'104', u'105', u'106', u'107', u'108', u'109', u'110', u'111', u'112', u'113', u'114', u'115', u'116', u'117', u'118', u'119', u'120', u'121', u'122', u'123', u'124', u'125', u'126', u'127', u'128', u'129', u'130', u'131', u'132', u'133', u'134', u'135', u'136', u'137', u'138', u'139', u'140', u'141', u'142', u'143', u'144', u'145', u'146', u'147', u'148', u'149', u'150', u'151', u'152', u'153', u'154', u'A0', u'A1', u'A2', u'A3', u'A4', u'A5', u'A6', u'A7', u'A8', u'B1', u'B2', u'B3', u'B4', u'B5', u'B6', u'B7', u'B8', u'B9', u'B10', u'B11', u'B12', u'B13', u'B14', u'B15', u'B16', u'B17', u'B18', u'B19', u'B20', u'B21', u'B22', u'B23', u'D1', u'D2', u'D3', u'D4', u'D5', u'D6', u'D7', u'D8', u'D9', u'D10', u'D11', u'D12', u'D13', u'D14', u'D15', u'W1'] ) ),
  Element( u'CAS03', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=3,
    codes=[] ) ),
  Element( u'CAS04', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=4,
    codes=[] ) ),
  Element( u'CAS05', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=5,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'10', u'11', u'12', u'13', u'14', u'15', u'16', u'17', u'18', u'19', u'20', u'21', u'22', u'23', u'24', u'25', u'26', u'27', u'28', u'29', u'30', u'31', u'32', u'33', u'34', u'35', u'36', u'37', u'38', u'39', u'40', u'41', u'42', u'43', u'44', u'45', u'46', u'47', u'48', u'49', u'50', u'51', u'52', u'53', u'54', u'55', u'56', u'57', u'58', u'59', u'60', u'61', u'62', u'63', u'64', u'65', u'66', u'67', u'68', u'69', u'70', u'71', u'72', u'73', u'74', u'75', u'76', u'77', u'78', u'79', u'80', u'81', u'82', u'83', u'84', u'85', u'86', u'87', u'88', u'89', u'90', u'91', u'92', u'93', u'94', u'95', u'96', u'97', u'98', u'99', u'100', u'101', u'102', u'103', u'104', u'105', u'106', u'107', u'108', u'109', u'110', u'111', u'112', u'113', u'114', u'115', u'116', u'117', u'118', u'119', u'120', u'121', u'122', u'123', u'124', u'125', u'126', u'127', u'128', u'129', u'130', u'131', u'132', u'133', u'134', u'135', u'136', u'137', u'138', u'139', u'140', u'141', u'142', u'143', u'144', u'145', u'146', u'147', u'148', u'149', u'150', u'151', u'152', u'153', u'154', u'A0', u'A1', u'A2', u'A3', u'A4', u'A5', u'A6', u'A7', u'A8', u'B1', u'B2', u'B3', u'B4', u'B5', u'B6', u'B7', u'B8', u'B9', u'B10', u'B11', u'B12', u'B13', u'B14', u'B15', u'B16', u'B17', u'B18', u'B19', u'B20', u'B21', u'B22', u'B23', u'D1', u'D2', u'D3', u'D4', u'D5', u'D6', u'D7', u'D8', u'D9', u'D10', u'D11', u'D12', u'D13', u'D14', u'D15', u'W1'] ) ),
  Element( u'CAS06', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=6,
    codes=[] ) ),
  Element( u'CAS07', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=7,
    codes=[] ) ),
  Element( u'CAS08', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=8,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'10', u'11', u'12', u'13', u'14', u'15', u'16', u'17', u'18', u'19', u'20', u'21', u'22', u'23', u'24', u'25', u'26', u'27', u'28', u'29', u'30', u'31', u'32', u'33', u'34', u'35', u'36', u'37', u'38', u'39', u'40', u'41', u'42', u'43', u'44', u'45', u'46', u'47', u'48', u'49', u'50', u'51', u'52', u'53', u'54', u'55', u'56', u'57', u'58', u'59', u'60', u'61', u'62', u'63', u'64', u'65', u'66', u'67', u'68', u'69', u'70', u'71', u'72', u'73', u'74', u'75', u'76', u'77', u'78', u'79', u'80', u'81', u'82', u'83', u'84', u'85', u'86', u'87', u'88', u'89', u'90', u'91', u'92', u'93', u'94', u'95', u'96', u'97', u'98', u'99', u'100', u'101', u'102', u'103', u'104', u'105', u'106', u'107', u'108', u'109', u'110', u'111', u'112', u'113', u'114', u'115', u'116', u'117', u'118', u'119', u'120', u'121', u'122', u'123', u'124', u'125', u'126', u'127', u'128', u'129', u'130', u'131', u'132', u'133', u'134', u'135', u'136', u'137', u'138', u'139', u'140', u'141', u'142', u'143', u'144', u'145', u'146', u'147', u'148', u'149', u'150', u'151', u'152', u'153', u'154', u'A0', u'A1', u'A2', u'A3', u'A4', u'A5', u'A6', u'A7', u'A8', u'B1', u'B2', u'B3', u'B4', u'B5', u'B6', u'B7', u'B8', u'B9', u'B10', u'B11', u'B12', u'B13', u'B14', u'B15', u'B16', u'B17', u'B18', u'B19', u'B20', u'B21', u'B22', u'B23', u'D1', u'D2', u'D3', u'D4', u'D5', u'D6', u'D7', u'D8', u'D9', u'D10', u'D11', u'D12', u'D13', u'D14', u'D15', u'W1'] ) ),
  Element( u'CAS09', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=9,
    codes=[] ) ),
  Element( u'CAS10', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=10,
    codes=[] ) ),
  Element( u'CAS11', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=11,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'10', u'11', u'12', u'13', u'14', u'15', u'16', u'17', u'18', u'19', u'20', u'21', u'22', u'23', u'24', u'25', u'26', u'27', u'28', u'29', u'30', u'31', u'32', u'33', u'34', u'35', u'36', u'37', u'38', u'39', u'40', u'41', u'42', u'43', u'44', u'45', u'46', u'47', u'48', u'49', u'50', u'51', u'52', u'53', u'54', u'55', u'56', u'57', u'58', u'59', u'60', u'61', u'62', u'63', u'64', u'65', u'66', u'67', u'68', u'69', u'70', u'71', u'72', u'73', u'74', u'75', u'76', u'77', u'78', u'79', u'80', u'81', u'82', u'83', u'84', u'85', u'86', u'87', u'88', u'89', u'90', u'91', u'92', u'93', u'94', u'95', u'96', u'97', u'98', u'99', u'100', u'101', u'102', u'103', u'104', u'105', u'106', u'107', u'108', u'109', u'110', u'111', u'112', u'113', u'114', u'115', u'116', u'117', u'118', u'119', u'120', u'121', u'122', u'123', u'124', u'125', u'126', u'127', u'128', u'129', u'130', u'131', u'132', u'133', u'134', u'135', u'136', u'137', u'138', u'139', u'140', u'141', u'142', u'143', u'144', u'145', u'146', u'147', u'148', u'149', u'150', u'151', u'152', u'153', u'154', u'A0', u'A1', u'A2', u'A3', u'A4', u'A5', u'A6', u'A7', u'A8', u'B1', u'B2', u'B3', u'B4', u'B5', u'B6', u'B7', u'B8', u'B9', u'B10', u'B11', u'B12', u'B13', u'B14', u'B15', u'B16', u'B17', u'B18', u'B19', u'B20', u'B21', u'B22', u'B23', u'D1', u'D2', u'D3', u'D4', u'D5', u'D6', u'D7', u'D8', u'D9', u'D10', u'D11', u'D12', u'D13', u'D14', u'D15', u'W1'] ) ),
  Element( u'CAS12', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=12,
    codes=[] ) ),
  Element( u'CAS13', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=13,
    codes=[] ) ),
  Element( u'CAS14', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=14,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'10', u'11', u'12', u'13', u'14', u'15', u'16', u'17', u'18', u'19', u'20', u'21', u'22', u'23', u'24', u'25', u'26', u'27', u'28', u'29', u'30', u'31', u'32', u'33', u'34', u'35', u'36', u'37', u'38', u'39', u'40', u'41', u'42', u'43', u'44', u'45', u'46', u'47', u'48', u'49', u'50', u'51', u'52', u'53', u'54', u'55', u'56', u'57', u'58', u'59', u'60', u'61', u'62', u'63', u'64', u'65', u'66', u'67', u'68', u'69', u'70', u'71', u'72', u'73', u'74', u'75', u'76', u'77', u'78', u'79', u'80', u'81', u'82', u'83', u'84', u'85', u'86', u'87', u'88', u'89', u'90', u'91', u'92', u'93', u'94', u'95', u'96', u'97', u'98', u'99', u'100', u'101', u'102', u'103', u'104', u'105', u'106', u'107', u'108', u'109', u'110', u'111', u'112', u'113', u'114', u'115', u'116', u'117', u'118', u'119', u'120', u'121', u'122', u'123', u'124', u'125', u'126', u'127', u'128', u'129', u'130', u'131', u'132', u'133', u'134', u'135', u'136', u'137', u'138', u'139', u'140', u'141', u'142', u'143', u'144', u'145', u'146', u'147', u'148', u'149', u'150', u'151', u'152', u'153', u'154', u'A0', u'A1', u'A2', u'A3', u'A4', u'A5', u'A6', u'A7', u'A8', u'B1', u'B2', u'B3', u'B4', u'B5', u'B6', u'B7', u'B8', u'B9', u'B10', u'B11', u'B12', u'B13', u'B14', u'B15', u'B16', u'B17', u'B18', u'B19', u'B20', u'B21', u'B22', u'B23', u'D1', u'D2', u'D3', u'D4', u'D5', u'D6', u'D7', u'D8', u'D9', u'D10', u'D11', u'D12', u'D13', u'D14', u'D15', u'W1'] ) ),
  Element( u'CAS15', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=15,
    codes=[] ) ),
  Element( u'CAS16', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=16,
    codes=[] ) ),
  Element( u'CAS17', Properties(desc=u'Claim Adjustment Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'5'), position=17,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'10', u'11', u'12', u'13', u'14', u'15', u'16', u'17', u'18', u'19', u'20', u'21', u'22', u'23', u'24', u'25', u'26', u'27', u'28', u'29', u'30', u'31', u'32', u'33', u'34', u'35', u'36', u'37', u'38', u'39', u'40', u'41', u'42', u'43', u'44', u'45', u'46', u'47', u'48', u'49', u'50', u'51', u'52', u'53', u'54', u'55', u'56', u'57', u'58', u'59', u'60', u'61', u'62', u'63', u'64', u'65', u'66', u'67', u'68', u'69', u'70', u'71', u'72', u'73', u'74', u'75', u'76', u'77', u'78', u'79', u'80', u'81', u'82', u'83', u'84', u'85', u'86', u'87', u'88', u'89', u'90', u'91', u'92', u'93', u'94', u'95', u'96', u'97', u'98', u'99', u'100', u'101', u'102', u'103', u'104', u'105', u'106', u'107', u'108', u'109', u'110', u'111', u'112', u'113', u'114', u'115', u'116', u'117', u'118', u'119', u'120', u'121', u'122', u'123', u'124', u'125', u'126', u'127', u'128', u'129', u'130', u'131', u'132', u'133', u'134', u'135', u'136', u'137', u'138', u'139', u'140', u'141', u'142', u'143', u'144', u'145', u'146', u'147', u'148', u'149', u'150', u'151', u'152', u'153', u'154', u'A0', u'A1', u'A2', u'A3', u'A4', u'A5', u'A6', u'A7', u'A8', u'B1', u'B2', u'B3', u'B4', u'B5', u'B6', u'B7', u'B8', u'B9', u'B10', u'B11', u'B12', u'B13', u'B14', u'B15', u'B16', u'B17', u'B18', u'B19', u'B20', u'B21', u'B22', u'B23', u'D1', u'D2', u'D3', u'D4', u'D5', u'D6', u'D7', u'D8', u'D9', u'D10', u'D11', u'D12', u'D13', u'D14', u'D15', u'W1'] ) ),
  Element( u'CAS18', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=18,
    codes=[] ) ),
  Element( u'CAS19', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=19,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'550',desc=u'Service Adjudication Date'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'573'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
)
parsed_837_2400 = Loop( u'2400', Properties(looptype='',repeat=u'999',pos=u'365',req_sit=u'R',desc=u'Service Line Number'),
Segment( u'LX', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'365',desc=u'Service Line Number'),
  Element( u'LX01', Properties(desc=u'Assigned Number', req_sit=u'R', data_type=(u'N0',u'1',u'6'), position=1,
    codes=[] ) ),
),
Segment( u'SV2', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'375',desc=u'Institutional Service Line'),
  Element( u'SV201', Properties(desc=u'Product/Service ID', req_sit=u'R', data_type=(u'AN',u'1',u'48'), position=1,
    codes=[] ) ),
  Composite( u'C003', Properties(req_sit=u'S',refdes='',seq=u'02',desc=u'Service Line Procedure Code'),
    Element( u'SV202-01', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=0,
      codes=[u'HC', u'IV', u'N4', u'ZZ'] ) ),
    Element( u'SV202-02', Properties(desc=u'Product/Service ID', req_sit=u'R', data_type=(u'AN',u'1',u'48'), position=1,
      codes=[] ) ),
    Element( u'SV202-03', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=2,
      codes=[] ) ),
    Element( u'SV202-04', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=3,
      codes=[] ) ),
    Element( u'SV202-05', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=4,
      codes=[] ) ),
    Element( u'SV202-06', Properties(desc=u'Procedure Modifier', req_sit=u'S', data_type=(u'AN',u'2',u'2'), position=5,
      codes=[] ) ),
    Element( u'SV202-07', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=6,
      codes=[] ) ),
  ),
  Element( u'SV203', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=3,
    codes=[] ) ),
  Element( u'SV204', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=4,
    codes=[u'DA', u'F2', u'UN'] ) ),
  Element( u'SV205', Properties(desc=u'Quantity', req_sit=u'R', data_type=(u'R',u'1',u'15'), position=5,
    codes=[] ) ),
  Element( u'SV206', Properties(desc=u'Unit Rate', req_sit=u'S', data_type=(u'R',u'1',u'10'), position=6,
    codes=[] ) ),
  Element( u'SV207', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=7,
    codes=[] ) ),
  Element( u'SV208', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=8,
    codes=[] ) ),
  Element( u'SV209', Properties(desc=u'Nursing Home Residential Status Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=9,
    codes=[] ) ),
  Element( u'SV210', Properties(desc=u'Level of Care Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=10,
    codes=[] ) ),
),
Segment( u'PWK', Properties(syntax='',req_sit=u'S',repeat=u'5',pos=u'420',desc=u'Line Supplemental Information'),
  Element( u'PWK01', Properties(desc=u'Report Type Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'AS', u'B2', u'B3', u'B4', u'CT', u'DA', u'DG', u'DS', u'EB', u'MT', u'NN', u'OB', u'OZ', u'PN', u'PO', u'PZ', u'RB', u'RR', u'RT'] ) ),
  Element( u'PWK02', Properties(desc=u'Report Transmission Code', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=2,
    codes=[u'AA', u'AB', u'AD', u'AF', u'AG', u'BM', u'EL', u'EM', u'FX'] ) ),
  Element( u'PWK03', Properties(desc=u'Report Copies Needed', req_sit=u'N', data_type=(u'N0',u'1',u'2'), position=3,
    codes=[] ) ),
  Element( u'PWK04', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'PWK05', Properties(desc=u'Identification Code Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[u'AC'] ) ),
  Element( u'PWK06', Properties(desc=u'Identification Code', req_sit=u'S', data_type=(u'AN',u'2',u'80'), position=6,
    codes=[] ) ),
  Element( u'PWK07', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=7,
    codes=[] ) ),
  Composite( u'C002', Properties(req_sit=u'N',refdes='',seq=u'08',desc=u'Actions Indicated'),
  ),
  Element( u'PWK09', Properties(desc=u'Request Category Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=9,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'455',desc=u'Service Line Date'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'472'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8', u'RD8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'455',desc=u'Assessment Date'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'866'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'475',desc=u'Service Tax Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'GT'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'475',desc=u'Facility Tax Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'N8'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'HCP', Properties(syntax=u'R0113 P0910 P1112',req_sit=u'S',repeat=u'1',pos=u'492',desc=u'Line Pricing/Repricing Information'),
  Element( u'HCP01', Properties(desc=u'Pricing Methodology', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'00', u'01', u'02', u'03', u'04', u'05', u'06', u'07', u'08', u'09', u'10', u'11', u'12', u'13', u'14'] ) ),
  Element( u'HCP02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'HCP03', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=3,
    codes=[] ) ),
  Element( u'HCP04', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=4,
    codes=[] ) ),
  Element( u'HCP05', Properties(desc=u'Rate', req_sit=u'S', data_type=(u'R',u'1',u'9'), position=5,
    codes=[] ) ),
  Element( u'HCP06', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=6,
    codes=[] ) ),
  Element( u'HCP07', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=7,
    codes=[] ) ),
  Element( u'HCP08', Properties(desc=u'Product/Service ID', req_sit=u'S', data_type=(u'AN',u'1',u'48'), position=8,
    codes=[] ) ),
  Element( u'HCP09', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=9,
    codes=[u'HC'] ) ),
  Element( u'HCP10', Properties(desc=u'Product/Service ID', req_sit=u'S', data_type=(u'AN',u'1',u'48'), position=10,
    codes=[] ) ),
  Element( u'HCP11', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=11,
    codes=[u'DA', u'UN'] ) ),
  Element( u'HCP12', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=12,
    codes=[] ) ),
  Element( u'HCP13', Properties(desc=u'Reject Reason Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=13,
    codes=[u'T1', u'T2', u'T3', u'T4', u'T5', u'T6'] ) ),
  Element( u'HCP14', Properties(desc=u'Policy Compliance Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=14,
    codes=[u'1', u'2', u'3', u'4', u'5'] ) ),
  Element( u'HCP15', Properties(desc=u'Exception Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=15,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6'] ) ),
),
parsed_837_2410,
parsed_837_2420A,
parsed_837_2420B,
parsed_837_2420C,
parsed_837_2430,
)
parsed_837_2300 = Loop( u'2300', Properties(looptype='',repeat=u'100',pos=u'130',req_sit=u'R',desc=u'Claim Information'),
Segment( u'CLM', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'130',desc=u'Claim Information'),
  Element( u'CLM01', Properties(desc=u"Claim Submitter's Identifier", req_sit=u'R', data_type=(u'AN',u'1',u'38'), position=1,
    codes=[] ) ),
  Element( u'CLM02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'CLM03', Properties(desc=u'Claim Filing Indicator Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=3,
    codes=[] ) ),
  Element( u'CLM04', Properties(desc=u'Non-Institutional Claim Type Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=4,
    codes=[] ) ),
  Composite( u'C023', Properties(req_sit=u'R',refdes='',seq=u'05',desc=u'Type of Bill'),
    Element( u'CLM05-01', Properties(desc=u'Facility Code Value', req_sit=u'R', data_type=(u'AN',u'1',u'2'), position=0,
      codes=[] ) ),
    Element( u'CLM05-02', Properties(desc=u'Facility Code Qualifier', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=1,
      codes=[u'A'] ) ),
    Element( u'CLM05-03', Properties(desc=u'Claim Frequency Type Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
      codes=[u'0', u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'A', u'B', u'C', u'D', u'E', u'F', u'G', u'H', u'I', u'J', u'K', u'L', u'M', u'N', u'O', u'X', u'Y', u'Z '] ) ),
  ),
  Element( u'CLM06', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=6,
    codes=[u'N', u'Y'] ) ),
  Element( u'CLM07', Properties(desc=u'Provider Accept Assignment Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=7,
    codes=[u'A', u'C'] ) ),
  Element( u'CLM08', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=8,
    codes=[u'N', u'Y'] ) ),
  Element( u'CLM09', Properties(desc=u'Release of Information Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=9,
    codes=[u'A', u'I', u'M', u'N', u'O', u'Y'] ) ),
  Element( u'CLM10', Properties(desc=u'Patient Signature Source Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=10,
    codes=[] ) ),
  Composite( u'C024', Properties(req_sit=u'N',refdes='',seq=u'11',desc=u'Property and Casualty Related Causes Codes'),
  ),
  Element( u'CLM12', Properties(desc=u'Special Program Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=12,
    codes=[u'01', u'02', u'03', u'05', u'07', u'08', u'09'] ) ),
  Element( u'CLM13', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=13,
    codes=[] ) ),
  Element( u'CLM14', Properties(desc=u'Level of Service Code', req_sit=u'N', data_type=(u'ID',u'1',u'3'), position=14,
    codes=[] ) ),
  Element( u'CLM15', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=15,
    codes=[] ) ),
  Element( u'CLM16', Properties(desc=u'Provider Agreement Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=16,
    codes=[] ) ),
  Element( u'CLM17', Properties(desc=u'Claim Status Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=17,
    codes=[] ) ),
  Element( u'CLM18', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=18,
    codes=[u'N', u'Y'] ) ),
  Element( u'CLM19', Properties(desc=u'Claim Submission Reason Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=19,
    codes=[] ) ),
  Element( u'CLM20', Properties(desc=u'Delay Reason Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=20,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8', u'9', u'10', u'11'] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'135',desc=u'Discharge Hour'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'096'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'TM'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'135',desc=u'Statement Dates'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'434'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'D8', u'RD8'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'DTP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'135',desc=u'Admission Date/Hour'),
  Element( u'DTP01', Properties(desc=u'Date/Time Qualifier', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'435'] ) ),
  Element( u'DTP02', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'DT'] ) ),
  Element( u'DTP03', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
    codes=[] ) ),
),
Segment( u'CL1', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'140',desc=u'Institutional Claim Code'),
  Element( u'CL101', Properties(desc=u'Admission Type Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=1,
    codes=[] ) ),
  Element( u'CL102', Properties(desc=u'Admission Source Code', req_sit=u'S', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[] ) ),
  Element( u'CL103', Properties(desc=u'Patient Status Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=3,
    codes=[] ) ),
  Element( u'CL104', Properties(desc=u'Nursing Home Residential Status Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[] ) ),
),
Segment( u'PWK', Properties(syntax='',req_sit=u'S',repeat=u'10',pos=u'155',desc=u'Claim Supplemental Information'),
  Element( u'PWK01', Properties(desc=u'Report Type Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'AS', u'B2', u'B3', u'B4', u'CT', u'DA', u'DG', u'DS', u'EB', u'MT', u'NN', u'OB', u'OZ', u'PN', u'PO', u'PZ', u'RB', u'RR', u'RT'] ) ),
  Element( u'PWK02', Properties(desc=u'Report Transmission Code', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=2,
    codes=[u'AA', u'BM', u'EL', u'EM', u'FX'] ) ),
  Element( u'PWK03', Properties(desc=u'Report Copies Needed', req_sit=u'N', data_type=(u'N0',u'1',u'2'), position=3,
    codes=[] ) ),
  Element( u'PWK04', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'PWK05', Properties(desc=u'Identification Code Qualifier', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=5,
    codes=[u'AC'] ) ),
  Element( u'PWK06', Properties(desc=u'Identification Code', req_sit=u'S', data_type=(u'AN',u'2',u'80'), position=6,
    codes=[] ) ),
  Element( u'PWK07', Properties(desc=u'Description', req_sit=u'S', data_type=(u'AN',u'1',u'80'), position=7,
    codes=[] ) ),
  Composite( u'C002', Properties(req_sit=u'N',refdes='',seq=u'08',desc=u'Actions Indicated'),
  ),
  Element( u'PWK09', Properties(desc=u'Request Category Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=9,
    codes=[] ) ),
),
Segment( u'CN1', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'160',desc=u'Contract Information'),
  Element( u'CN101', Properties(desc=u'Contract Type Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'01', u'02', u'03', u'04', u'05', u'06', u'09'] ) ),
  Element( u'CN102', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'CN103', Properties(desc=u'Percent, Decimal Format', req_sit=u'S', data_type=(u'R',u'1',u'6'), position=3,
    codes=[] ) ),
  Element( u'CN104', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=4,
    codes=[] ) ),
  Element( u'CN105', Properties(desc=u'Terms Discount Percent', req_sit=u'S', data_type=(u'R',u'1',u'6'), position=5,
    codes=[] ) ),
  Element( u'CN106', Properties(desc=u'Version Identifier', req_sit=u'S', data_type=(u'AN',u'1',u'30'), position=6,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'175',desc=u'Payer Estimated Amount Due'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'C5'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'175',desc=u'Patient Estimated Amount Due'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'F3'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'175',desc=u'Patient Paid Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'F5'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'AMT', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'175',desc=u'Credit/Debit Card Maximum Amount'),
  Element( u'AMT01', Properties(desc=u'Amount Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'MA'] ) ),
  Element( u'AMT02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'AMT03', Properties(desc=u'Credit/Debit Flag Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=3,
    codes=[] ) ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Adjusted Repriced Claim Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'9C'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Repriced Claim Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'9A'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Claim Identification Number For Clearinghouses and Other Transmission Intermediaries'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'D9'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'2',pos=u'180',desc=u'Document Identification Code'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'DD'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Original Reference Number (ICN/DCN)'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'F8'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Investigational Device Exemption Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'LX'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Service Authorization Exception Code'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'4N'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7'] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Peer Review Organization (PRO) Approval Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'G4'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'2',pos=u'180',desc=u'Prior Authorization or Referral Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'9F', u'G1'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Medical Record Number'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'EA'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'REF', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'180',desc=u'Demonstration Project Identifier'),
  Element( u'REF01', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'P4'] ) ),
  Element( u'REF02', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=2,
    codes=[] ) ),
  Element( u'REF03', Properties(desc=u'Description', req_sit=u'N', data_type=(u'AN',u'1',u'80'), position=3,
    codes=[] ) ),
  Composite( u'C040', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Reference Identifier'),
  ),
),
Segment( u'K3', Properties(syntax='',req_sit=u'S',repeat=u'10',pos=u'185',desc=u'File Information'),
  Element( u'K301', Properties(desc=u'Fixed Format Information', req_sit=u'R', data_type=(u'AN',u'1',u'80'), position=1,
    codes=[] ) ),
  Element( u'K302', Properties(desc=u'Record Format Code', req_sit=u'N', data_type=(u'ID',u'1',u'2'), position=2,
    codes=[] ) ),
  Composite( u'C001', Properties(req_sit=u'N',refdes='',seq=u'03',desc=u'Composite Unit of Measure'),
  ),
),
Segment( u'NTE', Properties(syntax='',req_sit=u'S',repeat=u'10',pos=u'190',desc=u'Claim Note'),
  Element( u'NTE01', Properties(desc=u'Note Reference Code', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'ALG', u'DCP', u'DGN', u'DME', u'MED', u'NTR', u'ODT', u'RHB', u'RLH', u'RNH', u'SET', u'SFM', u'SPT', u'UPI'] ) ),
  Element( u'NTE02', Properties(desc=u'Description', req_sit=u'R', data_type=(u'AN',u'1',u'80'), position=2,
    codes=[] ) ),
),
Segment( u'NTE', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'190',desc=u'Billing Note'),
  Element( u'NTE01', Properties(desc=u'Note Reference Code', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'ADD'] ) ),
  Element( u'NTE02', Properties(desc=u'Description', req_sit=u'R', data_type=(u'AN',u'1',u'80'), position=2,
    codes=[] ) ),
),
Segment( u'CR6', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'216',desc=u'Home Health Care Information'),
  Element( u'CR601', Properties(desc=u'Prognosis Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=1,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6', u'7', u'8'] ) ),
  Element( u'CR602', Properties(desc=u'Date', req_sit=u'R', data_type=(u'DT',u'8',u'8'), position=2,
    codes=[] ) ),
  Element( u'CR603', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=3,
    codes=[u'RD8'] ) ),
  Element( u'CR604', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=4,
    codes=[] ) ),
  Element( u'CR605', Properties(desc=u'Date', req_sit=u'R', data_type=(u'DT',u'8',u'8'), position=5,
    codes=[] ) ),
  Element( u'CR606', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=6,
    codes=[u'N', u'U', u'Y'] ) ),
  Element( u'CR607', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=7,
    codes=[u'N', u'Y'] ) ),
  Element( u'CR608', Properties(desc=u'Certification Type Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=8,
    codes=[u'I', u'R', u'S'] ) ),
  Element( u'CR609', Properties(desc=u'Date', req_sit=u'S', data_type=(u'DT',u'8',u'8'), position=9,
    codes=[] ) ),
  Element( u'CR610', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=10,
    codes=[u'HC', u'ID'] ) ),
  Element( u'CR611', Properties(desc=u'Medical Code Value', req_sit=u'S', data_type=(u'AN',u'1',u'15'), position=11,
    codes=[] ) ),
  Element( u'CR612', Properties(desc=u'Date', req_sit=u'S', data_type=(u'DT',u'8',u'8'), position=12,
    codes=[] ) ),
  Element( u'CR613', Properties(desc=u'Date', req_sit=u'S', data_type=(u'DT',u'8',u'8'), position=13,
    codes=[] ) ),
  Element( u'CR614', Properties(desc=u'Date', req_sit=u'S', data_type=(u'DT',u'8',u'8'), position=14,
    codes=[] ) ),
  Element( u'CR615', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=15,
    codes=[u'RD8'] ) ),
  Element( u'CR616', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=16,
    codes=[] ) ),
  Element( u'CR617', Properties(desc=u'Patient Location Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=17,
    codes=[u'A', u'B', u'C', u'D', u'E', u'F', u'G', u'H', u'L', u'M', u'O', u'R', u'S', u'T'] ) ),
  Element( u'CR618', Properties(desc=u'Date', req_sit=u'S', data_type=(u'DT',u'8',u'8'), position=18,
    codes=[] ) ),
  Element( u'CR619', Properties(desc=u'Date', req_sit=u'S', data_type=(u'DT',u'8',u'8'), position=19,
    codes=[] ) ),
  Element( u'CR620', Properties(desc=u'Date', req_sit=u'S', data_type=(u'DT',u'8',u'8'), position=20,
    codes=[] ) ),
  Element( u'CR621', Properties(desc=u'Date', req_sit=u'S', data_type=(u'DT',u'8',u'8'), position=21,
    codes=[] ) ),
),
Segment( u'CRC', Properties(syntax='',req_sit=u'S',repeat=u'3',pos=u'220',desc=u'Home Health Functional Limitations'),
  Element( u'CRC01', Properties(desc=u'Code Category', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'75'] ) ),
  Element( u'CRC02', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'N', u'Y'] ) ),
  Element( u'CRC03', Properties(desc=u'Condition Indicator', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=3,
    codes=[u'AA', u'AL', u'BL', u'CO', u'DY', u'EL', u'HL', u'LB', u'OL', u'PA', u'SL'] ) ),
  Element( u'CRC04', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[u'AA', u'AL', u'BL', u'CO', u'DY', u'EL', u'HL', u'LB', u'OL', u'PA', u'SL'] ) ),
  Element( u'CRC05', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=5,
    codes=[u'AA', u'AL', u'BL', u'CO', u'DY', u'EL', u'HL', u'LB', u'OL', u'PA', u'SL'] ) ),
  Element( u'CRC06', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=6,
    codes=[u'AA', u'AL', u'BL', u'CO', u'DY', u'EL', u'HL', u'LB', u'OL', u'PA', u'SL'] ) ),
  Element( u'CRC07', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=7,
    codes=[u'AA', u'AL', u'BL', u'CO', u'DY', u'EL', u'HL', u'LB', u'OL', u'PA', u'SL'] ) ),
),
Segment( u'CRC', Properties(syntax='',req_sit=u'S',repeat=u'3',pos=u'220',desc=u'Home Health Activities Permitted'),
  Element( u'CRC01', Properties(desc=u'Code Category', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'76'] ) ),
  Element( u'CRC02', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'N', u'Y'] ) ),
  Element( u'CRC03', Properties(desc=u'Condition Indicator', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=3,
    codes=[u'BR', u'CA', u'CB', u'CR', u'EP', u'IH', u'NR', u'PW', u'TR', u'UT', u'WA', u'WR'] ) ),
  Element( u'CRC04', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[u'BR', u'CA', u'CB', u'CR', u'EP', u'IH', u'NR', u'PW', u'TR', u'UT', u'WA', u'WR'] ) ),
  Element( u'CRC05', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=5,
    codes=[u'BR', u'CA', u'CB', u'CR', u'EP', u'IH', u'NR', u'PW', u'TR', u'UT', u'WA', u'WR'] ) ),
  Element( u'CRC06', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=6,
    codes=[u'BR', u'CA', u'CB', u'CR', u'EP', u'IH', u'NR', u'PW', u'TR', u'UT', u'WA', u'WR'] ) ),
  Element( u'CRC07', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=7,
    codes=[u'BR', u'CA', u'CB', u'CR', u'EP', u'IH', u'NR', u'PW', u'TR', u'UT', u'WA', u'WR'] ) ),
),
Segment( u'CRC', Properties(syntax='',req_sit=u'S',repeat=u'2',pos=u'220',desc=u'Home Health Mental Status'),
  Element( u'CRC01', Properties(desc=u'Code Category', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'77'] ) ),
  Element( u'CRC02', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[u'N', u'Y'] ) ),
  Element( u'CRC03', Properties(desc=u'Condition Indicator', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=3,
    codes=[u'AG', u'CM', u'DI', u'DP', u'FO', u'LE', u'MC', u'OT'] ) ),
  Element( u'CRC04', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[u'AG', u'CM', u'DI', u'DP', u'FO', u'LE', u'MC', u'OT'] ) ),
  Element( u'CRC05', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=5,
    codes=[u'AG', u'CM', u'DI', u'DP', u'FO', u'LE', u'MC', u'OT'] ) ),
  Element( u'CRC06', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=6,
    codes=[u'AG', u'CM', u'DI', u'DP', u'FO', u'LE', u'MC', u'OT'] ) ),
  Element( u'CRC07', Properties(desc=u'Condition Indicator', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=7,
    codes=[u'AG', u'CM', u'DI', u'DP', u'FO', u'LE', u'MC', u'OT'] ) ),
),
Segment( u'HI', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'231',desc=u'Principal, Admitting, E-Code and Patient Reason for Visit Diagnosis Information'),
  Composite( u'C022', Properties(req_sit=u'R',refdes='',seq=u'01',desc=u'Health Care Code Information'),
    Element( u'HI01-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BK'] ) ),
    Element( u'HI01-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI01-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI01-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI01-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI01-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI01-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'02',desc=u'Health Care Code Information'),
    Element( u'HI02-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BJ', u'ZZ'] ) ),
    Element( u'HI02-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI02-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI02-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI02-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI02-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI02-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'03',desc=u'Health Care Code Information'),
    Element( u'HI03-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BN'] ) ),
    Element( u'HI03-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI03-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI03-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI03-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI03-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI03-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'05',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'06',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'07',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'08',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'09',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'10',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'11',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'12',desc=u'Health Care Code Information'),
  ),
),
Segment( u'HI', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'231',desc=u'Diagnosis Related Group (DRG) Information'),
  Composite( u'C022', Properties(req_sit=u'R',refdes='',seq=u'01',desc=u'Health Care Code Information'),
    Element( u'HI01-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'DR'] ) ),
    Element( u'HI01-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI01-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI01-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI01-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI01-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI01-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'02',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'03',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'05',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'06',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'07',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'08',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'09',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'10',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'11',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'12',desc=u'Health Care Code Information'),
  ),
),
Segment( u'HI', Properties(syntax='',req_sit=u'S',repeat=u'2',pos=u'231',desc=u'Other Diagnosis Information'),
  Composite( u'C022', Properties(req_sit=u'R',refdes='',seq=u'01',desc=u'Health Care Code Information'),
    Element( u'HI01-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI01-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI01-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI01-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI01-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI01-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI01-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'02',desc=u'Health Care Code Information'),
    Element( u'HI02-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI02-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI02-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI02-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI02-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI02-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI02-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'03',desc=u'Health Care Code Information'),
    Element( u'HI03-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI03-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI03-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI03-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI03-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI03-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI03-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'04',desc=u'Health Care Code Information'),
    Element( u'HI04-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI04-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI04-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI04-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI04-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI04-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI04-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'05',desc=u'Health Care Code Information'),
    Element( u'HI05-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI05-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI05-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI05-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI05-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI05-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI05-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'06',desc=u'Health Care Code Information'),
    Element( u'HI06-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI06-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI06-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI06-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI06-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI06-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI06-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'07',desc=u'Health Care Code Information'),
    Element( u'HI07-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI07-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI07-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI07-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI07-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI07-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI07-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'08',desc=u'Health Care Code Information'),
    Element( u'HI08-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI08-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI08-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI08-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI08-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI08-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI08-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'09',desc=u'Health Care Code Information'),
    Element( u'HI09-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI09-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI09-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI09-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI09-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI09-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI09-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'10',desc=u'Health Care Code Information'),
    Element( u'HI10-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI10-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI10-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI10-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI10-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI10-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI10-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'11',desc=u'Health Care Code Information'),
    Element( u'HI11-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI11-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI11-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI11-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI11-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI11-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI11-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'12',desc=u'Health Care Code Information'),
    Element( u'HI12-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BF'] ) ),
    Element( u'HI12-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI12-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI12-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI12-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI12-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI12-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
),
Segment( u'HI', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'231',desc=u'Principal Procedure Information'),
  Composite( u'C022', Properties(req_sit=u'R',refdes='',seq=u'01',desc=u'Health Care Code Information'),
    Element( u'HI01-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BP', u'BR'] ) ),
    Element( u'HI01-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI01-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI01-04', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI01-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI01-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI01-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'02',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'03',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'04',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'05',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'06',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'07',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'08',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'09',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'10',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'11',desc=u'Health Care Code Information'),
  ),
  Composite( u'C022', Properties(req_sit=u'N',refdes='',seq=u'12',desc=u'Health Care Code Information'),
  ),
),
Segment( u'HI', Properties(syntax='',req_sit=u'S',repeat=u'2',pos=u'231',desc=u'Other Procedure Information'),
  Composite( u'C022', Properties(req_sit=u'R',refdes='',seq=u'01',desc=u'Health Care Code Information'),
    Element( u'HI01-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BO', u'BQ'] ) ),
    Element( u'HI01-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI01-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI01-04', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI01-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI01-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI01-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'02',desc=u'Health Care Code Information'),
    Element( u'HI02-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BO', u'BQ'] ) ),
    Element( u'HI02-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI02-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI02-04', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI02-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI02-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI02-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'03',desc=u'Health Care Code Information'),
    Element( u'HI03-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BO', u'BQ'] ) ),
    Element( u'HI03-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI03-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI03-04', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI03-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI03-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI03-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'04',desc=u'Health Care Code Information'),
    Element( u'HI04-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BO', u'BQ'] ) ),
    Element( u'HI04-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI04-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI04-04', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI04-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI04-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI04-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'05',desc=u'Health Care Code Information'),
    Element( u'HI05-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BO', u'BQ'] ) ),
    Element( u'HI05-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI05-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI05-04', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI05-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI05-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI05-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'06',desc=u'Health Care Code Information'),
    Element( u'HI06-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BO', u'BQ'] ) ),
    Element( u'HI06-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI06-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI06-04', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI06-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI06-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI06-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'07',desc=u'Health Care Code Information'),
    Element( u'HI07-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BO', u'BQ'] ) ),
    Element( u'HI07-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI07-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI07-04', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI07-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI07-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI07-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'08',desc=u'Health Care Code Information'),
    Element( u'HI08-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BO', u'BQ'] ) ),
    Element( u'HI08-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI08-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI08-04', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI08-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI08-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI08-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'09',desc=u'Health Care Code Information'),
    Element( u'HI09-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BO', u'BQ'] ) ),
    Element( u'HI09-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI09-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI09-04', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI09-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI09-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI09-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'10',desc=u'Health Care Code Information'),
    Element( u'HI10-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BO', u'BQ'] ) ),
    Element( u'HI10-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI10-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI10-04', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI10-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI10-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI10-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'11',desc=u'Health Care Code Information'),
    Element( u'HI11-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BO', u'BQ'] ) ),
    Element( u'HI11-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI11-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI11-04', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI11-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI11-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI11-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'12',desc=u'Health Care Code Information'),
    Element( u'HI12-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BO', u'BQ'] ) ),
    Element( u'HI12-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI12-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI12-04', Properties(desc=u'Date Time Period', req_sit=u'S', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI12-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI12-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI12-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
),
Segment( u'HI', Properties(syntax='',req_sit=u'S',repeat=u'2',pos=u'231',desc=u'Occurrence Span Information'),
  Composite( u'C022', Properties(req_sit=u'R',refdes='',seq=u'01',desc=u'Health Care Code Information'),
    Element( u'HI01-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BI'] ) ),
    Element( u'HI01-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI01-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'RD8'] ) ),
    Element( u'HI01-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI01-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI01-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI01-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'02',desc=u'Health Care Code Information'),
    Element( u'HI02-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BI'] ) ),
    Element( u'HI02-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI02-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'RD8'] ) ),
    Element( u'HI02-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI02-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI02-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI02-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'03',desc=u'Health Care Code Information'),
    Element( u'HI03-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BI'] ) ),
    Element( u'HI03-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI03-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'RD8'] ) ),
    Element( u'HI03-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI03-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI03-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI03-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'04',desc=u'Health Care Code Information'),
    Element( u'HI04-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BI'] ) ),
    Element( u'HI04-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI04-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'RD8'] ) ),
    Element( u'HI04-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI04-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI04-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI04-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'05',desc=u'Health Care Code Information'),
    Element( u'HI05-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BI'] ) ),
    Element( u'HI05-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI05-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'RD8'] ) ),
    Element( u'HI05-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI05-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI05-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI05-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'06',desc=u'Health Care Code Information'),
    Element( u'HI06-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BI'] ) ),
    Element( u'HI06-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI06-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'RD8'] ) ),
    Element( u'HI06-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI06-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI06-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI06-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'07',desc=u'Health Care Code Information'),
    Element( u'HI07-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BI'] ) ),
    Element( u'HI07-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI07-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'RD8'] ) ),
    Element( u'HI07-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI07-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI07-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI07-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'08',desc=u'Health Care Code Information'),
    Element( u'HI08-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BI'] ) ),
    Element( u'HI08-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI08-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'RD8'] ) ),
    Element( u'HI08-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI08-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI08-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI08-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'09',desc=u'Health Care Code Information'),
    Element( u'HI09-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BI'] ) ),
    Element( u'HI09-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI09-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'RD8'] ) ),
    Element( u'HI09-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI09-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI09-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI09-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'10',desc=u'Health Care Code Information'),
    Element( u'HI10-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BI'] ) ),
    Element( u'HI10-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI10-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'RD8'] ) ),
    Element( u'HI10-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI10-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI10-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI10-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'11',desc=u'Health Care Code Information'),
    Element( u'HI11-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BI'] ) ),
    Element( u'HI11-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI11-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'RD8'] ) ),
    Element( u'HI11-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI11-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI11-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI11-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'12',desc=u'Health Care Code Information'),
    Element( u'HI12-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BI'] ) ),
    Element( u'HI12-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI12-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'RD8'] ) ),
    Element( u'HI12-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI12-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI12-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI12-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
),
Segment( u'HI', Properties(syntax='',req_sit=u'S',repeat=u'2',pos=u'231',desc=u'Occurrence Information'),
  Composite( u'C022', Properties(req_sit=u'R',refdes='',seq=u'01',desc=u'Health Care Code Information'),
    Element( u'HI01-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BH'] ) ),
    Element( u'HI01-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI01-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI01-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI01-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI01-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI01-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'02',desc=u'Health Care Code Information'),
    Element( u'HI02-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BH'] ) ),
    Element( u'HI02-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI02-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI02-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI02-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI02-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI02-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'03',desc=u'Health Care Code Information'),
    Element( u'HI03-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BH'] ) ),
    Element( u'HI03-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI03-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI03-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI03-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI03-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI03-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'04',desc=u'Health Care Code Information'),
    Element( u'HI04-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BH'] ) ),
    Element( u'HI04-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI04-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI04-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI04-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI04-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI04-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'05',desc=u'Health Care Code Information'),
    Element( u'HI05-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BH'] ) ),
    Element( u'HI05-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI05-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI05-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI05-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI05-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI05-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'06',desc=u'Health Care Code Information'),
    Element( u'HI06-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BH'] ) ),
    Element( u'HI06-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI06-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI06-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI06-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI06-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI06-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'07',desc=u'Health Care Code Information'),
    Element( u'HI07-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BH'] ) ),
    Element( u'HI07-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI07-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI07-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI07-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI07-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI07-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'08',desc=u'Health Care Code Information'),
    Element( u'HI08-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BH'] ) ),
    Element( u'HI08-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI08-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI08-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI08-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI08-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI08-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'09',desc=u'Health Care Code Information'),
    Element( u'HI09-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BH'] ) ),
    Element( u'HI09-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI09-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI09-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI09-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI09-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI09-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'10',desc=u'Health Care Code Information'),
    Element( u'HI10-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BH'] ) ),
    Element( u'HI10-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI10-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI10-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI10-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI10-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI10-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'11',desc=u'Health Care Code Information'),
    Element( u'HI11-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BH'] ) ),
    Element( u'HI11-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI11-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI11-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI11-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI11-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI11-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'12',desc=u'Health Care Code Information'),
    Element( u'HI12-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BH'] ) ),
    Element( u'HI12-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI12-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[u'D8'] ) ),
    Element( u'HI12-04', Properties(desc=u'Date Time Period', req_sit=u'R', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI12-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI12-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI12-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
),
Segment( u'HI', Properties(syntax='',req_sit=u'S',repeat=u'2',pos=u'231',desc=u'Value Information'),
  Composite( u'C022', Properties(req_sit=u'R',refdes='',seq=u'01',desc=u'Health Care Code Information'),
    Element( u'HI01-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BE'] ) ),
    Element( u'HI01-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI01-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI01-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI01-05', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI01-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI01-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'02',desc=u'Health Care Code Information'),
    Element( u'HI02-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BE'] ) ),
    Element( u'HI02-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI02-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI02-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI02-05', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI02-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI02-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'03',desc=u'Health Care Code Information'),
    Element( u'HI03-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BE'] ) ),
    Element( u'HI03-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI03-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI03-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI03-05', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI03-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI03-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'04',desc=u'Health Care Code Information'),
    Element( u'HI04-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BE'] ) ),
    Element( u'HI04-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI04-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI04-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI04-05', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI04-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI04-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'05',desc=u'Health Care Code Information'),
    Element( u'HI05-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BE'] ) ),
    Element( u'HI05-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI05-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI05-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI05-05', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI05-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI05-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'06',desc=u'Health Care Code Information'),
    Element( u'HI06-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BE'] ) ),
    Element( u'HI06-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI06-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI06-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI06-05', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI06-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI06-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'07',desc=u'Health Care Code Information'),
    Element( u'HI07-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BE'] ) ),
    Element( u'HI07-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI07-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI07-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI07-05', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI07-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI07-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'08',desc=u'Health Care Code Information'),
    Element( u'HI08-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BE'] ) ),
    Element( u'HI08-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI08-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI08-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI08-05', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI08-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI08-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'09',desc=u'Health Care Code Information'),
    Element( u'HI09-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BE'] ) ),
    Element( u'HI09-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI09-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI09-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI09-05', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI09-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI09-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'10',desc=u'Health Care Code Information'),
    Element( u'HI10-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BE'] ) ),
    Element( u'HI10-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI10-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI10-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI10-05', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI10-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI10-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'11',desc=u'Health Care Code Information'),
    Element( u'HI11-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BE'] ) ),
    Element( u'HI11-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI11-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI11-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI11-05', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI11-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI11-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'12',desc=u'Health Care Code Information'),
    Element( u'HI12-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BE'] ) ),
    Element( u'HI12-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI12-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI12-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI12-05', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI12-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI12-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
),
Segment( u'HI', Properties(syntax='',req_sit=u'S',repeat=u'2',pos=u'231',desc=u'Condition Information'),
  Composite( u'C022', Properties(req_sit=u'R',refdes='',seq=u'01',desc=u'Health Care Code Information'),
    Element( u'HI01-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BG'] ) ),
    Element( u'HI01-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI01-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI01-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI01-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI01-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI01-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'02',desc=u'Health Care Code Information'),
    Element( u'HI02-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BG'] ) ),
    Element( u'HI02-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI02-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI02-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI02-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI02-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI02-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'03',desc=u'Health Care Code Information'),
    Element( u'HI03-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BG'] ) ),
    Element( u'HI03-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI03-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI03-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI03-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI03-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI03-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'04',desc=u'Health Care Code Information'),
    Element( u'HI04-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BG'] ) ),
    Element( u'HI04-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI04-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI04-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI04-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI04-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI04-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'05',desc=u'Health Care Code Information'),
    Element( u'HI05-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BG'] ) ),
    Element( u'HI05-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI05-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI05-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI05-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI05-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI05-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'06',desc=u'Health Care Code Information'),
    Element( u'HI06-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BG'] ) ),
    Element( u'HI06-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI06-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI06-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI06-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI06-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI06-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'07',desc=u'Health Care Code Information'),
    Element( u'HI07-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BG'] ) ),
    Element( u'HI07-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI07-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI07-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI07-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI07-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI07-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'08',desc=u'Health Care Code Information'),
    Element( u'HI08-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BG'] ) ),
    Element( u'HI08-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI08-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI08-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI08-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI08-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI08-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'09',desc=u'Health Care Code Information'),
    Element( u'HI09-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BG'] ) ),
    Element( u'HI09-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI09-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI09-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI09-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI09-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI09-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'10',desc=u'Health Care Code Information'),
    Element( u'HI10-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BG'] ) ),
    Element( u'HI10-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI10-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI10-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI10-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI10-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI10-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'11',desc=u'Health Care Code Information'),
    Element( u'HI11-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BG'] ) ),
    Element( u'HI11-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI11-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI11-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI11-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI11-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI11-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'12',desc=u'Health Care Code Information'),
    Element( u'HI12-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'BG'] ) ),
    Element( u'HI12-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI12-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI12-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI12-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI12-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI12-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
),
Segment( u'HI', Properties(syntax='',req_sit=u'S',repeat=u'2',pos=u'231',desc=u'Treatment Code Information'),
  Composite( u'C022', Properties(req_sit=u'R',refdes='',seq=u'01',desc=u'Health Care Code Information'),
    Element( u'HI01-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'TC'] ) ),
    Element( u'HI01-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI01-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI01-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI01-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI01-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI01-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'02',desc=u'Health Care Code Information'),
    Element( u'HI02-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'TC'] ) ),
    Element( u'HI02-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI02-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI02-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI02-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI02-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI02-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'03',desc=u'Health Care Code Information'),
    Element( u'HI03-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'TC'] ) ),
    Element( u'HI03-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI03-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI03-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI03-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI03-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI03-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'04',desc=u'Health Care Code Information'),
    Element( u'HI04-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'TC'] ) ),
    Element( u'HI04-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI04-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI04-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI04-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI04-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI04-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'05',desc=u'Health Care Code Information'),
    Element( u'HI05-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'TC'] ) ),
    Element( u'HI05-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI05-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI05-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI05-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI05-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI05-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'06',desc=u'Health Care Code Information'),
    Element( u'HI06-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'TC'] ) ),
    Element( u'HI06-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI06-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI06-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI06-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI06-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI06-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'07',desc=u'Health Care Code Information'),
    Element( u'HI07-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'TC'] ) ),
    Element( u'HI07-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI07-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI07-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI07-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI07-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI07-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'08',desc=u'Health Care Code Information'),
    Element( u'HI08-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'TC'] ) ),
    Element( u'HI08-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI08-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI08-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI08-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI08-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI08-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'09',desc=u'Health Care Code Information'),
    Element( u'HI09-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'TC'] ) ),
    Element( u'HI09-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI09-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI09-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI09-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI09-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI09-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'10',desc=u'Health Care Code Information'),
    Element( u'HI10-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'TC'] ) ),
    Element( u'HI10-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI10-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI10-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI10-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI10-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI10-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'11',desc=u'Health Care Code Information'),
    Element( u'HI11-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'TC'] ) ),
    Element( u'HI11-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI11-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI11-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI11-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI11-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI11-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
  Composite( u'C022', Properties(req_sit=u'S',refdes='',seq=u'12',desc=u'Health Care Code Information'),
    Element( u'HI12-01', Properties(desc=u'Code List Qualifier Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=0,
      codes=[u'TC'] ) ),
    Element( u'HI12-02', Properties(desc=u'Industry Code', req_sit=u'R', data_type=(u'AN',u'1',u'30'), position=1,
      codes=[] ) ),
    Element( u'HI12-03', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=2,
      codes=[] ) ),
    Element( u'HI12-04', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=3,
      codes=[] ) ),
    Element( u'HI12-05', Properties(desc=u'Monetary Amount', req_sit=u'N', data_type=(u'R',u'1',u'18'), position=4,
      codes=[] ) ),
    Element( u'HI12-06', Properties(desc=u'Quantity', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=5,
      codes=[] ) ),
    Element( u'HI12-07', Properties(desc=u'Version Identifier', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=6,
      codes=[] ) ),
  ),
),
Segment( u'QTY', Properties(syntax='',req_sit=u'S',repeat=u'4',pos=u'240',desc=u'Claim Quantity'),
  Element( u'QTY01', Properties(desc=u'Quantity Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'CA', u'CD', u'LA', u'NA'] ) ),
  Element( u'QTY02', Properties(desc=u'Quantity', req_sit=u'R', data_type=(u'R',u'1',u'15'), position=2,
    codes=[] ) ),
  Composite( u'C001', Properties(req_sit=u'R',refdes='',seq=u'03',desc=u'Composite Unit of Measure'),
    Element( u'QTY03-01', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=0,
      codes=[u'DA'] ) ),
    Element( u'QTY03-02', Properties(desc=u'Exponent', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=1,
      codes=[] ) ),
    Element( u'QTY03-03', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=2,
      codes=[] ) ),
    Element( u'QTY03-04', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=3,
      codes=[] ) ),
    Element( u'QTY03-05', Properties(desc=u'Exponent', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=4,
      codes=[] ) ),
    Element( u'QTY03-06', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=5,
      codes=[] ) ),
    Element( u'QTY03-07', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=6,
      codes=[] ) ),
    Element( u'QTY03-08', Properties(desc=u'Exponent', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=7,
      codes=[] ) ),
    Element( u'QTY03-09', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=8,
      codes=[] ) ),
    Element( u'QTY03-10', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=9,
      codes=[] ) ),
    Element( u'QTY03-11', Properties(desc=u'Exponent', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=10,
      codes=[] ) ),
    Element( u'QTY03-12', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=11,
      codes=[] ) ),
    Element( u'QTY03-13', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=12,
      codes=[] ) ),
    Element( u'QTY03-14', Properties(desc=u'Exponent', req_sit=u'N', data_type=(u'R',u'1',u'15'), position=13,
      codes=[] ) ),
    Element( u'QTY03-15', Properties(desc=u'Multiplier', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=14,
      codes=[] ) ),
  ),
  Element( u'QTY04', Properties(desc=u'Free-form Information', req_sit=u'N', data_type=(u'AN',u'1',u'30'), position=4,
    codes=[] ) ),
),
Segment( u'HCP', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'241',desc=u'Claim Pricing/Repricing Information'),
  Element( u'HCP01', Properties(desc=u'Pricing Methodology', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'00', u'01', u'02', u'03', u'04', u'05', u'06', u'07', u'08', u'09', u'10', u'11', u'12', u'13', u'14'] ) ),
  Element( u'HCP02', Properties(desc=u'Monetary Amount', req_sit=u'R', data_type=(u'R',u'1',u'18'), position=2,
    codes=[] ) ),
  Element( u'HCP03', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=3,
    codes=[] ) ),
  Element( u'HCP04', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=4,
    codes=[] ) ),
  Element( u'HCP05', Properties(desc=u'Rate', req_sit=u'S', data_type=(u'R',u'1',u'9'), position=5,
    codes=[] ) ),
  Element( u'HCP06', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=6,
    codes=[] ) ),
  Element( u'HCP07', Properties(desc=u'Monetary Amount', req_sit=u'S', data_type=(u'R',u'1',u'18'), position=7,
    codes=[] ) ),
  Element( u'HCP08', Properties(desc=u'Product/Service ID', req_sit=u'S', data_type=(u'AN',u'1',u'48'), position=8,
    codes=[] ) ),
  Element( u'HCP09', Properties(desc=u'Product/Service ID Qualifier', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=9,
    codes=[u'HC'] ) ),
  Element( u'HCP10', Properties(desc=u'Product/Service ID', req_sit=u'S', data_type=(u'AN',u'1',u'48'), position=10,
    codes=[] ) ),
  Element( u'HCP11', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=11,
    codes=[u'DA', u'UN'] ) ),
  Element( u'HCP12', Properties(desc=u'Quantity', req_sit=u'S', data_type=(u'R',u'1',u'15'), position=12,
    codes=[] ) ),
  Element( u'HCP13', Properties(desc=u'Reject Reason Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=13,
    codes=[u'T1', u'T2', u'T3', u'T4', u'T5', u'T6'] ) ),
  Element( u'HCP14', Properties(desc=u'Policy Compliance Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=14,
    codes=[u'1', u'2', u'3', u'4', u'5'] ) ),
  Element( u'HCP15', Properties(desc=u'Exception Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=15,
    codes=[u'1', u'2', u'3', u'4', u'5', u'6'] ) ),
),
parsed_837_2305,
parsed_837_2310A,
parsed_837_2310B,
parsed_837_2310C,
parsed_837_2310E,
parsed_837_2320,
parsed_837_2400,
)
parsed_837_2000C = Loop( u'2000C', Properties(looptype='',repeat=u'>1',pos=u'160',req_sit=u'S',desc=u'Patient Hierarchical Level'),
Segment( u'HL', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'001',desc=u'Patient Hierarchical Level'),
  Element( u'HL01', Properties(desc=u'Hierarchical ID Number', req_sit=u'R', data_type=(u'AN',u'1',u'12'), position=1,
    codes=[] ) ),
  Element( u'HL02', Properties(desc=u'Hierarchical Parent ID Number', req_sit=u'R', data_type=(u'AN',u'1',u'12'), position=2,
    codes=[] ) ),
  Element( u'HL03', Properties(desc=u'Hierarchical Level Code', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=3,
    codes=[u'23'] ) ),
  Element( u'HL04', Properties(desc=u'Hierarchical Child Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[u'0'] ) ),
),
Segment( u'PAT', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'007',desc=u'Patient Information'),
  Element( u'PAT01', Properties(desc=u'Individual Relationship Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'01', u'04', u'05', u'07', u'10', u'15', u'17', u'19', u'20', u'21', u'22', u'23', u'24', u'29', u'32', u'33', u'36', u'39', u'40', u'41', u'43', u'53', u'G8'] ) ),
  Element( u'PAT02', Properties(desc=u'Patient Location Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=2,
    codes=[] ) ),
  Element( u'PAT03', Properties(desc=u'Employment Status Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=3,
    codes=[] ) ),
  Element( u'PAT04', Properties(desc=u'Student Status Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[] ) ),
  Element( u'PAT05', Properties(desc=u'Date Time Period Format Qualifier', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=5,
    codes=[] ) ),
  Element( u'PAT06', Properties(desc=u'Date Time Period', req_sit=u'N', data_type=(u'AN',u'1',u'35'), position=6,
    codes=[] ) ),
  Element( u'PAT07', Properties(desc=u'Unit or Basis for Measurement Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=7,
    codes=[] ) ),
  Element( u'PAT08', Properties(desc=u'Weight', req_sit=u'N', data_type=(u'R',u'1',u'10'), position=8,
    codes=[] ) ),
  Element( u'PAT09', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=9,
    codes=[] ) ),
),
parsed_837_2010CA,
parsed_837_2300,
)
parsed_837_2000B = Loop( u'2000B', Properties(looptype='',repeat=u'>1',pos=u'020',req_sit=u'R',desc=u'Subscriber Hierarchichal Level'),
Segment( u'HL', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'001',desc=u'Subscriber Hierarchical Level'),
  Element( u'HL01', Properties(desc=u'Hierarchical ID Number', req_sit=u'R', data_type=(u'AN',u'1',u'12'), position=1,
    codes=[] ) ),
  Element( u'HL02', Properties(desc=u'Hierarchical Parent ID Number', req_sit=u'R', data_type=(u'AN',u'1',u'12'), position=2,
    codes=[] ) ),
  Element( u'HL03', Properties(desc=u'Hierarchical Level Code', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=3,
    codes=[u'22'] ) ),
  Element( u'HL04', Properties(desc=u'Hierarchical Child Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[u'0', u'1'] ) ),
),
Segment( u'SBR', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'005',desc=u'Subscriber Information'),
  Element( u'SBR01', Properties(desc=u'Payer Responsibility Sequence Number Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=1,
    codes=[u'P', u'S', u'T'] ) ),
  Element( u'SBR02', Properties(desc=u'Individual Relationship Code', req_sit=u'S', data_type=(u'ID',u'2',u'2'), position=2,
    codes=[u'18'] ) ),
  Element( u'SBR03', Properties(desc=u'Reference Identification', req_sit=u'S', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'SBR04', Properties(desc=u'Name', req_sit=u'S', data_type=(u'AN',u'1',u'60'), position=4,
    codes=[] ) ),
  Element( u'SBR05', Properties(desc=u'Insurance Type Code', req_sit=u'N', data_type=(u'ID',u'1',u'3'), position=5,
    codes=[] ) ),
  Element( u'SBR06', Properties(desc=u'Coordination of Benefits Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=6,
    codes=[] ) ),
  Element( u'SBR07', Properties(desc=u'Yes/No Condition or Response Code', req_sit=u'N', data_type=(u'ID',u'1',u'1'), position=7,
    codes=[] ) ),
  Element( u'SBR08', Properties(desc=u'Employment Status Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=8,
    codes=[] ) ),
  Element( u'SBR09', Properties(desc=u'Claim Filing Indicator Code', req_sit=u'S', data_type=(u'ID',u'1',u'2'), position=9,
    codes=[u'09', u'10', u'11', u'12', u'13', u'14', u'15', u'16', u'AM', u'BL', u'CH', u'CI', u'DS', u'HM', u'LI', u'LM', u'MA', u'MB', u'MC', u'OF', u'TV', u'VA', u'WC', u'ZZ'] ) ),
),
parsed_837_2010BA,
parsed_837_2010BB,
parsed_837_2010BC,
parsed_837_2010BD,
parsed_837_2300,
parsed_837_2000C,
)
parsed_837_2000A = Loop( u'2000A', Properties(looptype='',repeat=u'>1',pos=u'001',req_sit=u'R',desc=u'Billing/Pay-To Provider Hierarchical Level'),
Segment( u'HL', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'001',desc=u'Billing/Pay-To Provider Hierarchical Level'),
  Element( u'HL01', Properties(desc=u'Hierarchical ID Number', req_sit=u'R', data_type=(u'AN',u'1',u'12'), position=1,
    codes=[] ) ),
  Element( u'HL02', Properties(desc=u'Hierarchical Parent ID Number', req_sit=u'N', data_type=(u'AN',u'1',u'12'), position=2,
    codes=[] ) ),
  Element( u'HL03', Properties(desc=u'Hierarchical Level Code', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=3,
    codes=[u'20'] ) ),
  Element( u'HL04', Properties(desc=u'Hierarchical Child Code', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[u'1'] ) ),
),
Segment( u'PRV', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'003',desc=u'Billing/Pay-To Provider Specialty Information'),
  Element( u'PRV01', Properties(desc=u'Provider Code', req_sit=u'R', data_type=(u'ID',u'1',u'3'), position=1,
    codes=[u'BI', u'PT'] ) ),
  Element( u'PRV02', Properties(desc=u'Reference Identification Qualifier', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=2,
    codes=[u'ZZ'] ) ),
  Element( u'PRV03', Properties(desc=u'Reference Identification', req_sit=u'R', data_type=(u'AN',u'1',u'50'), position=3,
    codes=[] ) ),
  Element( u'PRV04', Properties(desc=u'State or Province Code', req_sit=u'N', data_type=(u'ID',u'2',u'2'), position=4,
    codes=[] ) ),
  Composite( u'C035', Properties(req_sit=u'N',refdes='',seq=u'05',desc=u'Provider Specialty Information'),
  ),
  Element( u'PRV06', Properties(desc=u'Provider Organization Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=6,
    codes=[] ) ),
),
Segment( u'CUR', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'010',desc=u'Foreign Currency Information'),
  Element( u'CUR01', Properties(desc=u'Entity Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'3'), position=1,
    codes=[u'85'] ) ),
  Element( u'CUR02', Properties(desc=u'Currency Code', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=2,
    codes=[] ) ),
  Element( u'CUR03', Properties(desc=u'Exchange Rate', req_sit=u'N', data_type=(u'R',u'4',u'10'), position=3,
    codes=[] ) ),
  Element( u'CUR04', Properties(desc=u'Entity Identifier Code', req_sit=u'N', data_type=(u'ID',u'2',u'3'), position=4,
    codes=[] ) ),
  Element( u'CUR05', Properties(desc=u'Currency Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=5,
    codes=[] ) ),
  Element( u'CUR06', Properties(desc=u'Currency Market/Exchange Code', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=6,
    codes=[] ) ),
  Element( u'CUR07', Properties(desc=u'Date/Time Qualifier', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=7,
    codes=[] ) ),
  Element( u'CUR08', Properties(desc=u'Date', req_sit=u'N', data_type=(u'DT',u'8',u'8'), position=8,
    codes=[] ) ),
  Element( u'CUR09', Properties(desc=u'Time', req_sit=u'N', data_type=(u'TM',u'4',u'8'), position=9,
    codes=[] ) ),
  Element( u'CUR10', Properties(desc=u'Date/Time Qualifier', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=10,
    codes=[] ) ),
  Element( u'CUR11', Properties(desc=u'Date', req_sit=u'N', data_type=(u'DT',u'8',u'8'), position=11,
    codes=[] ) ),
  Element( u'CUR12', Properties(desc=u'Time', req_sit=u'N', data_type=(u'TM',u'4',u'8'), position=12,
    codes=[] ) ),
  Element( u'CUR13', Properties(desc=u'Date/Time Qualifier', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=13,
    codes=[] ) ),
  Element( u'CUR14', Properties(desc=u'Date', req_sit=u'N', data_type=(u'DT',u'8',u'8'), position=14,
    codes=[] ) ),
  Element( u'CUR15', Properties(desc=u'Time', req_sit=u'N', data_type=(u'TM',u'4',u'8'), position=15,
    codes=[] ) ),
  Element( u'CUR16', Properties(desc=u'Date/Time Qualifier', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=16,
    codes=[] ) ),
  Element( u'CUR17', Properties(desc=u'Date', req_sit=u'N', data_type=(u'DT',u'8',u'8'), position=17,
    codes=[] ) ),
  Element( u'CUR18', Properties(desc=u'Time', req_sit=u'N', data_type=(u'TM',u'4',u'8'), position=18,
    codes=[] ) ),
  Element( u'CUR19', Properties(desc=u'Date/Time Qualifier', req_sit=u'N', data_type=(u'ID',u'3',u'3'), position=19,
    codes=[] ) ),
  Element( u'CUR20', Properties(desc=u'Date', req_sit=u'N', data_type=(u'DT',u'8',u'8'), position=20,
    codes=[] ) ),
  Element( u'CUR21', Properties(desc=u'Time', req_sit=u'N', data_type=(u'TM',u'4',u'8'), position=21,
    codes=[] ) ),
),
parsed_837_2010AA,
parsed_837_2010AB,
parsed_837_2000B,
)
parsed_837_DETAIL = Loop( u'DETAIL', Properties(looptype=u'wrapper',repeat=u'>1',pos=u'020',req_sit=u'S',desc=u'Table 2 - Detail'),
parsed_837_2000A,
)
parsed_837_ST_LOOP = Loop( u'ST_LOOP', Properties(looptype=u'explicit',repeat=u'>1',pos=u'020',req_sit=u'R',desc=u'Transaction Set Header'),
Segment( u'ST', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'005',desc=u'Transaction Set Header'),
  Element( u'ST01', Properties(desc=u'Transaction Set Identifier Code', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=1,
    codes=[u'837'] ) ),
  Element( u'ST02', Properties(desc=u'Transaction Set Control Number', req_sit=u'R', data_type=(u'AN',u'4',u'9'), position=2,
    codes=[] ) ),
),
parsed_837_HEADER,
parsed_837_DETAIL,
Segment( u'SE', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'555',desc=u'Transaction Set Trailer'),
  Element( u'SE01', Properties(desc=u'Number of Included Segments', req_sit=u'R', data_type=(u'N0',u'1',u'10'), position=1,
    codes=[] ) ),
  Element( u'SE02', Properties(desc=u'Transaction Set Control Number', req_sit=u'R', data_type=(u'AN',u'4',u'9'), position=2,
    codes=[] ) ),
),
)
parsed_837_GS_LOOP = Loop( u'GS_LOOP', Properties(looptype=u'explicit',repeat=u'>1',pos=u'020',req_sit=u'R',desc=u'Functional Group Header'),
Segment( u'GS', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'010',desc=u'Functional Group Header'),
  Element( u'GS01', Properties(desc=u'Functional Identifier Code', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'HC'] ) ),
  Element( u'GS02', Properties(desc=u'Application Senders Code', req_sit=u'R', data_type=(u'AN',u'2',u'15'), position=2,
    codes=[] ) ),
  Element( u'GS03', Properties(desc=u'124', req_sit=u'R', data_type=(u'AN',u'2',u'15'), position=3,
    codes=[] ) ),
  Element( u'GS04', Properties(desc=u'Date', req_sit=u'R', data_type=(u'DT',u'8',u'8'), position=4,
    codes=[] ) ),
  Element( u'GS05', Properties(desc=u'Time', req_sit=u'R', data_type=(u'TM',u'4',u'8'), position=5,
    codes=[] ) ),
  Element( u'GS06', Properties(desc=u'Group Control Number', req_sit=u'R', data_type=(u'N0',u'1',u'9'), position=6,
    codes=[] ) ),
  Element( u'GS07', Properties(desc=u'Responsible Agency Code', req_sit=u'R', data_type=(u'ID',u'1',u'2'), position=7,
    codes=[u'X'] ) ),
  Element( u'GS08', Properties(desc=u'Version / Release / Industry Identifier Code', req_sit=u'R', data_type=(u'AN',u'1',u'12'), position=8,
    codes=[u'004010X096A1'] ) ),
),
parsed_837_ST_LOOP,
Segment( u'GE', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'030',desc=u'Functional Group Trailer'),
  Element( u'GE01', Properties(desc=u'97', req_sit=u'R', data_type=(u'N0',u'1',u'6'), position=1,
    codes=[] ) ),
  Element( u'GE02', Properties(desc=u'Group Control Number', req_sit=u'R', data_type=(u'N0',u'1',u'9'), position=2,
    codes=[] ) ),
),
)
parsed_837_ISA_LOOP = Loop( u'ISA_LOOP', Properties(looptype=u'explicit',repeat=u'>1',pos=u'001',req_sit=u'R',desc=u'Interchange Control Header'),
Segment( u'ISA', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'010',desc=u'Interchange Control Header'),
  Element( u'ISA01', Properties(desc=u'I01', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=1,
    codes=[u'00', u'03'] ) ),
  Element( u'ISA02', Properties(desc=u'I02', req_sit=u'R', data_type=(u'AN',u'10',u'10'), position=2,
    codes=[] ) ),
  Element( u'ISA03', Properties(desc=u'I03', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=3,
    codes=[u'00', u'01'] ) ),
  Element( u'ISA04', Properties(desc=u'I04', req_sit=u'R', data_type=(u'AN',u'10',u'10'), position=4,
    codes=[] ) ),
  Element( u'ISA05', Properties(desc=u'I05', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=5,
    codes=[u'01', u'14', u'20', u'27', u'28', u'29', u'30', u'33', u'ZZ'] ) ),
  Element( u'ISA06', Properties(desc=u'I06', req_sit=u'R', data_type=(u'AN',u'15',u'15'), position=6,
    codes=[] ) ),
  Element( u'ISA07', Properties(desc=u'I05', req_sit=u'R', data_type=(u'ID',u'2',u'2'), position=7,
    codes=[u'01', u'14', u'20', u'27', u'28', u'29', u'30', u'33', u'ZZ'] ) ),
  Element( u'ISA08', Properties(desc=u'I07', req_sit=u'R', data_type=(u'AN',u'15',u'15'), position=8,
    codes=[] ) ),
  Element( u'ISA09', Properties(desc=u'I08', req_sit=u'R', data_type=(u'DT',u'6',u'6'), position=9,
    codes=[] ) ),
  Element( u'ISA10', Properties(desc=u'I09', req_sit=u'R', data_type=(u'TM',u'4',u'4'), position=10,
    codes=[] ) ),
  Element( u'ISA11', Properties(desc=u'I10', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=11,
    codes=[u'U'] ) ),
  Element( u'ISA12', Properties(desc=u'I11', req_sit=u'R', data_type=(u'ID',u'5',u'5'), position=12,
    codes=[u'00401'] ) ),
  Element( u'ISA13', Properties(desc=u'I12', req_sit=u'R', data_type=(u'N0',u'9',u'9'), position=13,
    codes=[] ) ),
  Element( u'ISA14', Properties(desc=u'I13', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=14,
    codes=[u'0', u'1'] ) ),
  Element( u'ISA15', Properties(desc=u'I14', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=15,
    codes=[u'P', u'T'] ) ),
  Element( u'ISA16', Properties(desc=u'I15', req_sit=u'R', data_type=(u'AN',u'1',u'1'), position=16,
    codes=[] ) ),
),
parsed_837_GS_LOOP,
Segment( u'TA1', Properties(syntax='',req_sit=u'S',repeat=u'1',pos=u'020',desc=u'Interchange Acknowledgement'),
  Element( u'TA101', Properties(desc=u'I12', req_sit=u'R', data_type=(u'N0',u'9',u'9'), position=1,
    codes=[] ) ),
  Element( u'TA102', Properties(desc=u'I08', req_sit=u'R', data_type=(u'DT',u'6',u'6'), position=2,
    codes=[] ) ),
  Element( u'TA103', Properties(desc=u'I09', req_sit=u'R', data_type=(u'TM',u'4',u'4'), position=3,
    codes=[] ) ),
  Element( u'TA104', Properties(desc=u'I17', req_sit=u'R', data_type=(u'ID',u'1',u'1'), position=4,
    codes=[u'A', u'E', u'R'] ) ),
  Element( u'TA105', Properties(desc=u'I18', req_sit=u'R', data_type=(u'ID',u'3',u'3'), position=5,
    codes=[u'000', u'001', u'002', u'003', u'004', u'005', u'006', u'007', u'008', u'009', u'010', u'011', u'012', u'013', u'014', u'015', u'016', u'017', u'018', u'019', u'020', u'021', u'022', u'023', u'024', u'025', u'026', u'027', u'028', u'029', u'030', u'031'] ) ),
),
Segment( u'IEA', Properties(syntax='',req_sit=u'R',repeat=u'1',pos=u'030',desc=u'Interchange Control Trailer'),
  Element( u'IEA01', Properties(desc=u'I16', req_sit=u'R', data_type=(u'N0',u'1',u'5'), position=1,
    codes=[] ) ),
  Element( u'IEA02', Properties(desc=u'I12', req_sit=u'R', data_type=(u'N0',u'9',u'9'), position=2,
    codes=[] ) ),
),
)
parsed_837 = Message( u'837', Properties(desc=u'HIPAA Health Care Claim: Institutional X096A1-837'),
parsed_837_ISA_LOOP,
)

